/*
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2012.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */

`ifndef avery_defines_svh
`define avery_defines_svh

`ifndef _VCP
`ifndef __FILE__
    `ifndef AVERY_NC
	`define __FILE__ `"`"
    `endif
`endif

`ifndef __LINE__
    `ifndef AVERY_NC
	`define __LINE__ 0 
    `endif
`endif
`endif

`ifndef avery_fileline
`define avery_fileline $psprintf("%s", `__LINE__ == 0 ? "" : $psprintf("@%s:%0d", `__FILE__, `__LINE__))
`endif

`ifndef avery_fline
`define avery_fline    $psprintf("%s", `__LINE__ == 0 ? "" : $psprintf("@%s:%0d", `__FILE__, `__LINE__))
`endif

`ifdef AVERY_UVM
    `define AVERY_UVM_OBJECT_UTILS(T) `uvm_object_utils(T)
    `define AVERY_NEW(T, name) T::type_id::create(name)
`else
    `define AVERY_UVM_OBJECT_UTILS(T)
    `define AVERY_NEW(T, name) new(name)
`endif

`ifdef AVERY_UVM
    `define AVERY_NEW_PARENT(T, name, parent) T::type_id::create(name, parent)
`else
    `define AVERY_NEW_PARENT(T, name, parent) new(name, parent)
`endif


`ifndef avery_xvm_parent
    `ifdef AVERY_UVM
        `define avery_xvm_parent uvm_component   parent = null
    `elsif AVERY_OVM
        `define avery_xvm_parent ovm_component   parent = null
    `elsif AVERY_VMM                        
        `define avery_xvm_parent int             parent = 0    // stream_id for VMM
    `else
        `define avery_xvm_parent avery_component parent = null
    `endif
`endif 

`ifdef AVERY_NAMED_CONSTRUCTOR
    // for UVM 1.2 requirement
    `define  avery_new_named(x) new(string name="", x)
    `define  avery_strname      string name="",
    `define  avery_new1(x)      new("", x)
    `define  avery_new2(x, y)   new("", x, y)
    `define  avery_strarg       "",
    `define  avery_namearg      name,
    `define  avery_super_new    super.new(name)
`else
    `define  avery_new_named(x) new(x)
    `define  avery_strname  
    `define  avery_new1(x)      new(x)
    `define  avery_new2(x, y)   new(x, y)
    `define  avery_strarg
    `define  avery_namearg      
    `define  avery_super_new    super.new()
`endif

`ifdef AVERY_USE_CLK_DELAY
    `define avery_pound_ns(x) \
	do begin \
	    if (int'(x/1ns) == 0)  begin \
		@(posedge avery_pkg::avery_base_clk); \
	    end else \
		repeat (x/1ns) @(posedge avery_pkg::avery_base_clk); \
	end while (0)
    `define avery_pound_us(x) \
	do begin \
	    $display("avery_pound_us(%0t)", x); \
	    if (int'(x/1us) == 0)  begin \
		@(posedge avery_pkg::avery_base_clk1k); \
	    end else \
		repeat (x/1us) @(posedge avery_pkg::avery_base_clk1k); \
	end while (0)
`else
    `define avery_pound_ns(x) #(x)
    `define avery_pound_us(x) #(x)
`endif

// Wait or die if timed out
`ifndef avery_wait_die
`define avery_wait_die(cond, timer, LOG, msg) \
    fork begin \
        fork \
            wait (cond);\
	    #timer LOG.fatal($psprintf("%0dns elapsed: %s %s", timer/1ns, msg, `avery_fileline)); \
	join_any \
        disable fork; \
    end join
`endif


// wait in background and die when timed out.
`ifndef avery_wait_die_bg
`define avery_wait_die_bg(cond, timer, LOG, msg) \
    fork begin \
        fork \
            wait (cond);\
	    #timer LOG.fatal($psprintf("%0dns elapsed: %s %s", timer/1ns, msg, `avery_fileline)); \
	join_any \
        disable fork; \
    end join_none
`endif

`ifndef avery_fork
    `define avery_fork fork begin fork
`endif

`ifndef avery_join_any
    `define avery_join_any join_any disable fork; end join
`endif


`define avery_ring_len(tail, head, DEPTH)  \
	((tail + DEPTH - head) % DEPTH)
`define avery_ring_space(tail, head, DEPTH)  \
	((head + DEPTH - tail - 1) % DEPTH)  // one less


`define avery_reg_f_m(f, n_bits, lsb, def_val, sticky, acc, rand_default, rand_sticky, rand_acc) \
    rand avery_reg_field f = new(`"f`", this, n_bits, lsb, def_val, sticky, acc, \
                                rand_default, rand_sticky, rand_acc, 1)

`ifndef avery_print_stack
    `ifdef AVERY_VCS
	`define avery_print_stack $stack()
    `elsif AVERY_NC
	`define avery_print_stack $stacktrace
    `elsif AVERY_ALDEC
         // do nothing
         `define avery_print_stack do begin end while (0)
    `else
	// not needed after MTI10.2 `define avery_print_stack do if ($test$plusargs("avery_stack")) begin avery_pkg::avery_data_base a; a.up = null; end while (0)
	`define avery_print_stack $stacktrace
    `endif
`endif

`ifndef avery_finish
    `define avery_finish do begin $fflush(); `avery_print_stack; $finish; end while (0)
`endif

// USE for register test case in avery_pkg_test or UVM 
`ifndef avery_test_reg
    `ifdef AVERY_SV_TEST_CASE
        `define avery_test_reg(T) avery_pkg_test::avy_test_registry #(T, `"T`") test_id;
    `elsif AVERY_UVM
        `define avery_test_reg(T) `uvm_component_utils(T)
    `else
        `define avery_test_reg(T) avery_pkg_test::avy_test_registry #(T, `"T`") test_id;
    `endif
`endif 

`ifndef avery_test_reg_new
    `ifdef AVERY_SV_TEST_CASE
        `define avery_test_reg_new(T) `avery_test_reg(T) \
	    function new(string name, avery_component parent = null); \
	        super.new(`"T`", parent); \
	    endfunction
    `else
        `define avery_test_reg_new(T) `avery_test_reg(T) \
	    function new(string name, `avery_xvm_parent); \
	        super.new(`"T`", parent); \
	    endfunction
    `endif
`endif 

// USE for convert MACRO string to verilog string, 
// EXP: string s = `avery_stringify(`MACRO) or `include `avery_stringify(`MACRO)
`ifndef avery_stringify
    `define avery_stringify(x) `"x`"
`endif 

// USE for register test sequence for UVM 
`ifndef avery_seq_reg
    `ifdef AVERY_UVM
        `define avery_seq_reg(T, S) \
	    `uvm_object_utils(T) \
	    `uvm_declare_p_sequencer(S)
    `else
        `define avery_seq_reg(T, S)
    `endif
`endif 



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
nFC28O+5rWRk8B2Eg5/tYENYMiSD3K3lKplBsS8I9lucGwBq7kZLmtFo88hwjoEa
BXwHz+5kxSJZEjnl0GKBGh6XInIOC18tIRfnmdopW/7WSanevB7qU7/irJiW9dJd
kLvbXnEMffhTmeNZasIKXJYJkaOGkJxw5q9Ha0FhnZY=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
utTRLdJyfjg4UGMoLiGeFcEhqUq8xdeHXOBzxb1EWxg6WiOptj+Qw6UHBlZ96qqJ
CSGwz6xjK7JN2CWETuhoW7zWxHgLFmm2WEWyMUGaZyBZNnhBzIDFsnR+yEgiazct
mlxDF5QkAKg133z8K7bKAkYZwmT3s3P58jTpKVJBJdU=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
F2QhQhHJFoQ7ESlqQft+Bvzhq21RBgi5NHVxoGFmP7bWhVOftOlvPRE8hHoOGT6b
orUjA9A3UG/0zKZcd2RmOQ==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
gmn56Nd6s8mFGi7aDaSIa9nJaS89tQc/B6gB0qL5zLDo6bHI56Z/o66qNfPZCA1o
UVlvSWd5d1gSxUHnZuHTNLh5r05DNvhjcaSMctHR62pHHYHaS0OgZG442TELG6be
g8lLhGOpl5+fFbwAkgFyXFdGQ0KewgnKZadJivaPwgwOBzWgdGeNgU6Rpyw329As
ds73V8RgENsvqhKWbwZ8hgapz/KOhK6hUqTauiE8m+dfG8V0IGiprOrlpDNmJhT6
4EZGr0NIRF0SvZg8EHwGsoEKmsvWFQ5eyvP22xYz2mD3oe7uTyiu0Qj+LrQ8FrVB
dri6UmSK1MPX/IcwGonwxw==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
anL0Fmjy1uqfHWUqC32okQ9DlliH30zq7BWjPPWLD98+fCOHkfMyhp1XetAcYL6w
jHaFkZZjJ530C5HQcfKyOasEyzdrbKO2gj4Qvvg8kZ20bkrCvSGXpB4yPxbtLq2N
/TUi9z9Sb9qeUwG/RvIZ7nBB3Q8nMmpXtt0++a19gzM=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
lFhYVXzYIEuciRhC1Lke48duHoz2jKiEqVD78HiU9xK2XqOyjGB/huSelUtSzxUl
cETzIFTIaTW752euDi4NK0VsyPWTbAt5IOOPQ2xz6430vjnT3I/WWgsUb0ArPd/S
jyeoUsFg+d9vCXTNARUSroIfEPQQUnluXRyARl6c3VRDIcPH+rjNWD3zdBE2Te9s
gA46T8r0NIBPLcbahqdauxKBV86T/gEaNvk4dwskvpjS/8eeDlZ84+vGnXsfXP0q
dL7Olr3UT+y4aL3NgZWxiY8kHgtMHarKDJM3cHwptae2z0cJYqmZtAq8nL/9wzz/
obaD6CZZFQyxGa1oG/Q1uw==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
X3v3g0+LKddnXp1dHO4fsdyVJ1U9DWY7jhfbAqezlM/Z69LHTE3PabHY97K1spJG
6JO1m3Rw6MlZbAYfUzINybLold7nSoOmvLs6piBo060ICXy27fqLzErzfWRMYd4K
N8S975ge2pXf5z6Gs5dMVmwp2ezBSt9euWZAWXZmRqBHg9cCsPAFxcQG93uO8Bmq
j1IXx04oHM3HUnbqrxoTzQQ7ZmYXPrm+cn/MSi0rhb4ZX/xkpXw1v/X8a43oxCFY
u1S9P9OzZBd0pVLqZv3qzd5Kjx37v1yi9rrqCLjAXm6964MK/OfHO/VqY6gxzG+M
mcNTbdhDvjGaAfaKE1QUIA==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 5616 )
`pragma protect data_block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`pragma protect end_protected

`ifndef AVERY_MUX_DWIDTH
    `define AVERY_MUX_DWIDTH 3
`endif

`endif

// $Revision: 1.50 $

