/*
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2011.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */
`ifndef avery_pkg_inc_svh
`define avery_pkg_inc_svh

/* 
    Types:
        avery_u8
        avery_u16
        avery_u32
        avery_u64
        avery_data_base
        avery_hash_list
        avery_ring
        avery_pure_component
        avery_component
        avery_log

    Methods:
        function int       avery_max              ( int i, int j)
        function int       avery_min              ( int i, int j)
        function bit[63:0] avery_round_to_dw      ( bit[31:0] num_bytes)
        function bit[63:0] avery_round_up         (bit[63:0] a, bit[63:0] boundary);
        function void      avery_pack_bytes       
        function void      avery_pack_bytes_arr   
        function void      avery_q2a              ( input bit[31:0] from[$], output bit[31:0] to[])
        function void      avery_dwords_to_bytes  ( bit[31:0] dq[$], output bit[7:0] bq[$])
        function void      avery_align_addr       ( input bit[63:0] addr, bit[63:0] n_bytes, output bit[63:0] out_addr, bit[63:0] n_dwords)
        function void      avery_unpack_dwords    
        function void      avery_unpack_dwords_arr
        function int       avery_get_device_id    ( )
        function int       avery_power_of_two     ( bit[63:0] v)
        function bit[63:0] avery_multiple_of      ( bit[63:0] a, bit[63:0] b)
        function int       avery_two_to_power_of  ( bit[ 7:0] v)
        function bit       avery_is_power_of_two  ( bit[63:0] v)
        function bit       avery_is_multiple      ( bit[63:0] a, bit[63:0] b)
        function bit[63:0] avery_offset_mask      ( bit[63:0] page_size)
        function bit[63:0] avery_page_mask        ( bit[63:0] page_size)
        function string    avery_print_dw_array   ( bit[31:0] da[] , int len=16, string prefix="")
        function string    avery_print_dw_q       ( bit[31:0] da[$], int len=16, string prefix="")
        function string    avery_print_bytes      ( byte b[$], string prefix="")
        function string    avery_print_u8         ( bit[7:0] b[$], string prefix="")
        function void      avery_dq_2_ba          ( ref bit[31:0] from[$], ref bit[7:0] to[]);
        function bit[31:0] avery_swap_endian      ( bit[31:0] v)
*/
/*
`include "avery_defines.svh"
`include "avery_log.sv"
`include "avery_ring.sv"
`include "avery_timer.sv"
`include "avery_param_log.sv"
`include "avery_asso_mem.sv"
`include "avery_mem_mgr.sv"
`include "avery_reg_mask.sv"
`include "avery_scoreboard.sv"
`include "avery_fifo.sv"
`include "avery_rw_data.sv"
*/

`timescale 1ps/1ps

package avery_pkg;

`ifdef AVERY_UVM
    import uvm_pkg::*;
    `include "uvm_macros.svh"
`elsif AVERY_OVM
    import ovm_pkg::*;
    `include "ovm_macros.svh"
`elsif AVERY_VMM
    `include "vmm.sv"
`endif

`ifdef AVERY_CHECK_PLI
// Check if PLI is successfully included in User's run command
const bit avery_pli_chk = $avy_pli_check();
`endif

typedef class avery_data_base;
typedef class avery_pure_component;
typedef class avery_component;
typedef class avery_rw_data;
typedef class avery_sha256;
typedef class avery_sha1;
typedef class avery_rsassa_pkcs1_v1_5_verify;
typedef class avery_aes;
typedef class avery_rsa;
typedef class avery_oaep;
typedef class avery_reed_solomon;
typedef class avery_firecode;
typedef class avery_cprm;
typedef class avery_aesgcm;
typedef class avery_cmac;
typedef class avery_aes_wrap;
typedef class avery_log;
typedef class avery_scoreboard_base;

const bit[63:0] avery_1k   = 1024;
const bit[63:0] avery_2k   = 2048;
const bit[63:0] avery_4k   = 4096;
const bit[63:0] avery_8k   = 8192;
const bit[63:0] avery_16k  = 1<<14;
const bit[63:0] avery_32k  = 1<<15;
const bit[63:0] avery_40k  = (1<<15 + 8192);
const bit[63:0] avery_64k  = 1<<16;
const bit[63:0] avery_128k = 1<<17;
const bit[63:0] avery_256k = 1<<18;
const bit[63:0] avery_512k = 1<<19;
const bit[63:0] avery_1m   = 1<<20;
const bit[63:0] avery_2m   = 1<<21;
const bit[63:0] avery_64m  = 1<<26;
const bit[63:0] avery_4g   = 64'h1<<32;
const bit[63:0] avery_8g   = 64'h1<<33;
// for different timescale, avery_pkg is 1ps
const time      avery_ps   = 1ps;
const time      avery_ns   = 1ns;
const time      avery_us   = 1us;
const time      avery_ms   = 1ms;

avery_log avery_pkg_log = new("avery_pkg_log");

bit avery_base_clk;
bit avery_base_clk1k;

typedef struct packed {
    bit[31:0] high;
    bit[31:0] low;
} avery_u64;

typedef struct packed {
    avery_u64 h;
    avery_u64 l;
} avery_u128;

typedef bit[135:0] avery_u136;
typedef bit[64:0] avery_u65;

typedef bit[32:0] avery_u33;

typedef struct packed {
    bit[15:0] high;
    bit[15:0] low;
} avery_u32;

typedef bit[23:0] avery_u24;
typedef bit[15:0] avery_u16;
typedef bit[7:0]  avery_u8;
typedef bit[1:0][7:0] avery_u8_2;

typedef struct packed {
    bit[ 3:0] h;
    bit[ 3:0] l;
} avery_u4_2;

typedef struct packed {
    bit[7:0]  h;
    bit[15:0] m;
    bit[7:0]  l;
} avery_u32_3;

typedef struct packed {
    bit [3:0][7:0] bytes;
} avery_little_endian_t;

typedef struct packed {
    bit [0:3][7:0] bytes;
} avery_big_endian_t;

typedef bit[0:3][7:0] avery_big_endian_dw;

typedef enum
{
    // MIPI Manufacturer ID for Avery Design Systems, Inc
    AMIPI_MANU_ID= 'h0318
} avery_id_e;

typedef enum
{
    AVY_DBG_general,        // general message
    AVY_DBG_detail,         // detailed trace message
    AVY_DBG_avery_reg,
    AVY_DBG_aes,	    // AES encryption
    AVY_DBG_stacktrace,
    AVY_DBG_timer
} avy_debug_e; // for avery_log only

typedef enum
{
    AVY_REG_TYP_RO,         //Read-Only register
    AVY_REG_TYP_ROS,        //Read-Only-Sticky register
    AVY_REG_TYP_ROC,        //Read-Only and Read to clear
    AVY_REG_TYP_RW,         //Rewritable
    AVY_REG_TYP_RWS,        //Rewritable-Sticky
    AVY_REG_TYP_RW1S,       //Write-1 to Set (Write-0 is ignored)
    AVY_REG_TYP_RW1C,       //Write-1 to Clear
    AVY_REG_TYP_RW1CS,      //Write-1 to Clear - Sticky
    AVY_REG_TYP_WO,         //or RW_RET_0, Rewritable but always returns 0 when read 
    AVY_REG_TYP_WC,         //write clear
    AVY_REG_TYP_RSVD,        //Reserved
    AVY_REG_TYP_MIXED // not all bits have the same type
} avy_reg_typ_e;

typedef enum
{
    AVY_chklist_id_first

} avy_chklist_id_e;

typedef enum {
    AVY_IGNORE, 
    AVY_INFO,   
    AVY_EXPECT, 
    AVY_WARNING,
    AVY_USAGE, 
    AVY_ERROR,  
    AVY_FATAL
} avery_severity;

function automatic bit[63:0] avery_max(bit[63:0] i, bit[63:0] j);
    return ((i > j) ? i : j);
endfunction

function automatic bit[63:0] avery_min(bit[63:0] i, bit[63:0] j);
    return ((i > j) ? j : i);
endfunction

function bit [`AVERY_MUX_DWIDTH - 1:0] avery_mux8_1(
    input bit [2:0] sw2,
    input logic [`AVERY_MUX_DWIDTH - 1:0] in0= 'z,
    input logic [`AVERY_MUX_DWIDTH - 1:0] in1= 'z,
    input logic [`AVERY_MUX_DWIDTH - 1:0] in2= 'z,
    input logic [`AVERY_MUX_DWIDTH - 1:0] in3= 'z,
    input logic [`AVERY_MUX_DWIDTH - 1:0] in4= 'z,
    input logic [`AVERY_MUX_DWIDTH - 1:0] in5= 'z,
    input logic [`AVERY_MUX_DWIDTH - 1:0] in6= 'z,
    input logic [`AVERY_MUX_DWIDTH - 1:0] in7= 'z);
    automatic logic [`AVERY_MUX_DWIDTH - 1:0] out2= 'z;

    case (sw2)
    0: out2= in0;
    1: out2= in1;
    2: out2= in2;
    3: out2= in3;
    4: out2= in4;
    5: out2= in4;
    6: out2= in4;
    7: out2= in4;
    endcase
    return out2;
endfunction

function int avery_gcd(
    input int num2,
    input int num3);
    automatic int max2= avery_max(num2, num3);
    automatic int min2= avery_min(num2, num3);
    if (min2 == 0) return max2;
    else if (max2 % min2 == 0) return min2;
    else begin
	    int tmp2;
	do begin
	    tmp2= max2 % min2;
	    max2= min2;
	    min2= tmp2;
	end while (max2 && min2);
	return max2;
    end
endfunction

function int avery_lcm(
    input int num2, 
    input int num3);
    return (num2 * num3 / avery_gcd(num2, num3));
endfunction

function automatic bit[31:0] avery_abs(int a);
    if (a < 0)
        return -a;
    else
        return a;
endfunction

// Return bit position to the next upper dword boundary.
function avery_u32 avery_dw_boundary(avery_u32 offset);
    return (offset/32 + 1) * 32;
endfunction

// Round up to dwords
function automatic bit[31:0]  avery_round_to_dw(bit[31:0] num_bytes);
    return (num_bytes >> 2) + (num_bytes[1:0] > 0); 
endfunction

// Pack bytes into dwords. Note: the "to[$]" is flushed at beginning!!
function automatic void avery_pack_bytes(
        ref    bit[ 7:0]  from[$],
        output bit[31:0]  to[$],
        input  bit[31:0]  num_bytes    = -1,   // -1 means to the end from start_offset
        input  bit[31:0]  start_offset = 0);
    bit[31:0]  dwlen;

    dwlen = 0;
    if (num_bytes == -1)
        num_bytes = from.size() - start_offset;
    assert((num_bytes + start_offset) <= from.size())
    else begin
        $display("avery_pack_bytes:: caller error");
        $finish;
    end

    dwlen = avery_round_to_dw(num_bytes);
    for (int i= 0; i < dwlen; i ++) begin
        bit[3:0][7:0] dw;
        // workaround: Memory index truncation(start_offset)
        dw[0] = (start_offset >= from.size()) ? 8'hee : from[start_offset[31:0]];  start_offset++;
        dw[1] = (start_offset >= from.size()) ? 8'hee : from[start_offset[31:0]];  start_offset++;
        dw[2] = (start_offset >= from.size()) ? 8'hee : from[start_offset[31:0]];  start_offset++;
        dw[3] = (start_offset >= from.size()) ? 8'hee : from[start_offset[31:0]];  start_offset++;
        to.push_back(dw);
    end
endfunction

// Pack bytes into dwords array.
function automatic void avery_pack_bytes_arr(
        ref    bit[ 7:0]  from[$],
        ref    bit[31:0]  to[],
        input  bit[31:0]  num_bytes    = -1,   // -1 means to the end from start_offset
        input  bit[31:0]  start_offset = 0
    );
    bit[31:0]   dwlen;

    dwlen = 0;
    if (num_bytes == -1)
        num_bytes = from.size() - start_offset;
    assert((num_bytes + start_offset) <= from.size())
    else begin
        $display("avery_pack_bytes:: caller error");
        $finish;
    end

    dwlen = avery_round_to_dw(num_bytes);
    to = new[dwlen];
    for (int i= 0; i < dwlen; i ++) begin
        bit[3:0][7:0] dw;
        // workaround: Memory index truncation(start_offset)
        dw[0] = (start_offset >= from.size()) ? 8'hee : from[start_offset[31:0]];  start_offset++;
        dw[1] = (start_offset >= from.size()) ? 8'hee : from[start_offset[31:0]];  start_offset++;
        dw[2] = (start_offset >= from.size()) ? 8'hee : from[start_offset[31:0]];  start_offset++;
        dw[3] = (start_offset >= from.size()) ? 8'hee : from[start_offset[31:0]];  start_offset++;
        to[i] = dw;
    end
endfunction

// Queue to array for 32-bit data
function automatic void avery_q2a(ref bit[31:0] from[$], ref bit[31:0] to[]);
    to = new[from.size()];
    foreach(from[i])
        to[i] = from[i];
endfunction

// Be aware: bq is flushed first!! dq[i] is little-endian.
function automatic void avery_dwords_to_bytes(ref bit[31:0] dq[$], ref bit[7:0] bq[$]);
    bit[3:0][7:0] a;
    bq.delete();
    foreach(dq[i]) begin
        a = dq[i];
        bq.push_back(a[0]);
        bq.push_back(a[1]);
        bq.push_back(a[2]);
        bq.push_back(a[3]);
    end
    if ((dq.size * 4) != bq.size) begin
        $display("Caught a simulator bug: %0d vs %0d", dq.size * 4, bq.size); 
        `avery_finish;
    end
endfunction

// dq will be emptied first. dq[i] is little-endian.
function automatic void avery_bytes_to_dwords(ref bit[7:0] bq[$], ref bit[31:0] dq[$]);
    bit[3:0][7:0] a;
    int n = bq.size / 4;
    dq.delete();
    for (int i = 0; i < n; i++) begin
        a[0] = bq[4*i+0];
        a[1] = bq[4*i+1];
        a[2] = bq[4*i+2];
        a[3] = bq[4*i+3];
        dq.push_back(a);
    end
    // pad 0 at the end
    if (bq.size % 4) begin
	a = 0;
	a[0] = bq[n*4];
	if (bq.size > (n*4+1)) a[1] = bq[n*4+1];
	if (bq.size > (n*4+2)) a[2] = bq[n*4+2];
	dq.push_back(a);
    end
endfunction

function automatic void avery_ba2va(ref bit[7:0] ba[], ref bit[31:0] da[]);
    bit[3:0][7:0] a;
    int n = ba.size / 4;
    if (ba.size % 4) 
	da = new[n+1];
    else
	da = new[n];
    for (int i = 0; i < n; i++) begin
        a[0] = ba[4*i+0];
        a[1] = ba[4*i+1];
        a[2] = ba[4*i+2];
        a[3] = ba[4*i+3];
        da[i] = a;
    end
    // pad 0 at the end
    if (ba.size % 4) begin
	a = 0;
	a[0] = ba[n*4];
	if (ba.size > (n*4+1)) a[1] = ba[n*4+1];
	if (ba.size > (n*4+2)) a[2] = ba[n*4+2];
	da[n] = a;
    end
endfunction

// "to[$]" is flushed at beginning.
function automatic void avery_unpack_dwords(
        ref  bit[31:0]  from[$], // Queue
        ref  bit[ 7:0]  to[$]);
    bit[3:0][7:0] dw;
    to.delete();
    foreach(from[i]) begin
        dw = from[i];
        to.push_back(dw[0]);
        to.push_back(dw[1]);
        to.push_back(dw[2]);
        to.push_back(dw[3]);
    end
endfunction

// "to[$]" is flushed at beginning.
function automatic void avery_unpack_dwords_arr(
        ref  bit[31:0]  from[],  // Array
        ref  bit[ 7:0]  to[$]);
    bit[3:0][7:0] dw;
    to.delete();
    foreach(from[i]) begin
        dw = from[i];
        to.push_back(dw[0]);
        to.push_back(dw[1]);
        to.push_back(dw[2]);
        to.push_back(dw[3]);
    end
endfunction

// dword array to byte array
function automatic void avery_va2ba (
        ref  bit[31:0]  from[],  // Array
        ref  bit[ 7:0]  to[]);
    bit[3:0][7:0] dw;
    to = new[from.size * 4];
    foreach(from[i]) begin
        dw = from[i];
        to[4*i+0] = dw[0];
        to[4*i+1] = dw[1];
        to[4*i+2] = dw[2];
        to[4*i+3] = dw[3];
    end
endfunction

// see also avery_va2ba(). This one with extra byte enables.
function automatic void avery_va2ba_be(
        ref  bit[31:0]  from[],
        ref  bit[ 7:0]  to[],
        input bit[3:0]  first_be,
        input bit[3:0]  last_be
    );
    bit[7:0] bq[$];
    avery_unpack_dwords_arr(from, bq);
    casex (first_be)
        4'b???1: begin end
        4'b??10: repeat(1) bq.delete(0);
        4'b?100: repeat(2) bq.delete(0);
        4'b1000: repeat(3) bq.delete(0);
        4'b0000: repeat(4) bq.delete(0);
    endcase

    if (from.size ==  1) begin
        // single dword
        casex (first_be)
            4'b1???: begin end
            4'b01??: repeat(1) void'(bq.pop_back());
            4'b001?: repeat(2) void'(bq.pop_back());
            4'b0001: repeat(3) void'(bq.pop_back());
            4'b0000: repeat(4) void'(bq.pop_back());
        endcase
    end else if (from.size > 1) begin
        casex (last_be)
            4'b1???: begin end
            4'b01??: repeat(1) void'(bq.pop_back());
            4'b001?: repeat(2) void'(bq.pop_back());
            4'b0001: repeat(3) void'(bq.pop_back());
            4'b0000: repeat(4) void'(bq.pop_back());
        endcase
    end

    to = new[bq.size];
    foreach (to[i])
        to[i] = bq[i];
endfunction


// Return dword-aligned address and size.
function void avery_align_addr(
        input  bit[63:0] addr,     
        input  bit[63:0] n_bytes,
        output bit[63:0] out_addr,
        output bit[63:0] n_dwords
    );
    automatic bit[64:0] end_addr  = addr + n_bytes;
    out_addr = addr;
    out_addr[1:0] = 0;
    n_dwords = avery_multiple_of(end_addr - out_addr, 4);
endfunction


function automatic avery_u32 avery_get_device_id();
    static avery_u32 id_g = 0;
    id_g ++;
    return (id_g);
endfunction

function automatic avery_u32 avery_get_data_id();
    static avery_u32 data_id_g = 0;
    data_id_g ++;
    return (data_id_g);
endfunction


function automatic avery_u32 apqi_get_nvm_id();
    static avery_u32 nvm_id_g = 0;
    nvm_id_g ++;
    return (nvm_id_g);
endfunction

// Return n if it is n's power of 2; otherwise return -1 
// Can be used to detect is_power_of_2
function automatic int avery_power_of_two(bit[63:0] v); // NC bug: v >> 1 is not same
    int power2;
    power2 = 0;
    while (v > 0) begin 
        if (v[0]) begin
            if (v[63:1] != 0)
                power2 = -1;
            break;
        end else begin
            power2 ++;
            v = v >> 1;
        end 
    end
    return power2;
endfunction

// Return 1 if value is power of two.
function bit avery_is_power_of_two(bit[63:0] v);
    return avery_power_of_two(v) != -1;
endfunction

// "a" is multiple of "b" and round up.
function automatic bit[63:0] avery_multiple_of(bit[63:0] a, bit[63:0] b);
    if (b == 0) begin
        $display("%m: avery_multiple_of: b is 0");
        `avery_finish;
    end
    return (a / b) + ((a % b) > 0);
endfunction

// round "a" up to the next boundary.
function automatic bit[63:0] avery_round_up(bit[63:0] a, bit[63:0] boundary);
    if ( boundary == 0) begin
        $display("%m: avery_multiple_of: boundary is 0");
        `avery_finish;
    end
    if ((a % boundary) > 0)
       return (a / boundary) * boundary + boundary; // That is: a + boundary
    else
       return  a;
endfunction

// return the value of 2 to the power of "v"
function automatic bit[63:0] avery_two_to_power_of(bit[7:0] v);
    return (64'h1 << v);
endfunction

// return 1 if "a" is multiple of "b", else return 0
function automatic bit avery_multiple_check(bit[63:0] a, bit[63:0] b);
    $display("avery_multiple_check: is obsoleted. Use avery_is_multiple() instead");
    return avery_is_multiple(a, b);
endfunction

// return 1 if "a" is multiple of "b", else return 0
function automatic bit avery_is_multiple(bit[63:0] a, bit[63:0] b);
    if (b == 0) return 1;
    if ((a % b) == 0)
        return 1;
    else
        return 0; 
endfunction

// Return # of bytes to next page boundary. page_size should be in power of 2.
function avery_u64 avery_distance_to_page (avery_u64 page_size, avery_u64 addr);
    return page_size - (addr & (page_size - 1));
endfunction


// Return offset mask within a page.
function bit[63:0] avery_offset_mask(bit[63:0] page_size);
    return (page_size - 1);
endfunction

function bit[63:0] avery_page_mask(bit[63:0] page_size);
    return ~(page_size - 1);
endfunction

// Return the offset within a page.
function bit[63:0] avery_page_offset(bit[63:0] addr, bit[63:0] page_size);
    return addr & (page_size - 1);
endfunction

function bit[63:0] avery_page_align(bit[63:0] addr, bit[63:0] page_size);
    return addr & ~(page_size - 1);
endfunction

function bit[63:0] avery_random64 (bit[63:0] a, bit[63:0] b);
    return {$urandom_range(a[63:32], b[63:32]), $urandom_range(a[31:0], b[31:0])};
endfunction

function automatic string avery_print_dw_array(ref bit[31:0] da[], input int len=16, string prefix="", bit line_break=1);
    string s = prefix;
    if (da.size == 0)
        return "";
    foreach(da[i]) if (i < len) begin
        if (i % 16 == 0 && i)
            s = {s, "\n", prefix};
        else if (i % 8 == 0 && i)
            s = {s, "   "};
        $sformat(s, "%s %h", s, da[i]);
    end
    if (line_break)
        return {s, "\n"};
    else
        return s;
endfunction

function automatic string avery_print_dw_q(ref bit[31:0] dq[$], input int len=16, string prefix="", bit line_break=1);
    string s = prefix;
    if (dq.size == 0)
        return "";
    foreach(dq[i]) if (i < len) begin
        if (i % 16 == 0 && i)
            s = {s, "\n", prefix};
        else if (i % 8 == 0 && i)
            s = {s, "   "};
        $sformat(s, "%s %h", s, dq[i]);
    end
    if (line_break)
        return {s, "\n"};
    else
        return s;
endfunction

function automatic string avery_print_u8(ref bit[7:0] b[$], input bit[31:0] max = -1, string prefix="", bit in_dword = 0);
    string s = prefix;
    foreach(b[i]) begin
        if (i >= max)
            break;
        if (in_dword) begin
            if (i && i%16 == 0)
                s = {s, $sformatf("\n%s%h", prefix, b[i])};
            else if (i && i%4 == 0)
                s = {s, $sformatf(" %h", b[i])};
            else
                s = {s, $sformatf("%h", b[i])};
        end else begin
            if (i % 16 == 0 && i)
                s = {s, "\n", prefix};
            else if (i % 8 == 0 && i)
                s = {s, "   "};
            $sformat(s, "%s %h", s, b[i]);
        end
    end
    if (b.size > max)
        s = {s, " ......"};
    return {s, "\n"};
endfunction

function automatic string avery_print_bytes(ref byte b[$], input bit[31:0] max = -1, string prefix="", bit in_dword = 0);
    string s = prefix;
    foreach(b[i]) begin
        if (i >= max)
            break;
        if (in_dword) begin
            if (i && i%16 == 0)
                s = {s, $sformatf("\n%s%h", prefix, b[i])};
            else if (i && i%4 == 0)
                s = {s, $sformatf(" %h", b[i])};
            else
                s = {s, $sformatf("%h", b[i])};
        end else begin
            if (i % 16 == 0 && i)
                s = {s, "\n", prefix};
            else if (i % 8 == 0 && i)
                s = {s, "   "};
            $sformat(s, "%s %h", s, b[i]);
        end
    end
    if (b.size > max)
        s = {s, " ......"};
    return {s, "\n"};
endfunction

function bit[31:0] avery_swap_endian (bit[31:0] v);
    return {v[7:0], v[15:8], v[23:16], v[31:24]};
endfunction

function bit[15:0][7:0] avery_swap_endian_128 (bit[15:0][7:0] v);
    foreach (v[i])
	avery_swap_endian_128[15-i] = v[i];
endfunction


// "to[]" is deleted at beginning. dword queue to byte array
function automatic void avery_dq_2_ba(
        ref bit[31:0]  from[$],
        ref bit[ 7:0]  to[]);
    bit[3:0][7:0] dw;
    to = new[from.size * 4];
    foreach(from[i]) begin
        dw = from[i];
        to[4*i+0] = dw[0];
        to[4*i+1] = dw[1];
        to[4*i+2] = dw[2];
        to[4*i+3] = dw[3];
    end
endfunction


// --------------------- Classes -------------------------------

class avery_hash_list #(type T = int, type TKEY = int);
    T  list[$];
    T  hash[TKEY];

    function new();
    endfunction

    function void push_back(TKEY key, T v);
        if (!hash.exists(key)) begin
            list.push_back(v);
            hash[key] = v;
        end
    endfunction

    function void push_front(TKEY key, T v);
        if (!hash.exists(key)) begin
            list.push_front(v);
            hash[key] = v;
        end
    endfunction

    function T lookup(TKEY key);
        if (hash.exists(key))
            return (hash[key]);
        else
            return null;
    endfunction

    function void insert(TKEY key, T v);
        push_front(key, v);
    endfunction

    function void delete_all();
        list.delete();
        hash.delete();
    endfunction

    // This operation is expensive O(n).
    function void delete(TKEY key);
        if (hash.exists(key)) begin
            T v = hash[key];
            foreach(list[i]) begin
                if (v == list[i])
                    list.delete(i);
            end
            hash.delete(key);
        end 
    endfunction
endclass

class avery_assertion_item;
    avery_severity severity;
    string         id;
    string         description;
    int            cvg_cnt;     // # of times this assertion is triggerred
    bit            mask;
    int            fire_cnt;    // # of times this assertion is violated

    function new(avery_severity severity, string id, string des, int cvg_cnt = 0);
        this.severity    = severity;
        this.id          = id;
        this.description = des;
        this.cvg_cnt     = cvg_cnt;
        this.mask        = 0;
        this.fire_cnt    = 0;
    endfunction

    function string sprint(int verbosity = 0);
        string s;
        $sformat(s, "ID  : %s\nDesc: %s\n", id, description);
        return s;
    endfunction
endclass

// Class: avery_log_callbacks
//   This callback class is used to control how the <avery_log> object
//   reports a message.
virtual class avery_log_callbacks;

    // Function: assertion_msg_cb
    // Right after an assertion violation is detected. Use this method to lower
    // or increase the severity of an assertion.
    //
    //   is_disable - 1 to disable printing the msg
    virtual function void assertion_msg_cb(
                        input string msg,
                        inout bit is_disable,
                        ref avery_assertion_item item
                    );
        return;
    endfunction

    // Function: error_msg_cb
    // Right after an error message is encountered.
    //
    //   is_disable - 1 to disable printing the msg
    virtual function void error_msg_cb(
                        input string msg,
                        inout bit is_disable 
                    );
        return;
    endfunction

    // Function: fatal_msg_cb
    // Right after a fatal message is encountered.
    //
    //   is_disable - 1 to disable printing the msg
    virtual function void fatal_msg_cb(
                        input string msg,
                        inout bit is_disable
                    );
        return;
    endfunction

endclass

// Class: avery_user_data
//    Do not use by Avery. Shall be used by user.
//  avery_data_base has a handler for this class. User can extend this class and
//  instance the extended class, then save it to avery_data_base::user_data.
class avery_user_data;
    bit       u1;
    bit[15:0] u16;
    bit[31:0] u32;
    string    str;
endclass

// Class: avery_data_base
//   This is the base data class for all Avery's data objects.
class avery_data_base
    `ifdef AVERY_OVM
        extends ovm_sequence_item
    `elsif AVERY_UVM
        extends uvm_sequence_item
    `elsif AVERY_VMM
        extends vmm_data
    `endif
    ;
    string           name;
    int              avy_id;    // VAR: universally unique
    avery_data_base  up;        // VAR: the generic parent handle if available
    avery_data_base  down;      // VAR: the generic kid handle if available
    avery_user_data  user_data; // VAR: place holder for user data
    int              avy_id_orig = -1;
        
    // Make it const to prevent accidental overwritten.
    // Create your own log member if you need to overwrite the log.
    const static avery_log log = new("avery_data_base::log");
    avery_log  unbaselog = log;

    `ifdef AVERY_VMM
        static vmm_log vmmlog = new("avery_data_base", "class");
    `endif
    
    `ifdef AVERY_OVM
        `ovm_object_utils( avery_data_base )
    `endif           
    `ifdef AVERY_UVM
        bit blocking_item_done = 0; // 1: only send item_done() after data item is completed
        `uvm_object_utils( avery_data_base )
    `endif           

    function new(string name = "avery_data_base");
        `ifdef AVERY_VMM
            super.new(this.vmmlog);
            log.vmmlog = vmmlog;
        `endif
	`ifdef AVERY_UVM
	    super.new(name);
	`endif
        this.name = name;
        this.avy_id = avery_get_data_id();
    endfunction
        
    virtual function string sprint(int verbosity = 0, string prefix = "");
        return "";
    endfunction

    `ifdef AVERY_VMM
    function vmm_data copy(vmm_data to = null);
    `else
    function avery_data_base copy(avery_data_base to = null);
    `endif
        avery_data_base to2;
        if (to == null)
            to2 = new();
        else if (!$cast(to2, to)) begin
            log.fatal($sformatf("%M: input is not avery_data_base type"));
            return null;
        end
        to2.up          = up;
        to2.down        = down;
        to2.avy_id_orig = avy_id;
        to2.user_data   = user_data; // copy handle only
        `ifdef AVERY_VMM
            void'(super.copy(to2));
        `endif
        return to2;
    endfunction

    virtual function string sprint_user_str();
        if (user_data != null && user_data.str != "")
            return user_data.str;
        else
            return "";
    endfunction

    virtual function void replace_user_str(string msg);
        if (user_data == null)
            user_data = new();
        user_data.str = {"(", msg, ")"};
    endfunction

    virtual function void append_user_str(string msg);
        if (user_data == null)
            user_data = new();
        user_data.str = {user_data.str, "(", msg, ")"};
    endfunction

    `ifndef AVERY_UVM
    virtual function string get_name();
        return name;
    endfunction
    `endif

endclass

class avery_pure_component
    `ifdef AVERY_UVM
        extends uvm_component
    `endif
    ;

    `ifdef AVERY_UVM
        `uvm_component_utils_begin(avery_pure_component)
        `uvm_component_utils_end
    `else
        string               name;
        avery_pure_component parent;
    `endif

    int        avy_id;
    static bit _flushed = 0;

    function new(
        string name,
    `ifdef AVERY_UVM
        uvm_component        parent = null
    `else
        avery_pure_component parent = null
    `endif
        );
        `ifdef AVERY_UVM
            super.new(name, parent);
            avy_id = avery_get_device_id();
        `else
            this.name = name;
            this.parent = parent;
        `endif
    endfunction

    `ifndef AVERY_UVM
    virtual function string get_name();
        return name;
    endfunction
    `endif

endclass


// A generic driver
class avery_component
    `ifdef AVERY_VMM
        extends vmm_xactor
    `elsif AVERY_OVM
        extends ovm_driver #(avery_data_base)
        // extends ovm_component
    `elsif AVERY_UVM
        extends uvm_driver #(avery_data_base)
        // extends uvm_component
    `else
        extends avery_pure_component
    `endif
    ;

    `ifdef AVERY_OVM
        `ovm_component_utils_begin(avery_component)
        `ovm_component_utils_end
    `elsif AVERY_UVM
        `uvm_component_utils_begin(avery_component)
        `uvm_component_utils_end
    `else
        string          inst;
        avery_component parent;
    `endif

    avery_log log = avery_pkg_log; // extended class may overwrite this object
    int       avy_id;
    static bit avery_dump_all = 0;
    static bit _flushed = 0;

    function new( string   name,
                  `avery_xvm_parent);
        `ifdef AVERY_OVM
            super.new(name, parent);
        `elsif AVERY_UVM
            super.new(name, parent);
        `elsif AVERY_VMM
            super.new(name, inst, stream_id);
        `else
            super.new(name, parent);
        `endif
        this.avy_id = avery_get_device_id();
        if (avery_dump_all == 0 && $test$plusargs("avery_dump_all"))
            avery_dump_all = 1;
        /* Modelsim limitation: vsim-8385. Commented out these code:
        if (_flushed == 0) begin
            _flushed = 1;
            fork
                if ($test$plusargs("avery_flush_buf")) begin
                    forever #10us $fflush();
                end
            join_none
        end
        */
    endfunction

    `ifndef AVERY_UVM
    virtual function string get_name();
        return name;
    endfunction
    `endif

    // return 0 if there is error, 1 ok
    virtual function bit check_result( int verbosity = 0 );
        return 1;
    endfunction

    virtual task end_sim_cb(string msg = "");
        return;
    endtask

    virtual function string sprint(int verbosity = 0, string prefix = "");
        `ifdef AVERY_UVM
            return get_name();
        `else
            return name;
        `endif
    endfunction

    static int _file;
    virtual function void aprint(int file, ref string msg, input int id = 0);
        if (avery_dump_all == 0) return;
        if (_file == 0)
            _file = $fopen("avery_adb.log", "w");
        $fdisplay(_file, "\\{0x%0h:%s\\}", file, msg);
    endfunction

    virtual function void aprint_set_file(int file, string filename);
        if (avery_dump_all == 0) return;
        if (_file == 0)
            _file = $fopen("avery_adb.log", "w");
        $fdisplay(_file, "\\{0x%0h=\"%s\"\\}", file, filename);
    endfunction

endclass

// Avery queuing layer
class avery_qlayer_base extends avery_component;
    function new(string name, `avery_xvm_parent);
        super.new(name, parent);
    endfunction
endclass

class avery_mem_model #(type T = byte, type T2 = bit[63:0]);
    local string     inst_name;
    local avery_log  log;
    local T          mem [T2];

    function new(string name, avery_log log = null);
        this.inst_name = name;
        this.log = log;
        if (log == null)
            log = new("mem_model");
    endfunction

    function bit exists(T2 addr);
        int exist2;
        exist2= mem.exists(addr);
        return exist2[0];
    endfunction

    function T read(T2 addr);                                                                                                                                                                 
        if (!mem.exists(addr))
            return 'hee;
        else
            return mem[addr];
    endfunction

    function void write(T2 addr, T data2);
        mem[addr] = data2;
    endfunction

    function bit[63:0] size();
        return mem.size();
    endfunction

    function void delete(T2 addr);
        mem.delete(addr);
    endfunction

    function void delete_all();
        mem.delete();
    endfunction
endclass

class avery_seq_base extends
    `ifdef AVERY_UVM
        uvm_sequence #(avery_data_base);
    `else
        avery_data_base;
    `endif
 
    virtual task run();
    `ifdef AVERY_UVM
        `uvm_fatal("AVY_FATAL", $sformatf("%M: virtual task run() must be implemented"))
    `else
        log.fatal($sformatf("%M: virtual task run() must be implemented"));
    `endif
    endtask 
endclass

//`include "avery_log.sv"
`ifndef avery_log_sv
`define avery_log_sv

/* Extends from component so we can use hierarchical access in UVM.
 
  NOTE that a better class for this usage is avery_param_log. Please use that
  unless you have a good reason for discussion with Chilai */
class avery_log extends
    `ifdef AVERY_LOG_NOT_COMPONENT
	// To avoid limitation that uvm_component must be created during build_phase().
        // However, the string based accessed will no longer work when log is not a uvm_component: 
	//     uvm_config_db#(bit)::set(this, "env0.bfm.log*" , "enable_tl_tracker"  , 1);
        // To solution is to use API or direct access like this:
        //       env0.bfm.log.enable_tl_tracker = 1;
        //       or API if available: env0.bfm.port_set_tracker(-1, "tl", 1);
	avery_data_base; 
    `else
	avery_pure_component;
    `endif
    string name;
    string instance_name;
    string version_str;

    bit info_en  = 1;       // enable AVY_INFO  message
    bit warn_en  = 1;       // enable AVY_WARN  message
    bit exp_en   = 1;       // enable AVY_EXPECT message
    bit error_en = 1;       // enable AVY_ERROR  message
    bit fatal_en = 1;       // enable AVY_FATAL message

    static int runlog = 32'h8000_0001; // STDOUT
    `ifdef AVERY_VMM
        vmm_log vmmlog;
    `endif

    // test result         
           int      num_violations        = 0;
    static int      global_num_violations = 0; // shared by all instances
           bit      fail_flag             = 0;
    static bit      global_fail_flag      = 0;
    static bit [31:0] emu_abnormal_trigger_g= 0; // reverse a bit for an abnormal condition to trigger EMU debugger

    /* bit0 if 1, due to EDB's monitor list have some value change
       bit1 if 1, due to EDB's monitor equation is true
       bit2 if 1, IRQ at SV level */
    static bit [2:0] emu_monitor_trig_g = 0;
   
    extern function new(string name, `avery_xvm_parent);

    extern virtual function void error       (string msg = "", avery_data_base f=null);
    extern virtual function void fatal       (string msg, string msg2 = "");
    extern virtual function void info        (string msg="", int line_breaks_prefix=0)             ;
    extern virtual function void warn        (string msg="");
    extern virtual function void asst        (string idname, string msg="", avery_data_base f=null);
    extern virtual function void usage       (string msg, int is_finish=1);

    virtual function void trigger            (string idname); 
        error($sformatf("%m: virtual method is not implemented"));
    endfunction

    virtual function void set_global_severity(string idname, avery_severity v) ;
        error($sformatf("%m: virtual method is not implemented"));
    endfunction

    virtual function void set_severity       (string idname, avery_severity v) ;
        error($sformatf("%m: virtual method is not implemented"));
    endfunction

    virtual function bit  is_fired           (string idname );
        error($sformatf("%m: virtual method is not implemented"));
        return 0;
    endfunction // check if the assertion has been fired

    virtual function void coverage_rpt       (string filename="");
        error($sformatf("%m: virtual method is not implemented"));
    endfunction

    // Obsolete, use intern() instead. 
    virtual function void internal           (string msg, bit is_abort = 1, avery_data_base f=null);
        if (f != null)
            $fdisplay(runlog, "AVY_INTERN: %s@%0t  %s. Caused by: %s", instance_name, $time, msg, f.sprint(2));
        else
            $fdisplay(runlog, "AVY_INTERN: %s@%0t  %s", instance_name, $time, msg);
        if (is_abort) `avery_finish;
    endfunction

    // Same as internal.
    virtual function void intern (string msg, bit is_abort = 1, avery_data_base f=null);
        if (f)
            msg = $sformatf("AVY_INTERN: %s@%0t  %s. Caused by: %s", instance_name, $time, msg, f.sprint(2));
        else
            msg = $sformatf("AVY_INTERN: %s@%0t  %s", instance_name, $time, msg);
        `ifdef AVERY_UVM
            `uvm_fatal("AVY_INTERN", msg);
        `else
            $fdisplay(runlog, "%s", msg);
        `endif
        if (is_abort) `avery_finish;
    endfunction

    virtual function void debug              (string msg);
        $fdisplay(runlog, "AVY_DBG: %s@%0t  %s", instance_name, $time, msg);
    endfunction

    virtual function void spec_error(string msg);
        error($sformatf("%m: virtual method is not implemented"));
    endfunction

    // scope message related
    virtual function void sdebug(string scope, string msg);
        error($sformatf("%m: virtual method is not implemented"));
    endfunction

    virtual function void sinfo(string scope, string msg);
        error($sformatf("%m: virtual method is not implemented"));
    endfunction

    virtual function void swarning(string scope, string msg);
        error($sformatf("%m: virtual method is not implemented"));
    endfunction

    virtual function void serror(string scope, string msg);
        error($sformatf("%m: virtual method is not implemented"));
    endfunction

    virtual function void susage(string scope, string msg, bit is_abort = 0);
        error($sformatf("%m: virtual method is not implemented"));
    endfunction

    virtual function void sstep(string scope, string msg);
        error($sformatf("%m: virtual method is not implemented"));
    endfunction

    function void todo( string msg, int is_finish = 0);
        $fdisplay(runlog, "AVY_TODO: %s@%0t  %s", instance_name, $time, msg);
        if (is_finish)
            `avery_finish;
    endfunction

    function bit runlog_is_stdout();
        return runlog == 32'h8000_0001;
    endfunction

`ifdef AVERY_VMM
    `define AVERY_LOG_CALLBACK(T, method) `vmm_callback(T, method)
`else
    `define AVERY_LOG_CALLBACK(T, method) \
    do foreach (Q_registered_cb[i]) begin \
        T obj; \
        if ($cast(obj, Q_registered_cb[i])) obj.method; \
    end while (0); \
    do foreach (Q_registered_cb_global[i]) begin \
        T obj; \
        if ($cast(obj, Q_registered_cb_global[i])) obj.method; \
    end while (0)

    protected avery_log_callbacks Q_registered_cb[$];
    protected static avery_log_callbacks Q_registered_cb_global[$];

    function void append_callback(input avery_log_callbacks cb);
        Q_registered_cb.push_back(cb);
    endfunction
`endif



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
L1nE1s7U2tZnK2qJApAy1irh6VX6Pi9bgyxRTo+9ZBXuKeTa7dadSmyIy25W4/ae
dsxk7qU4HvaCg7egB9eJEWjbVGyijF4BoXce3sAW1iQAic8RBPanQmdi9lvHMxKU
0KH2sMMfM1nd9ysdfMoqTMfDF8+j0qsqLeTIqA3fVEg=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
0x0aYCACmlxsOPx95a9qZmxVin54qSmKYCXvZKove0p0TiStP2FaUS8lq1Icd5G+
G5d7TV8kx4b6y2JcVdpzfaiLSfBUC1ivHU/9VA3BykHMFIJ6BMzlYJiM7uSzMyJ/
QxxyIsX1gueS0yCPfdZKuthyxPpQk/Q9yAd/GkFsVtY=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
p006AzmWNovYTCM2ctND9BENxAcOvJursJAH93PLtkafAsNFuueznfLaMbG/8uQS
yV1vHGy1v0tSXwAV2f3KBg==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
opPFuU9OKCUSRt76iM+LnbykBQgHOgTNHth/eXN2uuqE7hvEsge9f0pqKis2O/Dy
woGOXTA+1ShlQOuwERAAiwWrWKOWM7omeXVG+yhdPKU6LnfNcCMCON7qrXDEoxNS
EKxP8NcB/VG06Tte3LNB+eoYniZO0gcDvA2F+/T+jE9sSv+B6bb/aP1CNGg4Xpa3
xY7AawCc+IGMPqRW4OZ9qyyXlNPBY/4GH4cCIgyNOHHmjX0fiF2MsGHxp0yezlah
9+zVsl2mMfvHWpv+F42SwL+HZ/vkLGpe84+ibyog1N0YO8tUhocAbXUXVCU6q2JH
2dCsidkZvarciscuYh1OPg==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
uyJPGMb/Rlkyx6K+EGJLuWEm774jCao1ZyI8Yl+XEIeX7LekIYqXanp6CZNCzEuP
IxPndLmxiKmgoR0E7CRv8U4PoTqkc9nv7lYe00zQO7R7gav0k0tt6EwB049t72fr
rzFHvPKfSHbYgBabkTbnbFEFw/vPHJRJ9F9CcSv24iI=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
ptXjRI2h8mcy8j7aIYjjJ3YQDoiwz2Qy/bEgIcB4SbnYS9y1ZAUPadIJ1Nhdx1ZE
jSTXZvPxh/bqs1ygYAlwI1tLJIXZsb/DzOaP/QuYks8gXeGHW+MfMR4bFUipJRD/
d/3VawpZMxPhkKksmcaAZNQhv5xbxPjIpBFRobuEWKU5e4V7ZKI8oLl3W7I95/lA
fxNkpUXc2ZtFwp1hNjhX/lwuT+ko0YOeIXGQu89He6NCFEDMqTVnFDGbQXqrivGG
gu/fbszmUlJn4GdmYyvmrN2D9hh6k30kzUWSb+OGuipPPxkSjvjWExhNCDPj3wO/
oXhPPfihKHZK2nBRWcyFzg==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
bq5eGrKOv0u0qCiuVLqVO0AacO4+lQ15Do8xvQErNJjdLd8KDTpl+5HMiyYUd0xh
/dZp9tbY8BKkAjqG8egwu1Ey/+cNASa/kjFrAoytd6GxzabZMIm78JqWmhZvNW81
CyP2/KCmwgoUev2PnGkdYDN9SQVq/+tuehOn/5QfG5JWjS1sX1myUjrIZlBiHNKR
HlCWm482Jo76U3PBv0WvNNMMI4YQfYRS46WYeRAS+nuYpgGrxcbMl2X4omosxt4b
HrS1prrZiLSD7IqBu67ydmijLBbKozOd+SNkjV6f30cF9gBmXShAItP+d5yc6OIT
ZuQ3YvdhC0bJ3ruIiddPsA==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 6096 )
`pragma protect data_block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`pragma protect end_protected

endclass



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
O9HxUHC1HadEtHJ4bt9bWGd0UxeZDQzDr+AzmavMsNg1vM5IQwn88Z0cHnm7MgS2
rLjkzrV0sGtDYmT8WVDjYacjHVzSrRG15B9CZHmpVdF4OI/uIErHCa6aEIvtUCph
bLW7L3A0sEIMvtuL88kL6aEeLEaOY+hfX/rGi3P3APs=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
LlXGlJcyJN84BDRFv8J4CfwOzCuTML183GspJt4qzCGLRpevz5KXAGgS1wg71p0h
gdXdGVLmAFMqHJ5LWQy6cfg123Bo1DUhfFnLdVG2ThV7M1uMbMzEtmQuFFBsSvDj
dozYJ8roWZ0+IPIpjB2r42XGHeTiqAL4TLJgubGglm4=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
LxV5hj/9UVJSOTzm8/QVlnhqD5L2dBighswRRFq4Ccbm7VY2k97GSYRLorRuLAEC
yKU7FhIp/YhWhHfbF9vgpg==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
KlbNzl4arytdxa/BGG9jtCFXrta0IqDCGXqFRE6eP0HnhCoRKgevDXzNhU1NplEc
r4igKFAKe4mTRWmoHl5rkghwUfyUnRZP9z5DSg0eu4ME3iVSFnUIKyZAiCZqDCXO
vSrXnuhGRijKL16kt86o3FSK0kywCQUXEM72j5QSz9ODmnRFXD49fZIx7iWBcHOu
v/tebaRkXmSyP1Y4UZoknz/TQALUsH1lhZRcALuIwu77LLH+KMLuSKGYL2UkaGKs
Cq4Em+SsZaQbccirTHzJuS/6THbDeKRrsfn2/csMLYDmj+Sk3vooWM67pj11YaAf
ehr29o58wj90YCksOg8w6g==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
j8S/bU+J1TonctZUhNgHhRoKw21EL4EBXlkYdZYMKanPVosla/XugwGezfRkzWwp
UVKbTVG42PhhgyiG9uhGnhFPagxOuMw4cs3Rp/HL9UtMH0gyOTPCn0wDfOBivGij
GKWLm5iLGBJrOyAh+L/K8u3QxnN4FJ5/1K/bse1HKCY=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
GWyBzYtjA1twYRsVpSHE+M3Exe788itYtFTJsbSLq/K5nh7xQEpKDIqifB0vwZ7W
FshSzXhIVAhlo6/OM17sts9MWP89jgw7IgBK19JE6eocJKSAYoDnmAmko/1Sy+F+
xVKq28uoebx9WbKgBzDzv49sB0+EgoDDqFifWlCykXp4lr7IUEWn5/Gc0dQM7CFZ
iIFQxjBVvfvZfEsSrzc7s1r/V04vezimLwfXQdtWqiNHR++eepsFh1hILmEvWlxo
BZd88oD5W3WemDyanQS+5yjEnXc5kxCVNnzXZIWGgErCKqLrtb05gpZ1rmBmboT1
FOc4Il8nJQkbcpm80dradA==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
hLEYS0wdCQ2ECEd+N+KULJ+L616JNcA10sZB6CCUE+J+QYrKojayoeNvK3hjAjqb
9vjW1GtOy7vr/Z6vBQTXai+yxXoNs3vHtzRXVZcHUgFQCMIKuZUTOk/kwqiCJ9Bl
Dw7mXYv24n6K57TsU52HPb6dT/KS8VzXvpN2+8YxtTOgYLwq6rsjzOwEbYQfwza9
buL9gewdkRYg/K6U/wN3AQ31XUeqtHMWKALxwWnmWlKCxfTIkydcmnsQeV9B65kj
rGTH4t0d9yazCSAVeZQgbcbbsHSjhlSklD+sgCHYN0KPkf3XnbM8a8Vy10st51B0
TFTeS58eaiFfe5tllgHS/A==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 3632 )
`pragma protect data_block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`pragma protect end_protected

`endif



// `include "avery_ring.sv"
`ifndef avery_ring_sv
`define avery_ring_sv
/*
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2012.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */
/* A ring is a circular queue using head and tail pointer.
   A ring is full when tail is 1 less then head.
   A ring is empty when head and tail is the same.
   Head point is consumer pointer.
   Tail point is producer pointer.
   APIs:
        delete
        delete_all
        get_base_addr
        get_entry_size            : in bytes
        get_qsize
        get_tail/get_pi           : return the head pointer (or index)
        get_head/get_ci           : return the tail pointer (or index)
        get_tail_addr/get_ci_addr : return the memory address of the head pointing to
        get_head_addr/get_pi_addr : return the memory address of the head pointing to
        head_diff
        tail_diff
        is_empty
        is_full
        peek                      : read next valid entry, not dequeued
        pop
        push
        size                        same as num_entries
        num_entries:                number of valid entries
        num_unused_entries
        wait_free_space
        wait_size
        sprint
        is_wrap

        
*/
class avery_ring #(type T = bit[63:0]) extends avery_data_base;
    int       id;
    bit[63:0] base;  // base address that this ring sits in the system memory
    int       qsize; // number of the total entries
    T         Q[$];

    extern function new(int id, int qsize, int entry_size, bit[63:0] base = 0);

    // Try to get the next entry pointed by head.
    // Return null if empty.
    extern virtual function T peek();

    // Pop out the next entry pointed by head
    // NC limitation: extern virtual function T pop();

    extern virtual function void push (T v);

    // same as num_entries
    extern virtual function int size();

    extern virtual function int num_entries();

    // number of unused entries
    extern virtual function int num_unused_entries();

    // Delete the i'th entry.
    extern virtual function void delete(int i);

    extern virtual function void delete_all();

    // NVM spec 1.c 4.1.2 p42: The queue is Full when the Head equals one
    // more than the Tail. The number of entries in a queue when
    // full is one less than the queue size.
    extern virtual function bit is_full();

    // 4.1.1 The queue is Empty when the Head entry pointer
    // equals the Tail entry pointer.
    extern virtual function bit is_empty();

    // return 1 if need to wrap around, and output the number of entries
    // need to be wrapped around.
    extern virtual function bit is_wrap(input int total, output int num_wrapped);

    extern virtual function int get_qsize();

    // in bytes
    extern virtual function int get_entry_size();

    extern virtual function int get_entry_size_dw();

    // the tail pointer (index of which entry)
    extern virtual function bit[63:0] get_tail();
    extern virtual function bit[63:0] get_pi();

    // the head pointer (index of which entry)
    extern virtual function bit[63:0] get_head();
    extern virtual function bit[63:0] get_ci();

    // the memory address of the tail pointing to
    extern virtual function bit[63:0] get_tail_addr();
    extern virtual function bit[63:0] get_pi_addr();

    // the memory address of the head pointing to
    extern virtual function bit[63:0] get_head_addr();
    extern virtual function bit[63:0] get_ci_addr();

    extern virtual function bit[63:0] get_base_addr();

    extern virtual task wait_free_space(int num_free_entries = 1);

    extern virtual task wait_size(int num_entries = 0);

    // Pass in an newer header pointer and calculate what's difference.
    // This is used to check if the new_head is indeed valid.
    extern virtual function int head_diff(int new_head);

    extern virtual function int tail_diff(int new_tail);

    extern virtual function int pointer_diff();

    extern virtual function string sprint(int verbosity = 0, string prefix="");

    // Pop out the next entry pointed by head
    function T pop();


`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
EuBPEKU6MpBDR0AvOzxsr8OxGwS1Z25KSwHKsi+LKoS/GT496oMYVV/QqdhTLx+I
mbKpElvBryPCbe91I6tIYVIt9Pntvwl5u9fgoLRgKMsXtftwNHTUtjvRDkhk6Kae
zf5T5lxwrF27Jw9J842vxvWYyM0FBtluSuEp4PMMSh0=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
ArJtj3WJRmEySVl9j3NYUXK76ivfMUP/drZ2F6077/D9psOAuzblP10orIpem0Ck
5RGZOFCZYvA7EGgrf2vSwW4kFTlIKk4UGMx8YwXhAJV4xqMQ725pbS03LuM/x0Ow
DD9QCi7cjKVxoW3LUAGPl1p8W27gMg2V8g2uTHN2ihA=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
Aej11Xf23TnZPdunImJQF5qTQPeMDYSKqsauCUxJyvXbUjOynWQdU3+VWXK2bULF
PqLG9hvNGww7OOw+miQlOw==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
LO9xePBZJS6roOlcGMOg8Hq8JigNdMza3Rh66s5kKLxi/LntKmUSYfOns9OqVnJD
V3uPT/Cz0bm3iugcRvoaLE/rXH1UstjLUKjKzcHelYZc0y8im61LCYnUlhqjPg/c
3iV4g4/xVMEb+wNI7Ytbc2JBXcWD/KaABCJgSZTQL1XZTodpcLEssPHx2xP3OXfu
YShIStjbMPIp7AIJb076Gt7oGDExYEoTwC+p8TEn9hEwJBuOiPhLD6SGvQzXawB2
OQS2g6r2mRPPNg7hlZrB+G1dFfbjq9BqJE6mHER29+4JxPfTCC7mXO5UTWnyqpek
AgdiGxGFBuT+1ffvtHbZ9Q==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
swp/mYGipohC+XJVgn8fCn83XsKqvz+IGPp0RczYlsGGv/Hyr73A6HwRzJqaNI9l
a89hHhC6azFJdhpPIWrnTqJb7Jharfo107CFkFEcCiBvwI0YpCi5D8IxZkMk2nXn
NQ3H97hC5DcB7EOh1o0hhbX4i5Zs9MupOzVekx8fDcs=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
WLiCJk1ta40iFHQqUOMCNuXzrA6IqjsT0f6OiaylteprFbyfhRiLP7m2uhT1d7ht
FDiQG/VI1oiV4vUu6O1DW2lqBAkoVofR41g6LJCqTQ1Af0PAG+8zDUbRkZt4kPnq
0P1u4jat9vkAOIe+ew5Mh3NJ+PgFkJ9H95zr+XVxMNBWxsVxn3JVxa9R1i1+Jybw
/GFTCijFv6J4QO5tUDjSIyvJGbd7PcP0zJyzhyuv8w/+mFf6BisJ/XFLhT0K3G/P
wCM80tnrWdfWgCEl9/MBt7E/SgbAsmgEloqDTm3IGWxngccXWxjtYJM26sM+LKbA
MSA6KMusW+VodecH9A3hVg==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
dRP6ZGkYoTPGlyqgH4zPZ2eXpByy5OhoADxfAhycLjMNZxvXH4r2/baMjQNl116x
kBEY9XT5gxB1ga6oCsDwEthYuh9maIJ/3c2llDFK1v03Cc/7UJF0Q7k7j2R59QjN
e2S3KsBkzomYtvsF11hreCAWQwxdSVUer+/d5PSS70ukr7dRQaZ1QBGnV+/QZOJX
CqfyaZRGY1d/dDpRIOq7CDRCpOrsPz7jHQM8U9YoUgw2fkdsNt0iJJz3BJv0hMqM
MofBYqQ/Md2DsGqw9l//ncJRa/x9n5ctoqBnLAUVqkQv936+/5W6YcD2tawZ2l1J
AcWmLJSFp+38FdYvdvfBWg==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 384 )
`pragma protect data_block
QNL59PTKzCDsVpSc+C3TiepCk7UGCCgt60KFIvhMYwZP3ykge7SdldhY9jOO6kgd
c4WIbACGglwcbbcHBSahwjq1k1dUlZprBKLu+gVmMEFHpYfd/0Wgvr36BVYX0hhh
cm1uW+36qs17sHhMURdfvOy3B2KPELPOHqpBgMCWP65g8je4OQkTzurPrxlM4Yp8
aRqpszuC1HmQNBAA5nunQWwIQzK7fboOc1A9bTvKBrfnEOlbwBE/nCZAemNcFMY7
SkNHSypnSd3Q4g5ICsM3+jMMswUmucboe/x9fcoDk2/RPz7vTji3qJR0j1i5eIN3
iDu2CbNVcqquo+Jftf43wNOLwVmWHqLTPdUs/h5KWB2Ewsh9zYDm0e58wfTUFFr+
BftoHZK77T3hCPgQ6hmBGXAC4wYtrWDy6MfTu++sOwqmMkxsHLV+52YPPcKo14+z
WtuDdvHel/dYPGRimiuAljjitnqkyM6I2sbxJs8SjpL9SbDb2csKuFl0UOmbSEF6

`pragma protect end_protected
    endfunction



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
P4Hu49ElLYEKBhfR46ysqkXCoVDPYoL6zcpCDLPy44CODrxzk154VW1NkU5capTE
dyiaWpkNW4Fw2whAnXxWj/Hvp0Po0rql+4Kd9+h5iNaMClS3g8N3CoPVDb7zNu9K
mqn9wYJYBAdm16LbgtQYTURG/2fP0VmJERTnDk5lTPE=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
de0VleLv888rwi3ERrD8OfBumDCYPq3zAlMwptmqFxb4vLp0NWVwHrB+uu3tOwFe
oQ3iK0qLXR1M/kAoEbajd38UOAGJF+KkyWw5ef19hUg3YY+JuoGmj1hDic0357+M
4s+HaYbBVVt2iOJdr11be5ylGbuwP9SUzoNzge2iOm4=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
BdPxDfPPHUy7VrhgTE9JmZDRXW13c/nB3rXV13otNgHyHaBdfYojwmt+kfv/f6zn
MOxycFbeokyngkpdnFNwOw==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
je/v0A9VaF+KbSeDtdfWkKKgPImaPFba6qfVvddFmUyM98kXUXKq43BfogxK2J8d
LoaW8CoRBfdpz4iEmqHo7EPZVVUaHE5W+BpqMWSajEPMywcL6wUl5SBOoWqRiNmV
8keWPVybBeTXy6WnH5xC8L9HI87OY3TwboxEV/bZpOqAVVLsCZUh/d1PNC8/Hdcb
cqClZYF6aYKSvg58/AMrpiHrhl324h2Blm+INutpweEQt8MDlsHj9uYT5kVXrcfm
lsUX24uV3uxHwDDJB0n3cCKd1gxwkHeFyW++xJU41cFqjsBRO0nt48+K8DbaPT20
iBDioNyFBn7eqKm835mDpw==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
hDyeELKZ9qr+SuFCNvAI3tHPsNW70xZoIfa6u97qPegLzmB3busrofnJlDZ+pnjl
YP4pk6oKk4cLDnC58oTfzC5LbIaGm3+EjXUoN0tXlTYWN99LzLh20J/rgmULwNeR
QdMUrXgfwvWrkSCMyORweNNwrvSmowrcVtk3g4DYjrg=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
rYLfRYWewAGFFGFk+RmPyqgy2GWIL0J/LZMgnUHCD1PhLqJj+zTgLD/ztBH+wKoM
LnaBo8bLQSxrqOJw63SztaxTer7EmvoxeXI8/h5kPA3T5BeqKvQ1wNPFjlc8pB6X
Xb4aTYDn/bEMa95UgSLIeB7ZV9eY2WZa3IomPMH5oN8Nazttwj+nu4HUdGOaLc5I
nUKohA7+bdsY7wk/Feu7hGb4USFBHi+DedoeiJnfjjJMSyMvVI/avjnWjzS5DbiC
hbuainh319EAzX2bFJzlT/V+6tWRBJOfYF0zlAH9nFTGZVXiKmHNx+55DI+imd/9
E4YfErtj8SmtR2U5UsxhrQ==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
a3yW4q/0ZQRGOVOwC9MW1gV8zzQr6tYI38hBaC5wacpN8ZaI+qsGXW55/w0b1yK9
nn9EiGX5BiBq/gAAElsC9NNlVGVTbB0sRogmNsCe2b2xR802X6bu5SxKqpdUgQ8U
YClgJ7mZ1r5turNfkOp2yDRmIgYz2bZrkJfueAFD7ie4zEUyRxJoLNwj8FAfN4nl
n1+rf6Fspxa22zkGzR5S+qPmBEzJ7057r8/CLrtdjkRv84EuqYig9flMl9dcI4gs
GYK1hCCn5/R1DjlLFmS1kclgTOJu8+3IoniMAAKy8j6RGkhu7lJLDU55tyNj9cmq
IjoYnJ/mhL+rbpxf1r+mrA==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 1360 )
`pragma protect data_block
QNL59PTKzCDsVpSc+C3TiepCk7UGCCgt60KFIvhMYwZP3ykge7SdldhY9jOO6kgd
iarbyUuIjFwk7gELrnM0Q+iQgOHCab3qNZFydUPDu8JtWcWb+rEpjy7oAX2zZMWb
EPDT1FlMMAQZjbEhmMTt9SvtaZSxDezixhEorYOtUpMIdy308CxTYVgpearmmm5A
b1VUuNqrAcJIuGc5BFFhiTvEVm6S3KrmJXEpQ5Lnm3Mkh1RIfRIGrbQH3zf1HI5M
pT1J0Z1rK2oPvbUUCiyhlvpQaLor0fDWVI3dRadoCXnMknagkmDSa9/G/URJp/We
qft44Y1U3nv1ktJknw7DKH8WHPNPF2TiK5E0hoJ/SASLAFBaAw5ymiBCMpSNibqG
hnGCJppiyrVnGxhYWdlls71tRQvk7l1+H+/n0kyuNFmVA7h7vbrnY4oz/O9BuIKO
n6+yLPKypUwLrgQ9sVuf491rGQKz1HofjPqmJAa1gTD3+ltTCM8xfKSjYW7T1IGH
Te9/tAwte09RMKhSdcoZ0N4xd4I7ZHtQ8o/Bth9X/srI10IW/eNIOouIiFfU8OX5
XufHHPjXozLs/OzGVS46PPs9Fl3G1iPU/5gcza4NVnT+Xy3CmpFiyBZTuPz4pfvr
BGcMsTKyiV8vFN1zun7+K6lfedY36HQX5U8YUEvX769TWgs2/PMdw/0Kf5cGv87w
qqi5L3sireeVl8ZL4qqavCHKcyJkzBszSUeCD1WDD+6yfj/q+AcH4Lbs5cPWmy7l
YgcWj4V3IpslaYFKwqzLhLRpPs9z+MtuSaeoE8dMSOOgTkSpA5/XAPEZ0cgNkE4u
h/llsNWcVWKEhuAZSmZLNDLFDRkcsOhJzqTjooUcCnlI2vQDDtuA7aVg3Rqak+xq
g8nhoN1wde2IDMDMDhoLUR4ewlq2oXUafFWpbQqacwBWKEEYBlkJko7NPT1udhH1
fRhfKFBDE/+XIgTYOvNk6m9uADcpDafho6OXrmd6R9q9SEisDbPxFMcPnZtNeV92
1Ppr7KFq5rArHF2Axjcl0EGLLNJLlebU/m4I/5jsOmda+UhKUJF143A8UKZjgML6
GRYQDR9LLq9KURHgMAKFv5Ul2dOjhh853G5At2XJMkpNqGNNcz86xThfNGbO1AK/
prGpebdSdhiXMQEx/ac21S4clm18kp20He7kNVt7zR9Qnw5vWlZOd9WxfMSTKE6u
JXRA28+mCOPWMIIjvpK1/pqTGNIyWACkYgskVsKu9oyHOyvs6FFsB2aWlzZ0lrws
SXEF8emUHW04oAnJ5YWsSP0ezcGC3isZkGfIs31kyMizm4VtCQNBIZuG6kAeMsKH
7ATjosAOZYc8E5wK0bw0cUodu1AURL+5oVZahgyN6e/HMLOeCggEBZ0Qhi6IF+Fq
SXGEfQHzKFG78Bvn/OticuMauAqxIwA/fM7YQcxYpzhW/MFh3/B5H3afZ1iea6dK
nRclU45ASDlFvn0Oyv1JQmbcv5KPfeSDOEZW3hMTfqV35vJ2yyL8K8AZKDDlcfJp
cyNlCNS9maNXjaZ96PHKcZfiILwxZaaBdRFBPW6UCQLdlqmB7UK9JAh9pcl7ZmAT
dDTpSZyiGNluDmF2Td8lisqyAYOJmx6kMHk59QblwFZ99IXlOCVWspTxpPhNSdEj
C9KQSVF55qklh5QV/2NqwWiiaztMcojU5UO2MhCx4kCW5lQsk/mA063SROEYtv8M
drMtvQnM8+ndDkBGBZ5BiOGGjh8E4qXyV5OPhimW44HlIWKfRy0hr483EtWKoYJB
d5aILgJ6U+3jPBCEwbN4ZQ==

`pragma protect end_protected

endclass



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
guas0JWCRuNqb2iFr7ocVEanlgGVXuFN2G4SQR2EvRk0baLi94tEF7wUvYYZYwv+
EQqtS2wmw5f8NgPsFBswIR8XVYw8TU5x66jEeb7nqaasQxJc6bX7HapdMIIVnlKY
H8ibPyCVvkZbLGG/hw9oRhvhgAUAzyoke1J13av9yJU=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
HQ8v5H6rbPnylKM9Gruzm4/egUI59j8fmfWpjvfpblQVILPXaTHo3trKHkXwjcQH
fVOrbTqzj8xs6IA/oU33tUqnP3amlhmAFXluuwuQ2zgl21zXvWn4takMbShYM8Rx
I7+MdkGWuRbubh8JDYnTpP1YbO6TvYMtNVyOeKaGx0o=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
Q2eIJHcCXdSnHkllM5p16d/em8pMuOjl/mcH681G7h3CMufzuX50iwI02u3AELra
PmPR19MgQUDzvPgSScxawg==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
A7YHf9SxNycJS7Lol9GlEUllfEvHrNd+ZqBP0kdPE1I/uIWTnF1/meUhLImuW/Ne
JlrwtZKsSWVauURGYZrsqL8ciZs/dCBBoWxYQcBsD0VJ3gOOw6fVuk/6qrAPlRb6
FLHEkOfdIV5xQhbCfrdM/93tFRLaa85+bXBcLeccJeQymCRq4s301xDyLIc6aUk6
IXbStJfhlSw5uBXcsc4dRuqDe5avOEC7bg4IT3wmXjJxIStfwmM37diQHj8JaXwZ
DD3IMNY1qkoNB4QGKMOCM3mO7zGoEBkOVbfRXT5NAIrEKKFsm6WnAylz52W9h1qc
taU3nwtuD7HeZxSIUM0sfA==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
r2G9R1klDRfXLInQBCVZm8F0xoo4mcj4K8wA3dJXMgxoF6YakiZ87bcKmqZJqa00
hkb9foUZGowiICfMxpoyeMws0kFukr+ZAk2DsfQASucL/IKpM+Un1+g1s8mxpoXz
YZoarI3tYvH6LhQU5fvoP1qPlLqneviaRhT9lrqQtOs=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
nx5RH23MZ4f6ti6zQg36cltI+I0BBpwIbf2B/2WM8KkmbAh+5icViwRMHDDIXfIX
InGK4ZnSvng1E3CqDqztm1FDRZyKbHutOz190iU+cpvTIb8hXLXo6hs10nUuJqWx
TcgHFyeBsPbxea5+gg1gXHvnhyX9Sk+JLaAuiZI0TLHqh/7hj69dvSvxP9B5a7u+
YSmBYjGJPY01HMb5sZJ4bfSm/ofPXMMjLNVxodteZFwaUOoQzlnFGXJVsoQaZNaH
pypHISwvlb4aETIpByt/7lnnSRzg7HDI+2TR+0a7RJ5jwm4nQWhnAbc0+eXw/B6a
ijDcnJlrUt1P6+/NSG2XMQ==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
jAQDb6dHIMh62DDZoO6JVm2AOaXJMq+52+xKruGTw/6mFPRexLVTV6rtYJUkFoPP
iX8r6Z9s2AfCJ1d7QTknrmN6Vpmh+CbnolaoDyk2Hilhz+4NQ2tO2korKgnBLnYw
uTVIfnAZPNtwoNGFJKIo8PGyxWlpQ530ZdVrg2for2L7N2rTkr+SFlsQAPCGo/7m
wUo6TrDO8zpoRcjKUr3iDrd/kdoAE5gIR00g+TFZAh6Wovu389Ky5OPR5I+P5ZVm
HmkOE26jl59rIgl/KhVFsn0xZvlgw0seFx++sKzEg0Z2zvzrUOrPHpitnvR+xVYk
HPlYwuI+TLRAPjp9D3N8yA==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 4736 )
`pragma protect data_block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`pragma protect end_protected


`endif
// `include "avery_timer.sv"
/*
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2009.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */

`ifndef avery_timer_sv
`define avery_timer_sv

class avery_timer;

    bit  is_timed_out     = 0; // timer timed out flag
    bit  is_min_timed_out = 0; // mininum timer timed out flag

    extern function new(
            avery_log  log = null, 
            time       timeout,         // time unit is determined by timescale. If min/max is used, it's the maximum timeout value
            time       min_timeout = 0, // minimum timeout value, use 0 to disable it
            string     msg = "",
            bit        is_fatal = 0
        );

    extern virtual task          start();
    extern virtual task          restart();
    extern virtual task          stop();
    extern virtual function void set_timeout(time t); // change to a new timeout value
    extern virtual function void set_min_timeout(time t); // change to a new timeout value



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
aXivcAXnO+kZ/D9ipXLS+usUCRM5vUKYoVesJnQ8fSWcANoNFd7zSfw43i48/42v
BBpOY3olb10qlzLieXFOnvt4zNSW6bqKwDLdEa4Rz6wQQ+wjQaZGXuhV88OhNhoe
aIPVD+4YjxwvNalTddy1S2CuXA2eIR/vTW6yEMhMp7A=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
hItf+FX88ESx+LewnGmrxMC1JXLBjJLQDZJH6ApWP+xqmD8vKdycb0TIXBKXhbs5
+NT+Uw55bZvynht0PoDCZp+yRhBo3o02tsmPqwqKAULjWeHOhP1jMFuZZ56idzfc
rkEjhk0lpRcUeZuANYKNSch5pBpF0CTvKe5YRV7fMxE=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
pQDJHNvGba80/D+YsG9s+rVJH9g7tM/44sHy+9oOKTL6tBOMaZpzzh/CD34P2bxm
VcQMMGEM/AdJx+dzeDvLKQ==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
rHSrIZbaGpJgjr/aXTEKkpuOpDnObd+rJ1dnU0A4rPCKk3tmZF29QNY1QZeqLv2P
KrBr3FQNAQP8GaY9R2uoCa4pHOGCFJ3351Mo1jjYIEcRTLr1Jj/yyri+aG9/krpP
T7+uP8fvqTRcD43ryhqWj0t71Q2MU5QhSp6cgGn+TPJcOfMfRRoPiDbymySpWGWt
BvXUNH31RSHHeN+nttueCkVkypCqAs6k5QzW6WIqyItq6znjNDn0vFWtmvlmcJgA
5dJFgZALOSFfx/iAD3+lPL/cWcuZCtw5h6Fq9GWd4Q4fJwCTtXfQAnLJVQSFDBOj
3SZsOIY/D05zBIDvhHcg3A==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
tU00SuetzqEp/SD5PxgBfAriBxPkkkXI+W7y7zJDUzsouPsl5Oy6guZMZaiwZLwv
ckzJ2OXX+CNKB0KOqDxz6Di5gXBSIUBpHZXjsd51W3t3f/2fTbrGZTTOt5O9ljsV
1MPbJN4/D1cacyh6390AzETG2aMtZZwmgCj9CyMgC3A=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
SLl828FbyykZ/KyHfLLqESKOxCOdQ4M2hWA6o2E6+nkO9ydEF7gFYPJOgAclBqnK
AqZw39vXeL4njg93R183ilXGxE1azX9CxdvOWZRsBP0IBSOSurd7Ih8VVLqrTWk+
peKtZfFy9p2cIxOXmzF+aPIRr5wz70pSheu7PTjVG3WGpG4yTF7uwP+MzpXDLRB0
ScXwgKi06o+nL0h1x7Kd99Tawh2VcTN8jT3+s4hFp1DwBtG8QNB63ndmFUbEBa2e
bucNTwQnUAq0/znnKGFVTkTGKa1bRfjSvcKhM4UeGqjHXGUEWrgMENdTuoFCvhIT
tV689VpqcSU7VaYoa2+/RQ==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
a4iq2oJEBxormSXA4pr5AbSDrFUiVfdJb4lw3w3MHSCiATpBA7N6nsVnrqVxHRW3
UufPe8svRJJZnaUFpt8t3bLnweNyXpDgqdxYoi3u1DF5IrgitM7/gdHW/Sel+Byy
eK6XM5QAdTHXjoWHl60eqEIfGR7CxPgXezlW88KcmYpoeoZ5+dmYwcjdM84g0LkV
X9sgQpbS1xZ7XPSh5exm4Cvh7Zb8bfl4YSlO9ZbjYAoa9x9SBnZqVx+DYz7fiAZR
+OqEmzD3dCgjnZWO3MWoJ8LM2kmm1DPWoHUn4xqy6gAN3HXB+FfQXG/aAHAmihgj
vjcFJAbqxmUcscCuGyYDMA==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 1392 )
`pragma protect data_block
QNL59PTKzCDsVpSc+C3TiepCk7UGCCgt60KFIvhMYwZP3ykge7SdldhY9jOO6kgd
c4WIbACGglwcbbcHBSahwtYyTA+9Z/E4ikmqPREDXWmB62tMAg+lIrEregTEEr+3
Kbpq0jVh6DkTdN8YpWj3ZiSjQ/h+1IAETj2qn1dd+OgAdT80vlbuPJBO484scfYO
/HHREieriaT8OqlFo8HCT59cRIR42ZC7b+eAmXKzpSZeXMNd4XOMDwU2lSfckTBD
2gUZFZrdILxCprDsPVxLZZp1lSxxl3gvi8WUNM9P/YMsDtFxlFTaNLzhZp2Fosjp
c4q2LXqevTIX2EX9V56kBuNsnmhkXnTpuU2LlWqX4k8LPrq1H1CXtzrb0An3E63t
0vv8ZDlY9V2pTekxxpsw/gHX1mh2ZORiQLniXlImz6yPRyxyrZ0yg3ctrCW9Y/fO
/XHlXrIYx2iFOTiB6obuj/oe6za6AsZUhNWqm7KLXBnLvL0B7WMCHs3pfQ+HWJR9
1tNFHN2FlX++6VUgEUlu9sv7RpT25YMmKWm6vZI89Qrz4pht1zzDQ894n6fJTHoh
4IF9AzoSjwwfeiuIfgXUYdUEDV0jl2kkQ2X9qdDbywvDhLOnH4rs6Tq2B7NnPmnn
jCGrT0tVFGkbD1D3hyTCuXigSavRrkugDPId9vjTHqytBTPS1f8TO5mzWAXD8A4q
4IeHKkA6ESfXQXqj54m4ADBf5ywdenaYlZ1CyBFMLLhHxiHjyx0JqyClhZSiGB/r
j87jxV2DYy8vNG95sfuayy/2fG01RG6/X375VUEkOrWbPLf9xZ2UkuEToDRC7w/1
EgsuGr7IJRR+xfxlih/5tP9Pgwkb3t9wIzs758HpRc7f5pYIDXGexnWi06J0RbE2
T24HMZ2VFZABEfWyJqS3Ece7arwnbH7eYwnK6ntGGa83u6/EC6rknJflEdrka9UQ
Zp41vW4rcop0O5ufE28pKEK++ZDJ+zU8Cy7KHK+x26UxN0MonfjfC6N/P2PyPZWy
XjbIDSFNqXkHWqo/ptl7KXnzVhXhAlWeFTuVjo0u9QkkLaUdQ4KCSPZa2hXT3uH+
z72T/r5uwZCeSgrA2wtmhZz/hbebOtQdH17ZIcz75ZdyecJ+5efZnYBt6NINPoGd
Xvnnxu89vk/2ky2Ae1rsTecCm58ZjrKs2snwAU5jRx8QqhcH4ODfrIUMN3+WQGhE
sJeT2rLQzBllo8NPNE7tDMrCCqC8stSqm1lTj4M+cAxvvtwJ2r36FO1YrvupfGXg
IrEaHdmuunE3nXhcdwW1RXNERxLReuJb2q/llh6l8RO202BMoj4cCIih7JRn73E6
TtiiG1Ad4UpUIusKMddRuOBYbkXczAdB79wx3K4CSK4GoukY3R/IdahDeZar7ScA
q7Hy/AcNQ2UQL78PYzZFgtmDre5MdmYKNyHMy7+JOvvPWDaEPeFubLOHEzQQ7lh3
hO3bBTuNSlaLxwQ3AEiKxcVOEBMokna+oevxnZQTnFy9l7cZHLeCYVJy6HveAtjm
Pr7aKbt8ZvtLtAcpxOdCBRE74Z1SLzTJaJnsoNf6/ZAnDEX7AgBLd6IJsLN7eWSU
7xQv6TICQuVSrjdzuSuOCoda2AzRU3NTwwNqoSl6JIMVq28gAkh8auGlyGSW8cxz
zd8v8+uAeahZ7tAc0z/ZmD6AK5lrJki/M0Br5iLvGBQTDdV69u+A/oBNxOQalOVN
FHrFtVIpIJywCkB4JiW0F72MAf3gEUOvv743TKeCAyzF7NUBCvtiikvXT+TRj/Xz
ecd5YM8vTItBDswlQKk9YrJo1uGYh5pJF9GFDp+yIkI+2eybPH040JEldnz+WHyT

`pragma protect end_protected

endclass



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
hCtSn7dp6GOGllDUNuY8ARR+9VIuGq+8CMq03IMDSAFae5fxaleBCtmHTy0ur3jy
nl9zg5vcHvYX9ya4otKSAvQYlkIqHxiLjpWW/VsoKJuQ2RkVkpyfOOthnU+fosvY
pysPegASoFurON/jZQ5iFvcko8EMkCBBdIDpBOWeFOM=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
fow5ipkB+ASTrE/2uFCvQLebSJ+T4xAngfRkQYvZWl2M8sixHzs6+APdP7TbdVSs
pXynoe9Cm2S/A8Do32qlHx+eXiifIZ6NIlzgX3wOR+IG8H3B9juTs2+g4fabS8fM
OYW1UE5k+u0GI6unZ9f8PfOxmgZH19FehlOGiOC4Uho=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
F270PY6F898MldahrlbZsaWr8ZrlhAJDJt5oN2AfEhDJEEPodSBbyXpzRAYqRp58
IHb8XWIIbfNchO+HXiCwFQ==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
LuC4sSLu+mqELTaBEBX4mdVzIPWwv1vPacR+IkDbYVGU842DzMfCwxjweqJrhqqq
FP/XftcDDc7pGrXe9m9RJNzOsF1rnb4fbH7Pb2IYv5RumgjHsOb8b20nplR5ZB3v
1xnA9atf3QTVt5hf5hFwN+B/3iRNFOX5ORmj3AZuRwXkL6TmAz8GvBNwoyoaCviP
t8sDAdq6X8OLjp7SyiJdR0tUZEiseKDscM7eWrwgqSYRaDOFZY07uL48YEkFmHTZ
ISJP1B51Ir2GRaGzdoqjmA5oeCNIRFEiFP7KUsKFt596Ah6aF5VichEKNGpK2UhA
SBza4sqDdSK3bi8kcD1AcA==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
gfeksyK/ru8AAFYdE5L58gxhttfjbp7/i9BRfytiC/maaQ+qB4apWlASSwXxvQnV
MHIOLJWpRE+BHbLFIR8TiAkqBBywH1S5wgjZiunCi7eI1B3YSzXH3eyM23Yi2h6f
sq9aw6IrJpjo6sPPAgrml6rbIdT7jPqUeZL1EHLVlJI=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
m/sz+ByK2kKSSW8Jmj7mOQRY1ySrzx20bpPRqwUOxwf6An9rovft+adSNuojbFCR
AHYFEDm3rCJaXoon50wfU/ZOh1K5WxbU6FpG0yPpIDoxgB8e/WXbLilvDz2Uq+/T
YX2k0nxe13w4jLYs9QTG9VsQ2lnqNAm1Y17inZdDsdOYFUh6tp6usRVLIVVot25S
K/RotQc+qCiVmI/H7iubO9q9LApUQa4k8bZhpPCzfNCh/OARjQOMfcnrrgz4hcQM
wROQnugaSmXARxmS3v46Eb/VrwPgOEnStWfcVw1rpRRdj8YZdwl4CCRL4U+wRWBv
3TVl/j/6uuoFMKHXnXVLHQ==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
rhMFZN8P1sgL6Ztih9cHOH5wKSrpcgvZI5kFvy47rI2SSGrwWNz+zIjmkgC1zpVj
d2vwEmyj7iS+oGv9/qlP+X3KaxJ6yrMDCKjOEotnqCejlYWDQbB13bNvkpLhzoA4
wKpxMCFSaGT2ZG0sWJsFKROw1VUZbfhsaLBmVeynJLN0huXepjP+hlZC2WR1fc3C
DEmVD39tDrCqsi5CUA27dvpJFu9QDeeYsXFlAYvEOxIf8iilmytCSVB263ldpkKA
yBOVXyZgGPed5YvKq1Ps+1qPFKa1pyXQnV5Z7QJ/nlMjSqmTs3o5Rq2HlzyQ5NIj
NbpgxmmYfOPHRlFx3GRqnA==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 1968 )
`pragma protect data_block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`pragma protect end_protected

`endif

`ifndef avery_print_util_sv
`define avery_print_util_sv



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
cRNay3b+a49jVr5+896mkshCz1k0MetYi0el8MxS6Remw9+aMs1GbSjSkkIGproS
sKwwQQCzbD7hIVfP96K77tDU9wbpnEMOnqv3y1+SSGjt+RtPhrziRSNA8rGaV5A6
DyGguJ+6v3kyJj3PRJGUBcN9pHRrtpfJoSXeeB7sN5c=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
P0lNxQzVYB15N9h7ezqIJ3tlwoJQAAZC+IodAZmOAhrTRmCkzpfVbFj8cTjukx0Q
F1Wv/yikj6bZVWJWnQ7wYm0UBbqCqjfb0PUDamuIN0IN0Tw+5mmr0LkWM9t8kS25
kaDoZH9gXsQJBzlO4QRQPtvHNxxO+9VR6aF2xAmDgNc=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
VS/FKILwAQqE7T2r/Do3fSQWdN9ZunKcqNUwf5xB+h/UhvahMGUUf/M1j1/iB3iW
TGGUXXjmdezw7krKBYRJog==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
jyr7xLiswmVphTq5GYiyVY11k019nw06+ZMDRODUxVWb8qeLyzD76bj9Syp0+zCO
uLibhADq0wsnwJAZDWysTRy93oOB3WdqWZ+H9tusni1UGgWj4ZFUvcrp47UTarq1
Rzi4oiKprF3R+SFm+TIwhkUJ4BEDQP2AIcuVFjN+DFp912LOYJVTBlQ35wKOfsRW
lIx7qIIa3qFDcl7YaryFid51bmTNRWenClgZBZsh5nC1xZJi1YXGjFamQ3W8BoAP
DsMBTw3h0mtJ4KSISws+T+h3UzZ2QjykKhsQ2MUQ2pzZl/g63TNFoWTq+z3mfbTW
2b29a1y7NO6s9Sb0sIrojg==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
LggkhwTNf4aWsqmzAoG8OR2oT0CWB9eS49eH3/U6r1GqY2joappcIjOqWIv0+Dzb
lTjDsauX/zO4mb3gqax8JDGkXY4YGkGz+3+e6T15CtKj65QUVV1VWEDN81St6uZv
u9K0If1aV1cDu/7uonFtPCuX2HYjWLNa5tmAv/Ej+Ms=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
GX/mISb6dGJSq9DO29HgNnqaz2KJXJyJUyyBQA8tI43c3RvW7pF+zkFSaEcdX0/E
/i9WbkyTXCvAKd+7hIjxwD28iZ024F1O4IIAA05Nssr4n961g/P8p+/iqHz0hDz7
t3K7l7hbK0YpZcsLC/k42Pi2Z2wSxBdWJYRLDcdrNb7o11Wnw0dM1tT8pAbMxk8J
B3YKYYttJB/JZQ/YohV6qN3pRMrNke2D9Bxp5vT6vRrgaZ26fg46tZvJjGE/teZw
AdgtaSrVzqrpOb9oOrXBpo+Jl0SJLV8KBQSiP0fY+crTmNn1eMY+YrGeE2VRaanp
ThxTsMR1z8papAiTMEjQQA==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
CsOBsf2aa1NoJZnTHdYLtD5CCP2W7O7bNZ7f4g8LeOo4ggR2Asi+UehGLr/SzBnP
/Hnj0YoWoKM2kTA6p0I9KyuqNpLQBKADvb7PIQd1AfwZcOACS6jX+PKDQ84x7V84
TPdfE4xvgdJclSIz65hRVd8C2EhxhZfiO527RbLcg3GOYhWr4sKiuqLBsYROlyX3
occQU46qsK7BtOHCdbZlXEx0pYlcQ5K9kOn8voJKHNsTlqqVrEFHya+Zj1/KN+7w
qGBIxC8EeJ8kp16xRnFjvpMmxcoWchftcSS/p3OPi0T8oqPE4YrJPNBOBssBLKIl
OulsdNbI/UepVSvfwLwTkg==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 1952 )
`pragma protect data_block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`pragma protect end_protected

`endif

// `include "avery_param_log.sv"
/*
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2012.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */
/***************************************************************************
 *    File Name:  avery_param_log.sv
 *  Description:  avery_param_log class for basic
 ***************************************************************************/

`ifndef avery_param_log_sv
`define avery_param_log_sv

// for merge coverage 
class avery_param_log_base extends avery_log;
    // basic variable of log
           string   product_name;    // BFM product name        
           string   product_name_s;  // BFM product name small letter

    function new(string name = "avery_param_log", `avery_xvm_parent);
        super.new(name, parent);
        this.name = name;
    endfunction

    // for merge coverage item if up-layer can't directly get down-layer
    virtual function void merge_coverage (avery_param_log_base log_base_a); 
        error($sformatf("%m: virtual method is not implemented"));
    endfunction
endclass

class avery_param_log #(
    parameter type debug_e     = avy_debug_e, 
                   chklist_e   = avy_chklist_id_e, 
                   assert_item = avery_assertion_item
    ) extends avery_param_log_base;
    // file handle
           int cvg_report_file = 0;

    // debug message related
           bit dbg_flag[];
    static int dbg_flag_visited[string];

    // NEW:
               assert_item      chklist_map[];                // chklist_e to assertion
    protected  chklist_e        sampled_item;
    covergroup cg_checklist;                                  // Var: checklist coverage group
        coverpoint sampled_item
        {
            bins AVY_chklist_id_first = {0};
        }
    endgroup

    // assertion item related
           assert_item          assert_map[string];           // name to assertion
    static avery_severity       user_global_severity[string]; // name to assertion
    local  string               unknown_assert_q[$];

    extern function new(string name, `avery_xvm_parent, string product_name = "AVY");
    


`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
K+xwcn+YMHFMYT7UhAZb5l2zE7Uzbi3xiof5jQoSp3jS+FS64SjILo1ERR7IRjiS
acPHsUehGqT0mn2Uys4O3NvA61jgJskWb1QP7sci/c7xVDPTQtoFzyQGamJuE/+n
zkNzwQfGivdfn9F0PrgQBRqHJAD00QIy/0+dnQ7amck=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
J4M80GzjL4YKVnaTWbqEJgNo7QLsXVfBtpUOA4LuylPjxDmZ35aaI3Sx1vGwEFkd
QJnW1jSSWXL+JZGKhEZRNYCXUvrPpJ1Vbkarmg4xWEwcG7z7kVmLD8E5drc79yuS
vZaGPx/HjTXwBH3DIU5zXjzIxbiqfWM0sGQdh6vhnBc=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
lgVkYjbHN7H4puxM78FcbbZ5G/YCDxHNohpA4abf+lE8pAKrvknUcFxVGCybVoKP
bx3IsRf2t4YBveH4uxX/3g==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
u2RdVFlZ1KVbZyZM5XEeqZuMO2zKbZYaG+X2uJQjvy/AcySPbnqj14RP93EYGMlV
rnBz1BlRQD3shEeU5oc623JCUidcawF7Vu63DAiGTf7h4zbH3L/DeuAdthWe9NaU
wYP3P9Mu7df58sEvNuKSH28SIbCHGOz74XiRzY39DRwAChcor9/fs0auwtQ8yL2O
Xp7SRVwVnMoj98AMpr+GDaD+KGSOIF9HLciYYmUBbpbdC5rOoxS4ro9S27ztjAFW
U/GFXuufA5xMker4z6iSnBxImefQMmNMVVXacsYs0hukOZ0yTmiCUW1EKrpLiLOU
8YuwA/vElgOvCtDlb6YXog==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
eLCTlpKcsh3UaaL3QlJ/kHczeh/6s6s7NZgFnFff2QWKv+jdbJUhSLcZmJykFQZ5
Qch2FdeOgoLSrFU2DatPtNEA38LdJJVkVx7263nmhOZk37Q1SfIu2hLXuDLc4QbM
9M7c7Rfpv5yPJltfi+qEfjwUsbV4u2RQkpIL5docqcA=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
svZpNa4GxVPr1XG4plwdvICVWU8xJN453h/2pK5vTJh/5Do6yjbdAHIcju6kbINQ
dpBa2/FPYvx5oBewNiu9Il24e9jsqDBXOuKaDojOFHzJag9b7cSO1Z2IL5wSNTdQ
lyt3lhiHO8iIDeiDj+K57jfyRrkaxXCYt0DTReJ4pHBOFZC4ttREYNXSOHUZU6qz
LHjz/zKJTArkBpUe8/Ttz3BB4Y3Qej3HkLaR2xvYQhO8MDsUYtpraKTj88tYeryV
5q1tbAO0MYxDx9Dm54Da5bSGKRwPhxBOrlc2ixm/7e/sEqGhJQRSis+042uBJNCY
xBcLciVsej9BZeNEZUm8bw==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
SLcECA4Aldh4qRn2tfNVEOQPbQV6IVcMlQCRrRcUP6b8sn7+sMZ40aBUTaNrgUzG
tHAvkF7CB2XdMJlNd3//R6c8vdM8rkaQy15PIM9tZjjdOJFjGj/VknVzu7DT/eFf
nzTfsRnRePGdbI6lrC1NW/vxdSUuNhDfDmgNlrjjt9kj1FG4ADd9fn/vBiw0lG0C
v6Fu6E28jE7u9X4V4BLKBNxt6HFSSFpPGs92vW/fRnHTzPtrcZ5Z04PJjdM86WbZ
PRFR37ESsVK5juiVZfu1/LoMJrDDXKG/aSapMae41JM+OrHdIWmexx/r16Ggi8w1
K2grQ1aXOgrWy65DGpyebQ==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 28176 )
`pragma protect data_block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`pragma protect end_protected

endclass



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
X6/hSStkav+Q2HnySyuMPNgvzDdtZGuPsrisa0YlKwNwLTAR1yvucFyNIZXz1aw+
AcvKYPG/14nBOgWWFzhhHoS+5580jmDcrUIlRD2TuxSmVR2v/IsL/V42Lbw0mdas
zL9vtVOJNhdtwqgq0tU0uioD7GQV5JaZXUyc/YBwisE=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
tYvD0rg0reuDNOkeR0yE+varNXMouOmPuCYAD3hHgOHpJjQn4VvyRgj3c9NSDZme
U5apiO3ziMene05iVUjIFYVFuvK/hXd9MvlXWZVBnt9RVF3MloD1SrJjgWobp8OI
lYd/jDaExRDhVFWU9Igjy3GNpMh7o15pNmMZESX6/nQ=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
RGN3U9JOVFGm+XDNyBARPLFzzMpiW7MW9D6MOBsUAebCJ5YGweR5dtnblah0/des
SBaZM3eM7tGn29TYnGR/Kg==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
kdIUGzYbyWIe1pBkJMz40oABINelujEY4qqjMfhzbrLnOkx1B+6vLSdXXBkP5KoA
h7G8Cw/8yNmWpIEaZUgmhSBb5W7U4Ev0XwKANzCkwkigwWxb3W+IM+5Dc+bK7EDy
UubtIPhpO4RkLyvIIFstBJT2Jzpkvq6AGaHb+xbMmGOjHysv1rdJpxK/Ki6UJ9IR
XMFPl2zYLaHhndgm4wOPIFjR9wfm0LJdFUGux2KFFNNpkJMx8n5jN0U7ctGJ09fc
0lU5Id5bbBgzb6fkZfJhcSWk3b2GeYyWqlsGJrpmmy/Oz2Bejfj2QrHToMmN19u6
qgtawENHGPb4XDsVMGjg7g==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
3HBOX/1kOYUPCBM1sS9TTYjyLHiBqbhZGYwQYDtNFRyNDYNYNKG/jEz3Z34HRjL6
hT4GSSgBZKH5qP3wUtC+El/ysR2wWlojVDTCD2fb7n4hx6JKkHnIPG39McTMK6Ya
MVwUvYMtc+gCXpzAS1p/wiFvyVMOoCjMOo+RLqZTmLc=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
l2adzISlbQ+f0y1CCmfN+K41aEl6+OJtYRCePKx3J4VR+j1ksfXxpVtR8bv2BXCn
AfeYYq8FMma+B6fAY2X0/+1AYTVz1AlyfWN7w7oN026pcbmNLgQRp5s+CmVMLfMk
st8c5gKFo7D7d5GuuuO6/boZSG4ahk2wgJqCEa89yUTjJQpcH0DFYqhkareIGUY5
jg+Y2eeiVOHUVO0u/kdLx+xZ5KCozvbwYVjaj4tLpeP4UvS+POyKSeb1Ry0Npk4p
88Zuu0ESsra6wi0KB4Tj4Dyo6kQDIB4yde2m9k9fP0oehDKpR8jh9Wnj+S8h7ggN
4MzL6VtcrzrUj48Y/d9x2g==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
Pqn5SlNvbousyTkP0RWdkx8ApgflCe03XaCq8F4jwRoTeE6sVxwvLuUADeXQ7vv6
V+ujAGd3QEtzAqu7lFCm50th8qGBMPhf0BYuVESZhSnjdaTcxGjq10JfP9Qkv0wX
EWwfLjdOPAnKVmdEAVLpaM06SdidytwiPfRIMxYrhhcMXsi2t+tvrY9Grpf8xa39
9pG9iWUHWuaSFfXyontMgW/8yTy0Q4NcUGvF8zraRHckKybx65SltGZdfcKP3FMg
mjhwVGactDdLV2QvxfkO1uXMDuQKWKygKjiNSmardH9VoW36nyloPPKRzWVNDRRy
q0kvy2QJNeU0qQ3haWBFmA==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 3600 )
`pragma protect data_block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`pragma protect end_protected

`endif

// `include "avery_asso_mem.sv"
/*
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2012.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */
`ifndef avery_asso_mem_sv
`define avery_asso_mem_sv



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
Scg4xhXGnXLGYqjdp6RAeJTUr8Yvdx/qt75XstMNsDh8rTlSzsYHbWf/r7fu45zF
3qvxI8o6fONci5giYkXXeCWzcOyAHRRVBRSYxv14TpdE6O6oFtofODhkTYIP5ZIb
jOVDo3j2NR7yEjbxpGBZOUeEKR4w01mF56AKoWHBSwg=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
E5fVAmIrzPv1xh3njBA4xA8boiEUCUQBOvdG2o0ffxBcCTVLy3vj6PX4nC2t+hi9
Rpz2nKwnEgovYge2JA+JaD6XFhLWUv+UKbqApoUdisdgqn7+fFo4vLSkrTGRtkcp
wOSZilANOhp7K5PSEU41zNAdQ8DdKbKYmwg87SMRtrc=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
lB8Kn5J/ZBxhFulNRz4JLFSuu5G8Z50q6F4Ypqt7+4IybId4PjuqLZpA83vRMsg7
kjn9kiKNumzMBwNktEQ5rA==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
tGQ5B2EclqC5bX4uiq/kb3EcLPmhsugNeneWG1pAeYmoVYoX5c9qjzmzCmtrQPD3
5hvK5BfISvnMmINpdzpIlpmxFahzqcAXnMsxrzdyGsCRNYfaAMkVrWBVlVas5XzP
y+Nx0UP9L7qhDYNlr0lfW0y+hV0qOGFx1SUI9H8qgL65FG6el0tuJkcOVk3xWyGR
FrB3ipG09YMr0l3Gu/YQtQiuxepYDSqdTb01nix7ikl33x249Oju8WO9L7xkcz7x
qf0XZ/oS4ehT8nxF5gcZf3Ry6sR7Rtiey40Hyw/kf6B56CymlN0br8JR6hUM3+jl
tSZ01xqG5uYeyBh+4McW9w==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
nM1XUtiTgRM4V5feoLDKjuvOEuNGD2OEcoPCgg5qLUDBJKqmmCqZ01UtpNjybNhJ
Z845cr5YcthKW4iTwwi4wH6SCp0yB8EZ1XDgrbz9aba2NQclWlGt6t3IDX4DKhhS
Ov8zVYPjyP3LG5kV83QWiAMkT/38nW0YyiEnjZ79SnE=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
AaWKkda4r21jlGbeP+vZ/2A9QlZ/FKIcSQbnu945icp8+2O87QWITToie4W+32me
vWx5NDgdBRX98AF3Z9n5m08KuLK6lfe+W/vh+gpxMAxvLxHxEUIot+1UGuJhKdUZ
E5VoT1ViMbdF5y9rSDthCsJm6f/UM493moY4HZgkaqkxkZj+Qp3hEUvCEeF9hjU3
vdsM5vB/4qXwrspNnSmJuIdGDI5AWJb1ObcxCHwzRcwM08Gb+kbpA3Lzw2K4+rBF
4Kzod0pY2ecbyJEelOoJzbZy44ASBljUJCMEG2LRSau+1atcLn3RE6WNOl3kzYp9
nWpf0TzblVChlyZXEgHYtg==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
hvcM4hkroRKm1EKs3n6VyvJZH5eXsBOxgFNb4ZYgJ9cpTbWPllAd90MxrTzQyIjP
ZZaiwjA+cN/mk6ntd+U0VgTxdNJ4ezeN6K/+GAsn+leVB3YOjC4XNnZmaNhm7idV
0z02bpQwL1bxN191ndy0IB/wSMVPlgSnvXSUWj+kilFW/JJcU0ajkebihuxP/3M4
tMY9ql9L0BaFpuGRStNVm3IKxFX6dqlQeUCnsn5MaT4LlplxysKGncpHt3njObSv
+iT63PW2b7oUGJNScbQwNQgZzTDaXsyPoZx4p/kDgIidzdLIaNRW3sufNTqeEVkG
+53KrZR0UxKnWeIoCtCqOw==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 2880 )
`pragma protect data_block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`pragma protect end_protected

`endif
// `include "avery_mem_mgr.sv"
/*
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2012.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
hHGhaCjj5oWhsjJgU1LYI7gE8pPi6UznVRcEoZx8jcvVbYNckSy1JC6OPyQ+GaOP
6NzOV3pl0mO0E2RLauOWrxhYG6XJXK3Dgsj9vbH/EjFaY7GBuUyppNX1Nxk0RmPf
QRQmGKsPWeAFfrO9xQ8BuRGKp6byN+0W6ZgNNefQEoo=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
nscPjAm52wRHO/cuYw0YKTy8OXGbQu7C6XVNmBoG1D6kA9ykOl+HU90JU7kT8FSf
u18oqmQj+vY7pBXw8RUFyezRAqIX9CJWlmFTw2VjMX8eynTrs61vkAPhCYAVHRfx
xgRqIjnVQLkHDAhVyLKzngUG3piCdT8ABp3S74+h90Q=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
c3hm5ktgO2b8oOqCPN9IkCIb1VLhTOg5puPDu4HS9nz5gid4mTpePeM7LkF1lsIE
Nbi6+/8yvUkx1ZffJ92LDg==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
ges25yPbwCnV7K3SN03/mlmBm3UGyzW6H9O4AWmZGkpOZDUxSuTiwL6yKtWz2b5W
HozKQ1t3LtGWmeV2rbzDLp9Kp01TbfKZmkTtBrWS1NJ7P00Bzh2ZQLXuHnZKD6uw
TOEnQRceH3FOknE01oZGYfYX/19HEbeLUow7UFP5TxoCm485a3TzuFr4xYFbh0BA
z3nQA295hKPM4EDySHVxdVMHIrDooXzRN5Sw7UVHbufleBzonMv4xY9dJogFZT0M
8hmIdxrcTAbhZZkJTt9FE2BZ5exbtUgYx1lSn+55SksfkU567WSRr52egjCOGAvO
awgi2nPO+3w1NBGyqoM4zg==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
rOMRhD1paGUFtvS87vli9EOjDeprF7D22LELncXMnbW1ccu+bkuopXJH+WtOkFHI
bS2DvZCqZF4U5ZPvoxwkOcCyknk9PFs6RKz/NGG/GL+37+ADFpNSZrCRUE7J9Hp5
l2q4g4lRYAXwLZU07XKNz0d4OndE8429vzL8wg4ATMc=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
FEn1deks/1rfUVtHUZSPx4ixw7A5iVWGkeRW5qruO9htfCQXHv0cTcKPVXYlYqe5
+72DfFoDbm1ZEa2ztPH13540gZBnUrPwFCgQPNRQY2UV9YiH5J4Chz+2CPYFR+Ld
avWA96weXv0VlolyDRxpnTSJKbFdGeuOQOBjjYgIqPcTuNzH7Vt5xzD8MVtACvrz
jW39fgzVemaPnaRihKfr2clCFudh6y6QF0EnHtPaV3qF6t+bXwUGPSVoWqFJEprD
V1mzM/U57H+rE/bcHYPaTxmfAidxDiSlsuXrBuasEkPvS5Qf4EVTFaqwG90lAF6E
3DoqlOTshRIZfNduI6J8DA==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
J0dE0vYYP7DnqneUA05wdw3O9SbKQc3qT/Y5XrpWTx3fdkOb1KdvFEI7ANTLq+R3
kXbkLMQ8vXA1geXCBf+qanWzaQG5BDu3XZ1+3q/qvfCpIfj8Sfmn5YlB5Xr2ddNC
80UxXLWT09TVXB9NVy3Kqr4UlynzU5x0DNLImYzJZ6Ewiyrw3D8Dsw79Qhktb5Yj
r1xLDubvo5SlMAcN2lVZkgDCJegDlgflhicbLUagTby/GGVAE3Fq5TfcibX/ZsLO
HehqbIkLsKxgr2yQBesmhrsqjWsHv6ZXDqW8gTxL7T2X7eSfRE91eMbIXGo2TRNy
cSZLeGJ2Rek39WLyYotT9Q==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 16432 )
`pragma protect data_block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`pragma protect end_protected

// `include "avery_reg_mask.sv"
/*
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2013.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */

`ifndef avery_reg_mask_sv
`define avery_reg_mask_sv



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
nbdPXwNyeLyX4VgHYhSRq/YXlSVavAHaXhjMCstOPcWBqITbId0m+WziVY06hRDN
MTfHLd3YkECNA2hkxB5yzW5x5JRTMDYF8dnWAR3d0cuqIZq5nxZp1GDPXGbTK1Pw
7KatwKUwfiOM5SfqiwKHTR9GE+iD8FkKnh2DZNuYMWU=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
Msee5G+W1qpSOJTdJh2CEOLr0/cd0aEmwdfz/xHYKI+5wtEfByuksl6fjWMprj7B
zXrdmCLSoBjsXx9oV8DIKuIikqmL8BJeqiSzg1B3SXYRDDTG4Tj6cj84HPC/34tf
OLCG7oflUyF6MjBfirlSdbmguqZcFx/XH0P8qa3agmQ=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
lRnn9Casp0wFz5wVIfWAdlceVIhGxt+pvBk7xZi79BuoGpGXGgQpOYhLhbFtWgSo
OLYmA80pxruvko4td6I11A==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
fsunR4g7VgtMGs5v5yOFoT2OgouZmjDobrY6c9qlo3qoXbP4CSRxwLt761r6snm8
q2KW+rgTqQmW2R/mBk4kmYFyRCjm108bSo25iGQ9SoQeoSA4ZpIKuAgMFBOqsirK
iEsJ5pjNpMC/E26X/0DeCAHRls9S4cbZV2wxzAVi4a1Z34uuQqOeyWkvPloY5QT1
3YwIZ+N3GuhqYZLp5DRgOfQKQ8G70ZQt56UUW0VQJNu6LK+Lm4hU+Kc75khfBWGP
QUO7J1ysh2dlZuXK3C3bubLrQFcOVsYqi3Bci6s0YWbV6yZLuSQcUj8gEM90HWNN
1ujIVkERiQ120THFOe4GOg==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
SYce7HPzJcRO4tNvmpPdfE0AvKhFrLdQvTpJLmGXRIwKW/ilQP4hVsgf7V4K2oLW
5DvGi7YbuoI881yppEOp6XZ6WHjl+snBVLLb+VbvZEQPuv2f8rI921ymD782HX97
jhO61ZNMyp3qIbtIx7C11S2s7TqT15tR5RUYeJNEj30=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
K/Img9uGadYb0BSt0aBaUhVNSB3y7e7I38g4bpLxIhDTnPML/1TSn90ZUotEUTZT
KlCbS3U8LhGHhEU235Sej0bJe5VFMC1eQRjthn73BE7YTb6Z6bhMIC/AoOSeMu15
WrISxxLM+qh8Jn4Xo9TM1VOd9fzJkjcJ+EY36chH1JAjhgW/SnPLJNKVBU25+Luq
n/7w56PwwkJw28k3rdzF6jOW4z7mhrV5q64yMiQCZ2LKGmpYL3CoPqK3Oi0olJUQ
Junmb7buZHuTKznYchWWSKakl0HX7qvLcrYATWSrLn9o8bog8WP22HVbA6CEeUSA
mMw+N4BZyRDqIXI+hVE03A==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
rl1LKh/Wgvp5Klqgw7NYlmFiaIiFIwNzCczzEpXxl8Ksezih2GUo27nF8tum420f
Q2ExibKkG7KpWmnj/ycwjW1WUrp7JVetWuuNCvSVBygbQkUk0qaOzDu/Ke2UYlYP
C3mmrrapxdoSWMYq4XVYcTJJRVUFpc7uGfQHluzENlfT6ove+wI60JAgjMF94V/X
bicDQSI1Zl2HKpg/xQBzgBTMNnqQbeNjulzjbNNXey//S4PIhjUCel2tvNb7F3Vt
nXTEDFsAtv7z3m1jg5JKjHjxlkkhCGrHsDbqFsJq/LUeoH3KM8JbFl82Gg8C+x9O
QS66khMP/eZY1wGQDY9HFw==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 5936 )
`pragma protect data_block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`pragma protect end_protected

`endif
// `include "avery_scoreboard.sv"
/*
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2012.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */
`ifndef avery_scoreboard_sv
`define avery_scoreboard_sv



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
gUjfOnos2YsJeY5jsPQp6HiFAVNkf5CJ96dQQj44UMiXEtZAjnAr8gjQ2cSzHa+A
1tpk/CokjvUTxEkZihf/lYSt8M3ij3BHLve0wpzdvFJJSGqm5OZ5CcEjLN68dJQ3
B9ASHxglZp3ArRqJwFga0ObzfguTqWD6HZHHneewTSs=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
ojNeTQ0A1YJ8bNqAUhVaY6ScdTqH2eWHPib/jgubFdPCBFC63VB9LXtKjeJ2Pitb
6ykZJMX7dx0iFwLvcg7/XfLtoMoHTbKZbWh9vCX3UbrRpXJzNxFQdTdxC7LLxVXl
qGBsNHzk+F/ZAJD3jGoTSguuxdE8cl13xFFiKHDMuCE=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
pCevd7GEeHGv08qaMIrVb+lFbFfWPKJbGEC/pZeE4GPbIuEPX8ZiWx9sKR08JzFX
Lm7f0WeqdewJALKdknnapw==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
DNneOIguH4QzYRi/UhldJZlym0T+bHRmRbDdysFv5V1cmaKt99iqHYffZwmtXeVU
FPt3lJRdb4lSEPE5yutocgcfubSGproJfWg8x25Bmq0MCCV9E1j7Kd2k5MsRhFn1
qaCGyyMkZJv/BWSjH3RqyTuACEXx4wNUIpBf5lnbsIaurtVkF5xlhdIIcpVgGmTO
IfvsMnF+fnHAgBVM6TwUbc+biQ5itJffsybFOK5t8JDAnIKaBAsES0tx2aCLCna5
k+HpEWkRGG8d5Pa83+A1MB/H3IswFRGVyQlOG46H7/pCP5pmQROl/AjRIWS6lpxP
4U5RONoz+JvUEVYA9WDBSg==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
lDcppT42Qr4DeExc9tte59q9OlhzSGAfDB9NTkeuRDmY29dtrmtLCkKQL/CIbSGS
vTahv4nyww5Gp/tsIjBo9qIB1DCbPQLQ8yRO8jKAe/iYn3WCbHcbGa2O9n90ZUsD
sV9s9YXI/D1ivW90W42YH8uu1lRxNHzHlg7WlgQCPIA=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
sTafNE/ITTCqIuUBEVkw4j0y2K66Rs4IoPqWvKqju5hf2jHy7z7gUk+SiafG0Xiy
LWHz982iTQsQizlP41Cfb/rFpHkELyyJRiHT18gBzbSxPZDk7ruguJ4vs80Y/hyg
jSBaT4KC/9ePCrYC0i/Fvu3St/mP65O9pDvqKQF0uG1m78yRJ0uBLUhAbWE5A/hi
Wt3B80XcqqqTR2Efq1I++mCRs2+E3Z6xm7SmwWfi8uyK3igAW6e4RiOT73kZC+NM
V++4fc1W2ED/TQ0Wz89ZFp7v4uotFnN8J2YcpYqDe30i/u+Rc28Y8BcKeOTWnTQ4
qOS9ApVHGDiui0ZS+p6RCg==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
RbsTKYlf2X0dZIFaWYm+wzi5w9+2LOXQUhQrw3sNovrWbfWokTN4f7P8GEWpc+b7
9G32omMp//BCIoQSZ0da+xV7/iwOQfL5Vh+YCSEkg4oHcZsKQKGJt38kyySvaIUs
daAQEKZ+Cm+S/f+wXLhXZVzeqyPjwgLHdpA0dG+ovqGpcxs6xrFldB4bWo/vT006
Liim+UHwkiR1/9wFlPWxi0bwBDAzsdW9QcOuPj773hvjyRZyhhZOeg4ks4HhbSD3
JgwfWmYLgK82rgdPy8xpzwNhcus3XaW4C+z+8DyCTJcSpeBOm1ev2wNEjArrTLTr
pZwEnapINjc0OsxVpQXM6w==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 5712 )
`pragma protect data_block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`pragma protect end_protected

`endif
// `include "avery_fifo.sv"
/*
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2012.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */
`ifndef avery_fifo_sv
`define avery_fifo_sv



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
TGqj1vMNzRUhikO8HPt7Mxy5EYK6LBQve3SzQGsr2BDksGSXWO2BXmYWakuR0iVY
5P1r+K5EZaPdjVWs+jxZ1+XzwppiJO9Ct7WeUD/f2iiox3UDuaK4cm3NUa6qjaoU
JgaCL08NEWRpFoJ1/GxbCdiMXl7s2Wsto0PqxCXm75U=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
Jg8mpa+PnuQ+cGubEUcb5nzFcUooh1IAYNDDEMrK3+uHxGiZiyaC3T8/OoPkKpeG
cwgUiB/PoHfaylM6agkHWh5SmNHL3HZxwonvpTVX4l36T387SjzCoxrHabg2ESxf
3ejB7ZB5AyT5BAOQ0SnI5JibHOq19HZihoKz86ju+U0=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
q3lf8vWXs5Gtc4/Ju97DIuGTnBW2IhHt5htHHw89Rt6NmZjYN/p//nDB1oEJBYsL
KwEz7a4hh8Kd9m+G9loT0g==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
JUVK0gZm2sGHtRpQtZvmIoVHvyP9fEYrscfaHcNDX4IStlaATJCSUgonZHUJKMHO
oFeqHJVXXtfb9KvdOYH5dJ8UP9e4N8axzcAwW3i6H9IKCD98syatFLZswabQsjbW
8ksUbno0js/82kgiBWiDy/40ClppRWMla9zvHz56MV5/SovizWB6OkO5CJqNUViS
L6HM+iMvxxJcWXjn/eQk7jEzxI6ALsgj85sWJkGz//UYysAUQb7qXAi//62UYRo1
Sm8ATQUG4qML7/8hsezUeH7BgRiXgxi9eYZr07ok7/0G3UFvguyX4X33Q87V3XtC
ocdC1GpHtccfbPxR6v385A==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
cK9mrKej10ZtrjXN6a2pmhJOfIlHzNjQHqPvukUOePxU3NSu37lQbR48gJluHYKP
PoCThhLnk98PRuWFh+to9ZbijztC9QyeIhvcVIykT3Ufi9e2b1BVQCn8W/CHv+3s
RFjIeWF6uN+Phyx7GTVR6g9sSv3XMYHBHDWAcIt+LN0=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
pRohj8ygJRWeuS844vEVRudQFnTXbKPrvUcIPL49IMfxslQpI1HsLuLTKqL2wjTa
kr50o3tsk4enTMTi6U/oCYjd4pwsEMIsJ7o2rsba7kGaRagr9GfQ2WqWV8b+Gxr6
GF28lpQOeKzT6aBz48Le9vwSImdMk/j2uLvEy7GLgjbPhV31TVVZu82l9QCYb+4+
EGjFmxJmYkmzwcpWUaET/2drjg54Z4GPL8NDWFETl7r0ZeX7M94vnIuP282szwIx
TdDqTrwS1iBrhA07/qzU9SfKQ4pSHTr9mCvfDYGAqwSPSfV7iKoAom3jtzcpo4J7
E0DjTuY4fnXTL3F2uy5beA==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
EXyhbewW8ja8OQpjLhXkMOTQOpfM3TyieE+I7Q90pxW1tx83hMcHRF/JCKpc5WLe
gNYsc8RL6GED2tbor3RHCZynQLzAaStHeFCKe2UYpCD8q2pEEZj/VT/UKya9MInJ
TAfYpoUqhk0GnagensJD8NWNFh5l7jb0+uNYFeh1VD1T8CvLUH9GKPRI6qK/jhoT
12yYqe7QeCqEUNq7H28gHZ89y+pNjkgHZFXOZrBCaZboyxhAoQ5Y63xKOwHq7Kt/
oHoIZVM/ezEGPv+kEuB4zU54ysWE++UoydNGqiWy13de2gHLtbxMVHwusi9eaLPp
OGrUBA5WVMKhTJ4JxyIArA==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 1200 )
`pragma protect data_block
QNL59PTKzCDsVpSc+C3TiepCk7UGCCgt60KFIvhMYwZP3ykge7SdldhY9jOO6kgd
UDp+YRlxYBiBtN8v1e2FZX7MflT8v+oi0UdNd/9FLqBOVyn5HAy7bbsTziFoVA9x
CspJ/eXH3adROJ6rjRvLKwQ+LnhVRplkMj9dKYFobSPvYTeOPzw1p8g6qge9AgMn
Rzw6iRbqcXtyNhBgcLMDycYBnS5Cab+Ws9PX8Isr/otGjh3BYuZsEY6xSCgAT/kj
alTbgeo6MpTljz+4nnsuWIK1OoLI5uk/fBRdiCtDubzWzaoOiuSE+DvP+W3KJv6h
DiKIy2RqoZ9qRYbCPfiKdNIbvX+qgeaL9Yvd+nITIaVJLTxROaUyVnCp0Pjq+hx9
qzxucWbxHwW02pd6DYDOaxx42y1mGXuRh3BfQPGeRoDmxR0PMwKBsbKSFu+00HWP
yxA25L279SUp9iD59o57Kv8noHvs+R82b7YcIJvHOk/Mp3Bjk2vlZVY1kqkySefm
0qVdhe1DM4amv8dAcws9oJdtfsb/dJJUMrs3XysRlLVYRM4UJ9nebsgOpMgYdOw6
TFPxskEAuWTDnRZw3zO2PJrrBIetuXI/v+V9HjbkAQxb9O/DR9fiQR/LeDPEmEGk
PwZZ1MKr+egUfFvIODtxeOOJhbILYFIF2T4NmJnqAf5VzCPR+lWfzRt957yo550J
C+R09evimpE8elEWl6C46k3/nwl0CZ4KE6M64N+T7dsHpcPojsvK4rqUJ0pkXk+6
j7sDjdSerK67r/OTBqPX8nitwtR4prv6Yc1eOKSvW6ICF/Aw8ZWbhRAY0yhilgRn
u1e4kTMgoHrIHwgw6EM0R7TSW4lM0r0BtVQm+/MxgT6Xa0wRBUpS2ZyDGkGNHQE6
X9SUkFT4xJ2/oO/OqliI3W8Y9E85kQydI8mym/hd4rbYuohe2mFACzvNzOf2pWGD
5KddDWvUl59DRLhQ2X39lhPXUX4CxuUyt9VuAbGJfSjFrIc66Cw7IBg6vkvCwOrr
HF27MSGg1O4HCS9ZgOEJCJhfC36v66UDrJ0d4hyoH2Lpm7wown3cSHKyxSoaLpb+
aLwfuSaZDUYRbp986aCPP/pXDItB0JhSvfT1qq78CCA81aYi6W3tQWNq9722Otym
6lskSdjvuT/XKq8WFYDDZfFmeU7fyniGCJZyZV5gylI5nEHRVELnfAeW7xbRlFHs
M3nDCNPT0iS38sXUbHlyhYekYDXi4w8arH7+AIGkIWZGBar1iCYVe1r1hPlpyxOp
jY2zR8YqfSNjcObJzwhXDbP191BO8rgowjIRTPWdXxdmihkPgFnGmYrYxHTIbQF+
tVkXeVEAIee1FUPcJGuKw8g/pmhEbG+Nr9l0rXgZ0+v0MZycT1gw9cZtx69nrS8o
j/O97cnfWuGz9SOHKDie5dqkkwCtlgEQrl+AstbxwmWYpU/zI0zzfHcUpp1eToq5
I3+1gsBF45FtQB6pyXOTgk1S1IR2Bl8AOXYQBgiLZBvR3GZHcmckLGb1P0W0i1py
vysjkjdHWZkC02+A+rqIiHrNArBJnsuoaUX89gvxqJihMIJdxAC7DCJFqtHSGLSb

`pragma protect end_protected

`endif
// `include "avery_rw_data.sv"
/*
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2013.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */
// avery_rw_data is copied from ddr_sim/src/amem_rw_data.sv

`ifndef avery_rw_data_sv
`define avery_rw_data_sv

class avery_rw_data32;
    reg [31:0] payload_dw[$]; // double word

    /* function: new
       new
       - isw, if -1, no data in payload, else, fill payload with constant or random data
               0, 1: fill the queue with constant 0 (1)
               2: sequentially up
               3: random
               4: inverse of sequential up
               5: sequentially down using start2
               6: sequentially up using start2
               7: start2 without change
               255: all 1           
       - total2, total number of bytes
       - start2, initial value for DAT */
    extern function new (
        input int isw= -1, 
        input int total2= 1,
        input bit [31:0] start2 = 0);



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
gD523MU3qv2duOjXUGgpSGa0vaMRgVL6hetK5/1icH6igiYxsjjOhlnTsD27+J+H
eHk6n0I6ajZqXWCpeLjr/TLtaHUkUR2pFFG74/aFFhjmtaNamKnOoPC8jwgkH/Qf
AGE6roKRE712i59/Ylz4jvUV9HUDe/EcWTD3sSlEeCQ=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
x/8e2v8VEi+gGAMzDYSWPYfPjR97JhNztXnelvmLh9wk+i0zopmD5djaVXTEOuYQ
+tOdzaFxwPjxfFgpsqyGDwqq2341Z2PtROHaBOvW0ecypn7mSLR9nxs90YYBVf1N
NicZTGvNpSQup6xlQMv/DyjL+Xit9z4KmSuBZuiegxI=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
UWcAHzNugsJc+zDphljP9VaZbEiSTvO3RRk9NfYJ6VtfYAiguUx977ys0co/KToQ
fNbRRQYdelvWlgJo90Xftg==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
SN4FxRl7giRGo9km17s9jbLk1FvpkWIOIZ/yjKlDLdu9S2yz9hdPQyJcO3VXOK+y
o3swYmT6/aMxUrcsPDn5NvoZQH+N+D6V49r2zrFuiy6iqm4hXVre7wh6e3pW4RY0
MyDw+ow6NZzpSju+Jb9/SWFX9gefNAmMfXMhRElR0pD21DEyv06VCAe0goLrqr/i
3G+E0fn4e+1tbJJTEq+i8T1EWaVfv1/SHQ/P2J4ovV6CIsX6DJ49Emwn4BAFHDeh
HTDP4XUvTe/vElms6E4hw7s0chCiqQ5zOPv08xnK71G3jrVVEIPehl1vTvbK7YFo
tanbbaOuS92sKX1lI8Yxpw==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
DPAwKiDHgDbCdgY1JJBiTG90bpOdk8V0m9Al9NHL6CI6LZqCYb9ZyjWRLdmkygUb
Q5OFDbZOOG/c5FivAQ2Rrb5pa86s5h5rkioLn6mgNpc1JAFfg7xMOnXNQz/Cpykw
tfd3VT6hWq4RW0o9Ps//RrUpMclui+I4+6VEszwBpWA=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
arx6I+Pbh4AjIasrQXdvgujGN4TU/RpXW4aNwoUz400mNijB+sh1+jQ1D/6uII+I
cHMLdH25lES2seBLwGQevrlHoVoPw9J+43kh3EbzWEr3GBMm19cPBVN4NABUAQzU
Da/qADKeZ5pYUDtptH8zCN6//B00MtT+vmgH/UPvDqK9CBz5RLXxa4I6alUu4/MH
Ai5LA/Gdj6gMDByafOXiCK8Xydt7S2KJAjLyLOpsEWBPzxdQT89eWkK3Zc/29FEX
9dWyVTrCjxw0u0WBB/QKajVSCuAp64Kgl+XcMNA/OG0C9UhMHhJone6lYHqF1d13
Xg4Ls9ALcCHOq0qeq+WVxQ==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
KLa6o1qE2KmdkyDro41PyoTphGHluVEgBY82xVeC6w0rgv04ZQu3iMcf9zmjqVa9
rgp+ZK0AfnaY5FvVgiId+n9IPu6FLRZWoAr8DdW84M6mxRM3ZUS0ukb4znqI4QQS
Aqj2T3rJChLz8Wizzxmwg/3rzdiPk4yKJH3oY/CDg/Pd2OycCXaU5Tontq2okeXK
TINSut5CJnNiEl+JZq4obuOu2QjLyLx9QFF9jMnLCwnL9Je8gc7ugYVU1Jr3kee3
8iMvphwrZibQ3r83TIqTBcL6evlunjr+jqrWrl40+/i2Jdp1aDNH9c68h3dsCda2
RBP1BRBZZxyAoYK+otfxbw==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 6672 )
`pragma protect data_block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`pragma protect end_protected

endclass // avery_rw_data32
   


`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
cSxt2x9aWljACGAwwXbTxlU7uSUoK7omjpGecDzy6fm+AlV+EMTfX5RSOdK/4WOH
x6UoJ8deccF1ZlY+TiJrYlsZ9FFDBPc3QlAHfFKTt+b8CcWUXqUtGk4ChaOblXzv
Q2t84lxj6tKo/v3aciBezSwIzt/ooq9lvknMF8HHo5o=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
e+ZJvMuq4M7GxlnE/r5Igs3TgMv3PXXqrk2HvxcJovd4OtlbVzStiJVh/Oppe+iX
RdVQnQDnaVZ054RRHRz1MBIOEE+mo9XdMzruVhgKfE5+NF6/pxDAKxbE0ozEuJ/N
Uz1Vn6fGMs9HdtNHBxjKxjjZkTuFU3cilqL7sMrzzw8=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
FIJf96I/JdIpdjEwpIY9OR04+R1zDkVh/2VSukGQjZQmhOP1IZ/oOKAc1yXpj0QF
qCPznOy9d8XIk2lTN8oIEw==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
1IjCYuDQZO3Y383Pl+xubm/mNkpYFer1e6OFYsHIjJ/piJz8Yg7RJGSdhpSuyj/w
iHy5hlklqYI7cJi+9b9SpAh4jNjWM5LH0lwMvujXLTTrrpCk4EyGbUYNSFp0+28y
066raE9TUui+LsA/rlK5kj373xDBJYCrUpYSEnQur2IJclvF0ShcFX018CVqzMqN
dBpnl+NIYgRcNDjEoMLJVCr9Qpj9h1SEEKhs8Km6Oe5UGcSkpMxStLKShgUGjFjy
pFR80a7c51XJ/p+6RTbKOowb3EeeuPl1UJXej2JzGisiWVt+Cg5xtCcygR8DtXgj
xdTe1KWmPYQABIB9Yin13A==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
P6b/upQXdo0iCVADyVznkmp51dG9yXDxCWVOFNQ+sVkhLf1YmN2x2W2ImYa5H6XY
n8WyPwq4Ng++/oYOzCj2/qKM6ZNn9fYL72AjK0JZOy6IoBAxlALCZqZvB72wVWxK
JH9fnBmAGIjVy4l2bLcZpxchyOH4yvJSFFESCqddLKc=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
FuYQkxqUc9jRtOQofBxxG0vJEF39yRO7TUReE3W8TbQjObBaiKiMcNOanJ8LSBUX
CyIGvEyKzcUK1DiEdpRv8kuZFm4E9TRYCY8pGEWXRy0yMLdRhqWHY/+TiBRyGx06
cGhFEijC/BGX8K4knBr/0SMPdt98WAIq9380SNp9P4+mazyrE3Ucxy0PzZQcZt1h
rLloOWiwa7fzhjaA77e4lcgcM+GpXw94faJR2GKoIFfSpFQLa0GSP3hoJR9HKY46
6NWFgo2KYqyewnP9xcH1RoRPOsFgbrzHRyr5cLZedVHpMTP0nxmka9tqVDTEN7CS
zzSIZ4tH4kCcdFU8mOKmSg==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
gNb+vES/3EE6u7uXEm+l0ogAtj98ixzCGYPydnE8MgquBRL3VwU2mk9h8cZm7Cch
QAmKL35jxjwIrAXVn2cdRaRlD9r5sDcdUd0XXL9NMDStpenBIeKnz6SrJ9pAeXBi
WQUcu7fFz25pKNaM9wskApE39rtuYs3AemDyKH8vN3S6yPrqUeJQupva5/vqpxYI
coBd7E+eMbgz8f4SBGvsRcautvv7CUpDFLhmu9gtUI8ni4fs70is3bHnulUutZAJ
ldZg00Dc28ICKgK8VASaTCdjsV9Yy5qU14BWg8SbEhvyUZk2lFarOh1HC0s70UbA
ChSNxn7OEEdOcPG6/jXdxQ==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 288 )
`pragma protect data_block
QNL59PTKzCDsVpSc+C3TiepCk7UGCCgt60KFIvhMYwZP3ykge7SdldhY9jOO6kgd
hoEMroIz6d9m0GKJLOXJNRqF6jrScfdaiqLrFc1slaWCgxENr6sDIFUZbvB2eF9e
AaJhLc7hrK27bNZas2inYCh9XpSufKDqfEUPuvfpqheFtxbgAQ2oNc179xzFFcvN
yVeTCgsFtW9zxZsWFQtqcA2l92c9giVBS3v56k3zinS6VTMsj4s8850p/epuKdL1
pKqhkkj1gBbTiur45eO6Xgsn0BNrHHnQxX9X6Jyfyv6UTbyF8eiw4qhIWEUVMP9W
uOB+IKaoCawtIaZTXKB+aEG2I4jd9iUuxK3Hlo7idYlOn/Bdmnrib5jR+EnBU9dw

`pragma protect end_protected

/* Class: avery_rw_data
   This is basic class for read/write 
   - payload [$], reg [7:0] data payload,
   - payload_dw[$], reg [31:0] double word data payload
 CLH 2019_1129 I really want to phase out payload_dw
  and use avery_rw_data32 for that purpose
*/
class avery_rw_data;
    reg [7:0] payload [$];
    reg [31:0] payload_dw[$]; // double word
    // Simon 180911, it is used by eMMC/SD VIP
    // CLH 191129, the proper way is to extend this class and add those extra fields there. Otherwise, this class will contain so many fields not used often.
   
    bit [63: 0] rw_address; // ??? CLH 171121, don't know the usage. If no more used, it should be removed
    int extra_argument; // ??? CLH 171121, don't know the usage. If no more used, it should be removed
   
    /* function: new
       new
       - isw, if -1, no data in payload, else, fill payload with constant or random data
               0, 1: fill the queue with constant 0 (1)
               2: sequentially up
               3: random
               4: inverse of sequential up
               5: sequentially down using start2
               6: sequentially up using start2
               7: start2 without change
               255: all 1           
       - total2, total number of bytes
       - start2, initial value for DAT
       - is_dw2, if 1, double word
    */
    extern function new (
        input int isw= -1, 
        input int total2= 1,
        input bit [7:0] start2 = 0,
        input bit is_dw2= 0);



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
hRi6khK9k8WI12VPmaFvOVuzyNPsYSVTrxodGw0TYzu5dmNV7wR4GlOAImtCPwY7
pBCKZIyD9KwG27JVMwS9X2ce9vdU/7TKzBVEdjMFg8v5MOD9zearX6bZiIt5zLz+
Qd06YV+4EUyA3fHJrb36K8nz2SfR1WGoi2cqHi4iUbk=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
VqZFcyEgoJFwtQeYUwwtzz5AKhejDeEq3Ju3of9YPBjNTsBuxXfaIUIQGyjc4zY4
OlKF/3JzxCxVeMRA18UzxtizNidGkyLIB2b45FApymfQuNJFlVOFzSZd2+AfzaaD
vZtXpM2INEjpD3N3iC/jkG665y+AelY/WJYVZBG2wRM=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
JNj0M5clOXqsxrXg8bg6ABb2Rr6rhNY4exujYEBzzPisYwof7SVO/ej6JtYfUc4s
n0AdGYZL/Y/mQBCjhSrYkw==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
DlrXkuuXe17VfFECCgVAs45AstRbpA70Xf1UAbLReb6SiM5wc4xe/Qlw9gmfkwzx
Y1O7WzJ7gaictj3wKhH8A+UA1weKmQEk2H2UyOjgqDeTzUmpT15V/5myg6ywvTGt
7a2ZNayA7eA1ObKPrYsFfLN5rSQw3SI/s3M5j6MsC0ee9qlVhyD+iNWBk49osHyF
Q4fseVSAs/G9fJdvJn66ifbLZBJN4PlcJf8+LQJwOFiS4xRknSw1Q1I6Bls89Qd+
mP4+ClyQ84A9+TdNpimgs3YyN7vVXVycq6Jyc/4TdB2Qe8hmNSXsj8Viwd+xHB2h
hMSPnbHcXcJfB6zDe6aBZQ==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
uLJdGVzI8gtQlOCkgzZUeCbCNpoPqFpinNYv56QP62TQuhAteHl3yREU9T1NEN/m
z0pMWDsdzkoLPADnnXNyOzu03oLz8g++FdHmZi9XpLSovlX2uRM/uBd45KLsQJgz
L5By9Imv+hAyvGr5/JCZgpPhhdBPrEcQi/yhxxC56qs=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
qfksDDnOm47HmTPdM3EaTVpMz4O2gRJD23k7YVYrJXNoT80j7Wlp/wZcaNX0HjUG
cINTmoC+1yC8uV4bTXQbAIAPNiJswLrkmglXm3JP0CnMRsSdFuednn4UZxu7s0lo
vyjCNqZ9qBaIOcKIT6BqKU5ZZmFcGj2TJR4E9PKt528WTrPr9rfX0eg7gFw/rhN9
X5fO3t9d86uUhCj3zfw4PwBHp5l8p2mXh4qT5GJEcz1O85CKbM1+wU3y2BGaizEe
ZlHDdxV5L7+BdFgX9+/Hwe5z1izmabvVgugAGbh/yGVih0spcjoYBnWTx8KsNSzg
qjgwAbyG/rsse9IBSD3GmQ==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
J7Qm2CsP+STNKR/+IzpQimF0h5J+lnNizakQigUk0SPaESbV1PMNy9joLHvhDzDj
CJgyUE/x5Vzo6ghVFOb7E0C/EKxmx9xTlsXW4f1h+lx1X6hpymyOZvgWBN3t1Abt
Zf8K2a77knFv3FB0FiwSNF6AU+y0LXZzk2vXp1PGOO3C25n6LJpvCytkE/ApMTg/
3hbuG+HWyIcaH6mgPmrtjBaDfhUGQiuj8aZH89J4qMtt9e8FrXed5KfSUQI8W+Yl
I+0j7BCPrf+niUMevqQg/fnxNCSwBWLDMd/Q302SvvEo8VBhs22oPVT6dpqyYXT1
4rR7YCixoPjd6Sv0RxJokg==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 10304 )
`pragma protect data_block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`pragma protect end_protected

endclass



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
VpRKLmbc4cNdrZ4Cy7i+Sxw4+LtVp8XpQ+FP2kvi63tpuJayFzICruOCwpit0xQM
yCJKD9tSiqIPYkSUDCoXwdETxiIxoIkbFlaPf/U5OUKCPfXiPkHP2bZ+cZs5JEVY
7LATZi+nVfV6mCcWk28O8K4LRjDnvuYn/LRHoA/Qfxo=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
KLctiXhzUyM2lxQz/ZXQFX0a0tdyeZUKdatGgYLYQDWNzhBlTlu3PcQhseLKpnPN
UC1/5oCmy3XbdlZfrQBkUmvDdaTUEtEJcdLhiN4Fg5c5Rvm67vTA+ldFKdzW+1xL
NvZT4ndiqL9NkwG0maV8Sy6Y8oK/bNNOhKNbbpvVt80=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
P4/bothlbVpbRvATyOtDiw9RiTqB8RtkJxC5gpHtD/Hz/NyBl9QilwpMF6Bo8oVy
docjQ9Z+o1wehcWU1N5Rkg==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
wHZZovEJL8zyKqI4nBSODtf4H+aDPTep4pxajeCmo6Qh7bajZ4EH8qcNVloiliZj
ouaDq2zy2ZmBjcbOYPqFrNiW6b+ZUUIZN5QgBCCEuULOY3C7hF9txZShsJk3D2zP
mg+6Itu9NUeQ1fDkdjitCu1mns3SpEc2vGCX86aWfuKwh6Xv0crFCc7i+8Ic+68D
SFe1Xv3eZRTzvEDhU3Qs7WrdgA0Kgmtpub9qKTyLWUOK84X5+mqaO/RPuGiCbwJh
jqCeJYDLATH/nB1Sfp3LkHeNz3VRkkQa++5D60v21TWnpopno9dVSYi0zPDcRVWO
krQRdSGZS8GrSjGeWB5i+A==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
qG1DAG6LW4sE1rdq+axuRO9vJp2LMLEj5QV6ihF94+22KIeV7/5T8mi7X0H+wsZH
OGwDRIPNaSCsp4fYAMo7y/A4KWRqaof8B4dstkxQdLkJCjBNzuCO/bg2axKoLNMg
mVDSQf0IbWqdUaMWjDYGouJ2H3pvJ/1gcBAw9ojhmtI=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
DJVj6K8amFGo5lvZoCSXWl73iGi+xEFxUwh2SYoIn5dWuHQwKxcbA/QkM/S85qvF
KkT+pS0CYldOXywJFl0SMeEK46iBm93ozfTZrvNvr5QrBuKtUK4+wpQhdgiNCv9I
YqcOgVSMs4JV00HGKXADbSHyLpXtagtuNzXKDXO8J+3Uru0Crv33F3tjCvN4FyfO
kNYi7T25iaR+dgakNaWxmT7AaqKguvGYAkt4BYsoqbJwm1nn5gkJoBkSq2b16zQz
Mj6siwltx2X6/DT6YtgdydyHTDsWqo2k8EpnnwWBiXhqgKwZdVARJRb17kDkWqAW
W1gi8Kz1FhLpXzqJzwmgtg==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
BlcoDY0V/qAJkhCvYmlBsc5LGhmuESdmCP8R4rAy2qxFV8819lddvCzWDAiQFoHC
s+W7RVKxcKotJyfP4R5INa8XgCIXuOnE/qtyRGFsLgefEpNJIsou7lsDOHeRR9Y2
4lz99CXDPZRTpdLWZxOqfm3KME2m9ZB4rj/2Q9k5EbCnl2PsjZUjabDHB8ysBSM0
A0/PKR8xhqQLoSWFPb9vEZdWnJ+mc44YZNLmoOeZt0rpPu6w1SrqbrYAFLuW+RlU
NBy62PIvNwMFwzOvoftCuraUMUKreSoqZioOx97hHEIa4KCKhhuE+5JElOPc+pUI
+eUyJrazSHYUHFtNS00BjQ==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 320 )
`pragma protect data_block
QNL59PTKzCDsVpSc+C3TiepCk7UGCCgt60KFIvhMYwZP3ykge7SdldhY9jOO6kgd
hoEMroIz6d9m0GKJLOXJNRqF6jrScfdaiqLrFc1slaUWGqEOs0Ms2UPepZmgtQzB
iJZ98o/lRF6g1VrHyFPC2Srz2tRYWgcCgv0lVA0V2mh0IO6ycqTNZkFt6ixoeGHQ
BV32wzYqwcMFcrOaxAC4o4A/RoCuJCu4tmuGDNMzlUQlAXjqKe7RbQLaD17z1DEk
BEtjo0pSjXeW8uBXoQpqqZZpUqYF0vq1uRiywDjZGRi2XWL2aKqCvlZstnodCLDV
IUfJHC8xGK0kd8PX7jZR/xFj4WCvQ6VW4d/2kMPDbKkfzLWp6pUbioYU4AWKys4i
1PhtnntpmRm0Bfe8Nn7Ksm20phO3TDHtqbt3ilSoRjk=

`pragma protect end_protected

`endif

`ifdef AVERY_PKG_HAS_AVERY_REG

//`include "avery_reg_field.sv"
//`include "avery_reg.sv"

typedef class avery_reg;

typedef bit[63:0] avery_reg_val_t;

typedef enum {
    AVERY_REG_RST_cold, // Hard
    AVERY_REG_RST_warm,
    AVERY_REG_RST_hot,
    AVERY_REG_RST_flr   // function-level reset
} avery_reg_rst_e;

// Register field access policy
typedef enum {
    AVERY_REG_ACC_RC   ,  // W: no effect                            , R: clears all bits
    AVERY_REG_ACC_RO   ,  // W: no effect                            , R: no effect
    AVERY_REG_ACC_RS   ,  // W: no effect                            , R: sets all bits
    AVERY_REG_ACC_RW   ,  // W: as-is                                , R: no effect
    AVERY_REG_ACC_W0C  ,  // W: 1/0 no effect on/clears matching bit , R: no effect
    AVERY_REG_ACC_W0CRS,  // W: 1/0 no effect on/clears matching bit , R: sets all bits
    AVERY_REG_ACC_W0S  ,  // W: 1/0 no effect on/sets matching bit   , R: no effect
    AVERY_REG_ACC_W0SRC,  // W: 1/0 no effect on/sets matching bit   , R: clears all bits
    AVERY_REG_ACC_W0T  ,  // W: 1/0 no effect on/toggles matching bit, R: no effect
    AVERY_REG_ACC_W1   ,  // W: first one after ~HARD~ reset is as-is, other W have no effects , R: no effect  (Write Once)
    AVERY_REG_ACC_W1C  ,  // W: 1/0 clears/no effect on matching bit , R: no effect
    AVERY_REG_ACC_W1CRS,  // W: 1/0 clears/no effect on matching bit , R: sets all bits
    AVERY_REG_ACC_W1S  ,  // W: 1/0 sets/no effect on matching bit   , R: no effect
    AVERY_REG_ACC_W1SRC,  // W: 1/0 sets/no effect on matching bit   , R: clears all bits
    AVERY_REG_ACC_W1T  ,  // W: 1/0 toggles/no effect on matching bit, R: no effect
    AVERY_REG_ACC_WC   ,  // W: clears all bits                      , R: no effect
    AVERY_REG_ACC_WCRS ,  // W: clears all bits                      , R: sets all bits
    AVERY_REG_ACC_WO   ,  // W: as-is                                , R: error
    AVERY_REG_ACC_WO1  ,  // W: first one after ~HARD~ reset is as-is, other W have no effects, R: error
    AVERY_REG_ACC_WOC  ,  // W: clears all bits                      , R: error
    AVERY_REG_ACC_WOS  ,  // W: sets all bits                        , R: error
    AVERY_REG_ACC_WRC  ,  // W: as-is                                , R: clears all bits
    AVERY_REG_ACC_WRS  ,  // W: as-is                                , R: sets all bits
    AVERY_REG_ACC_WS   ,  // W: sets all bits                        , R: no effect
    AVERY_REG_ACC_WSRC ,  // W: sets all bits                        , R: clears all bits
    AVERY_REG_ACC_R0W  ,  // W: as-is                                , R: return 0

    // PCIe base 3.0 p587 
    AVERY_REG_ACC_WMSK,   // W: use bit mask, 1 means a bit is ReadOnly   , R: no effect
    AVERY_REG_ACC_RsvdP,  // W: software uses read value for write to bits, R: return 0 (Rsvd for future RW)
    AVERY_REG_ACC_RsvdZ   // W: software uses 0 for writes to bits        , R: return 0 (Rsvd for future RW1C)
} avery_reg_acc_e;

/* CLASS: avery_reg_field

    There are five members visible to user: 
    - v: current value
    - dv: default value after reset
    - acctype:  access type, READONLY, RW, etc
    - sticky: if set, the current value does not change during AVERY_REG_RST_hot or AVERY_REG_RST_flr
    - sticky_flr: if set, the current value does not change during AVERY_REG_RST_flr

    User may backdoor read the five fields during any time. But user may only be
    allowed to modify the values at certain BFM phase. Please refer to the
    related BFM user guide. Use these methods to change member value:
        - set_v()
        - set_dv()
        - set_sticky()
        - set_sticky_flr()
        - set_acctype()
        - set_write_mask()
*/

class avery_reg_field extends avery_data_base;
         string          name;          // VAR: register field name
    rand avery_reg_val_t v;             // VAR: current value
    rand avery_reg_val_t dv;            // VAR: default value after reset
    rand avery_reg_acc_e acctype;       // VAR: access policy type
    rand bit             sticky;        // VAR: 1 means no change across hot reset and functional level reset
         bit             sticky_flr = 0;// VAR: 1 means no change across function level reset

    function new(
            string           name = "avery_reg_field",
            avery_reg        parent = null,    // if null, do not configure the field yet
            int              field_size,       // bit width
            int              lsb_loc,          // least significant bit location within the reg
            avery_reg_val_t  default_val  = 0,
            bit              sticky       = 0,
            avery_reg_acc_e  acctype      = AVERY_REG_ACC_RsvdP, // access type
            bit              rand_default = 1, // 1 to allow randomization of dv
            bit              rand_sticky  = 1, // 1 to allow randomization of sticky
            bit              rand_acc     = 1, // 1 to allow randomization of acctype
            bit              is_static    = 0  // 1 means this field is a static field and cannot be removed during reconfig()
        );
        this.name = name;
        if (parent) begin
            configure(parent, field_size, lsb_loc, default_val, sticky, acctype,
                      rand_default, rand_sticky, rand_acc, is_static);
            parent.add_field(this);
        end
    endfunction

    constraint constr_v_dv_same{
        v == dv;
    }

    // FUNC: set_v
    // Backdoor change current value "v".
    extern virtual function void set_v(avery_reg_val_t v);

    // FUNC: set_dv
    // Backdoor change default value "dv" and current value "v".
    extern virtual function void set_dv(avery_reg_val_t dv);

    // FUNC: set_acctype
    // Backdoor change the acctype field.
    virtual function void set_acctype(avery_reg_acc_e acctype);
        this.acctype = acctype;
    endfunction

    // FUNC: set_sticky
    // Backdoor change the sticky bit.
    virtual function void set_sticky(bit sticky);
        this.sticky = sticky;
    endfunction

    // FUNC: set_sticky_flr
    // Backdoor change the sticky_flr bit.
    virtual function void set_sticky_flr(bit sticky_flr);
        this.sticky_flr = sticky_flr;
    endfunction


    // FUNC: set_lsb_loc
    // Backdoor change the LSB bit location. Shall only be called before the
    // avery_reg is finalized. 
    extern virtual function void set_lsb_loc(int lsb_loc);

    // FUNC: set_write_mask
    // Backdoor change the Write Mask bits. Only applicable when acctype is AVERY_REG_ACC_WMSK.
    // Value 1 in "mask[i]" means the bit is READONLY.
    extern virtual function void set_write_mask(avery_reg_val_t mask);

    // FUNC: get_write_mask
    // Backdoor read the Write Mask bits. Only applicable when acctype is AVERY_REG_ACC_WMSK.
    extern virtual function avery_reg_val_t get_write_mask();

    // FUNC: get_field_size
    // Return the number of bits this reg field has.
    extern virtual function int get_field_size();


    // FUNC: get_lsb_loc
    // Return the LSB bit location of which this register field is located
    // within an avery_reg.
    extern virtual function int get_lsb_loc();

    // FUNC: read_dw
    // Frontdoor dword read (via bus interface). 
    // Read starting from bit_offset to the next dword-boundary.
    // Note that A reg field may be spreaded across dword-boundary.
    extern virtual function avery_reg_val_t read_dw(int bit_offset, avery_u32 bit_enable = 'hffff_ffff);

    // FUNC: write_dw
    // Frontdoor dword write (via bus interface).
    // Write starting from bit_offset to the next dword-boundary.
    extern virtual function void write_dw(
                                    int       bit_offset,
                                    avery_u32 value     ,
                                    avery_u32 bit_enable='hffff_ffff, // value 1 of a bit permits writting to this bit
                                    string    dbg=""     );

    // FUNC: sprint_parent
    // Return the path to this register field.
    extern virtual function string sprint_path(int verbosity = 0);

    // FUNC: get_offset_dw()
    // Return the dword offset within the avery_reg.
    extern virtual function bit[15:0] get_offset_dw();

    // FUNC: get_offset()
    // Return the byte offset within the avery_reg.
    extern virtual function bit[15:0] get_offset();

    // FUNC: set_shared()
    // Share the same reg field with others. This is typically used for W1C,
    // W1CS and W1S fields on cases where one reg field is used for set and the
    // other is used for clear.
    extern virtual function void set_shared(avery_reg_field shared);

    // FUNC: inverse
    // Backdoor inverse the current value (v) according to the field_size.
    extern virtual function void inverse();

    // FUNC: set_one
    // Backdoor set all bits to 1 for current value (v). This is for testing RW1C.
    extern virtual function void set_one();

    // FUNC: compare
    // Compare the current value (v) between avery_reg_field according to field_size.
    // Return 0 for not equal.
    extern virtual function bit compare(avery_reg_field tgt);

    // FUNC: set_print_verbosity
    // Control when a field will be printed out. A field will not be
    // printed out unless the verbosity reaches the value set here.
    // A new born field has default value 0.
    extern virtual function void set_print_verbosity(int v);



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
GNnGj9HPftnUpdnqDIw2CG0scS2Owr0X/Qg1aS0mn+7+3wv/VuNhlSFpZDIJU7zM
mOnIwNavmsda6e6u4O7LdM9EyQUHuqFDzKSVDqt4C1SCF462L28+3EFRXjmKKbNX
H780cCMYswkz4v73E8Bx5GnOWye5R/vNuI5gP4I3vFw=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
yUTsX1jBZ74ZsGmgVyPksWhPgchn90sRATdE67qmUSU0XWh6F/dlQucxl5FCJDnF
+k3tZdi5rQT2GBefty7O9nEkY4OHlcKVbh/mCqJjCfA/96uUOS2yMa1C3mn3pi8W
VzGzObfbr0aqa/A/vA7xQLIgdDSsfSOMvbcLBOrgt/s=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
LOcXhrx/0FRTGBOEA2qCgYQCbsqRntujHHDNKh5Dg4cIfgD/5hHB+FzJK/qopzMZ
2aNxz1DdzPVbs1/iQBPwKQ==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
XH35ch0JMxuZoIV8kTo3PrpPDtrZh46rcbvbZ+lxMzuMfbzj2X07FezFgvTzWKHU
/nvgUXvEu6yR6CUHAxJyVpHbtXjwCEwa06ZhMTZx49MF7Kg1+z4bq9unJtWZQ3ke
rJdEe/3I/7IvcMrQ6gxKJ4HpA1r3iZ5Z6wbl7Hjx0MBwLSy5+8Okw3GFnhZJA4Wc
EzpizZyE0H9y/9cQpC1dlPB0y1pLmh6OWOIE24O3Hg5VkekmCkQX2g4CarwhZNi0
HTqEeNINrcaSH+cYe4fq0YjyU5UiSfTFXtqtqH/LJMplaYJfwc0VY/kXXAuY3LW2
pBcI2cN4HSfDprIhWNsgkA==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
SwmQGc0nXJFGCfgAmjGP6yZCu82scXvlbbVt3ic0G3UZ63ppuLok0t+qkwn20/rc
JedLM6onNAfkt8thUshXp4hD3t+ol09kJBYC6zuw3+JN+uqrNt0HXiQSnaZA+0yi
XirAU5iyVQ2mIOGTT6FPMDM0vSNCh1xUWA11AjoWZAI=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
fh0x7CKcDNRx5VoBrXpd67TMomNshbOxzQBMiswhClMvVoZLyqNMA483yjWVF0UK
PF1PsM090n3NYIqDxcATYhwt4JRTpMqPF19xsC6ei9jMpbtmKtGgVj2C7KcowSnj
JZ0C/ArwgrWPS8W5b/PfWE+YPKt6a6JCpIAQFjXFhG3lTGd3tFTznzQ8BIrsj/B+
NbJe935Jocc9b2XaSSZaXYuk7Lf6IZQtOZfRkSsKEnTqJTJzzrjE7GER7KYHxspy
DI3TnjXOeYuKHEh6djDDrGezIBpXP3Gmg6Jx+S6gjPg9V3t0j4jwmhcr6D1c86GA
OFyrbifeRbCs+I9iR3/pag==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
GtJhR7vs+tIEaCvJxtMp8e+lAX0MBYpIll42FoCU+dgdP08RTfB8DCVQv1ej/16h
h6i3dB0zkr/L1uq1qinQ1e88dbWmvgL775weOHSiuTWhWS+MVCqQELwKxkcjpqgB
QPZc95zWQbV/oO6wUFSn86cGApo2mHAcwe9VZjipZraMGkfpaAUJ/jfp7bg8hwac
y5/KhwanuDQK8VdHryeS3fkwBokd/d94qnIHSVgvxrYnjZqk/6IQtGq2jySDx6pc
oKfB8haMOwAYmUYUBHm8NFQkVbHUUmZBZJrul+kEVMV6wZaD2ksSg7RBUzj+Y5uz
YALBhp10XfDH7GSwQxG6og==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 10624 )
`pragma protect data_block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`pragma protect end_protected

endclass



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
eIU+C9AO8FDbNd7pCHUTlg8DeVRx0aJkpLsphB1zDPolJ0uhSERFRJx2Vxcfxwaz
LCcBM5vk8qnKjpMhFmn3g+np2s5s9dMhWDmN+qkfJZcu7hc7+/z+cQYjlHSyT3JV
Cr5enFH6CS6H6HTwRNW8WPD676fsGihnZ0zKD45lljk=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
sNIG9LGWqmd3lg/zHYbHiuUzXfOkgqfT493yoKsETh2GEkyslzp7OuAgnD7mB+7/
xogK1B3QIcncotJoFdBArtabJvR09AW35VFl1efAtPaYgHEGQJpPBj2om+YiT5GI
+KAyoAmzCVz4/cAk547yVHUNzuCP/7H357wzvNDYQ/I=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
anbMIXDHOL3u+y23cvDRr6HiI/gRRxfOCBnC5FYnthjJZQFjPUj1uB+EKsEaGnyM
vpBa0gdzRsFfbVC1+Sp09g==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
UayfrTh8bYoViwv+7wBRRRthVOtOoq5XZy2T0DwkdCyy0Kc/lugmuCPgxa+XObKh
r1FP9syCIzuHSb06R9VF7abom1u4aSC+Hw/ju3Wj+5cwCUh2yNalOML1urywxSw6
Zs0fULXKHPaW314eXzGEjs7hDJpRnip6jK7+GpQZSWoXJcwTibFOLxQei0Hx4HfM
sg+yH6IgRxI2OxsS7YIMfitWrp894sKsXzzArDpjIlsQV3WuxmUsEKken1H3ZPQr
IyKKaObXB5RJz3u8uwDZaSxYFhxGgkHvbCjixzrlpEJ8kidYQou5aBOEz65VWouO
AFoQkvPSS2DOJsVtW5EdxQ==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
UGedJMMeJQHFcnGaKLklzYqpPhPLtlzb/Nm2g+YHlDsB4hKYo7N8gfZ9COlDIMq2
z1TV1NDnXAtmvtRgCxt6TUf2ZXAOcKZHW2aDWyEswJQYxfCE1paJQTnLXeZkkNaN
iZPqu7cIvDIc8hOt9o62gaLO/AHfQBNBbygOhly3bYk=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
OtHysTqCzHLM9zvZKZtrT+ZzL5n7j5g71RtmfXrCHArpAiF3/SHhMJNyllKVp7Rb
3L6AmgNWZ9bQcZtaOk4xu59sthKK+608bVygcJzfdoqYiw7yeqV33P2zdIRb61Bs
flD10gIqWk0uO4murNCnOPzZK2JS5fAEPa3/sT67RcjJYI099NR9qt3ARUCpjM5J
k5cBPwzBkS8rH+/Y2RVKYJ7rL/MDBj+bHPJ0FZKSrwk7ZRZH/lWTKwti+0v1IHqq
Yx4GgMqug4Ir8lp2XxYuFuePk867KvWBHnxDOIRdUFmdVXPbcuE19TAqOJCQQUv7
vUhw8pS331SoE2nke4iMPg==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
VgdFtsSQ40WxkXSM7ml6A05nfXbkTEWCHbhWF3ZMwHae9C2g9f0WeUHgVI/nBRGh
lkn9oTUWCHSPvtFFWpzjTYvjMxdZgybzixL3YdSYJMxhZ48LwxNqJajB+I93bFyb
Xqaj+Q2P+XtLEXFUX6Pm+wGPHazE+c4QmKqxeHc/9boT2gWrIdCmOHiNqnIQ6Kw1
3M5frGHaRPg+jh+9J2o/V/Rsa//qfGcH0UsUu3QTA/+FLn2ZXnnMWzdKliPCxEfl
ojdw2nJaulzrPqhbOjwpwIU6gC721hfjrmC6543SafI31hyzOBnk3QDVHM7WmT35
K6aZ2xvgzp/KpgpXvyC6Rg==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 6864 )
`pragma protect data_block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`pragma protect end_protected

/* Class: avery_reg 
    This represents a generic register. For example, when used in PCIe protocol,
    it can hold a capability structure.
*/
class avery_reg extends avery_data_base; 
    avery_reg_field fields[]; // only available after configure() method was called.

    function new(string name = "avery_reg");
        super.new(name);
    endfunction

    // FUNC: get_size_dw
    // Return this register size in dwords.
    extern virtual function int get_size_dw();

    // FUNC: get_size
    // Return this register size in bytes.
    extern virtual function int get_size();

    // FUNC: fread_dw
    // Frontdoor (via bus interface) read the register.
    extern virtual function avery_reg_val_t fread_dw( int      dw_offset  ,
                                                      bit[3:0] byte_enable = 4'b1111 );

    // FUNC: fwrite_dw
    // Frontdoor (via bus interface) write the register.
    extern virtual function void fwrite_dw( int             dw_offset  ,
                                            avery_u32       value      ,
                                            bit[3:0]        byte_enable = 4'b1111,
                                            avery_data_base modifier    = null );

    // FUNC: sprint
    // verbosity:-
    // 0:- register name, 
    // 1:- all non-reserved fields
    // 2:- all non-reserved fields with all default value
    // 3:- all fields including reserved
    // 4:- all fields including auto-generated fields
    extern virtual function string sprint(int verbosity = 0, string prefix = "");

    /* FUNC: configure
       Steps

       1 Create dynamic fields if extended class implements it.

       2 Create auto reserved fields to fill gaps in between.

       3 Link all fields into fields[] for normal use.

       Note that fields[] is NOT available until this method is called.*/
    extern function void configure(int n_dwords = 0);

    // FUNC: get_dword
    // Backdoor get one dword.
    extern function avery_reg_val_t get_dword(int dw_offset);


    // FUNC: sprint_dword
    // Print fields' value within this dword offset.
    extern function string sprint_dword(int dw_offset, int verbosity= 0);

    // FUNC: set_dword
    // Backdoor set a dword data to the corresponding fields' "v" value.
    // a field is readyonly, the "dv" value is also changed.
    // Typically used to mirror a register (eg: apci_func_info.sv) 
    extern virtual function void set_dword(
            int             dw_offset  ,
            avery_u32       value      ,
            bit[3:0]        byte_enable = 4'b1111,
            avery_data_base modifier    = null );

    // Allow extended class to allocate fields of dynamic size.
    // This is called inside configure() or reconfig().
    virtual function void create_dynamic_fields();
    endfunction



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
kLlnGdsD55/CkEShHdAGGhVkP+xTA5Syz2L5PdR4vFbCWVZqqE+vEZ3PXYV0FRGG
4IOtLeIGYjuxNhq98OwBN0IyBjLip4W6mKH/xzR24i+zslBpKWLXcIe7QLWZ/u2V
mE0TDzq65Uf+2ZLfIr1dZIdEnDewCNT5G3Jfxq4h6SI=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
DUA3AKLXK1jGLCEvyr9QEikSsEiq9/RKeSqwvgvBeDQ1HHvwpBl0IlvWDkZp5nRD
YxkTZkr8cyD+c5ZwVl6VEWmRdyzYQUjouHvUi48IwI95oOofzZkswowgL/XPAiC+
uZwrafl2aZfeEhWlEbk4ryi7jzOOfVibKVXNiLIneWk=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
ZBCUSrKZMFEVSUP36VimJs+KO7f0TWAxtUKWk8fstvfUOnl6+LfKOWx8borRH6gi
WaG638zdqU1N38flix5MmQ==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
TNXJOp37nQuOjjxOcXshqFJoWv73FxZZPIB7LuL7MsK/id42Sz02ddP+XdnMDq7Y
WXAuBs29gnJXDdNZbscBkXQUgrqff/+sXbvq4Bdob5vUyS08/HxtPb08qbarLU+x
68G2r6IBC/cNC02L19kO/kUILaonxYgbdboXT+d0eGDvXe89i82xDOTsd3h+iygK
ImUF3RcgRPP0SueB1ECStZBGYu47reXExVCTBQICSiyvMOiRSq/B2n5NuJLV9k14
tyfeYJtFrmiO9OKP9wYB/na6tRrT40r22VDLkSMg8NDAHgdnSd2gn799ml+BJ1yU
QgNKz/6+jftj/36/SOMVHQ==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
QMe3TuqjQsAzEaL3Pj998UKd9ITai3vtN3V/urBUsqNvrOL1KHKAfcyU5UfwVxKl
/lIk/uBxutGUP3AOKzCQhMabUk81Rpwi/uiksinAYDZfdmLseLV5sh4IYYDlcTEv
Anu4T+MTFg/h0za5IzY19gSDACvJ49Fh9g0FKm3z76M=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
NQdoyjfdNFk1tDyI0Rs9FS1vjRQirCVYFCzYDoP0pZqnEiKFjxTJ9h6Z+gkIqFul
S9yCzNigJvVqE0bBDvFaVH/vb53Q18U03NZZ720BuP1n+Jz7UYg9jWMRapZs0mkR
dSn+X+wF6YUy90795KQZ8l4nv6BG65cjOHWXIHHkKnYFdJDHozzYwZq8rDLd8m2+
UtP0we2s7nhjuVc5x+JC3c41WP09nLpYiwmk/dJiMPwiEg22J/BgkYhrmlBgE2t1
yvi/PQ0qFOhNTi414FbAWroI+NlPjjx+wKDN/Q51qZv3Mx2N4NsKF67RZ/DMNqPX
pd0Y09zZ4s+vzTwIKJ6GVQ==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
cXw4d30XNbMbYlc5cAWzNBhd4DEIzC8TKUYTnT5arKAiH+yo4TxoEACVJhbWXsh/
sEF3uWrjWA7d0Q3Xj2cj0+5yeqVdA70ucjg1xF6l9cLankZLU4o9+gJWkJzrecgY
PgllfWGRbBN9967eiK8hFF1hguCVK0UCWNNhpyAz5b84CYOutESINJ4beFcz84Fp
bM0tz2moHL0lxKaoWamUD2Qp10H/sA5EEgjILj2WiBj2r2n7cvJnOTKZKT6Spz6B
XitigzEcWbRd4UAE3PqN6YAm7bDFwOX3wYsPSjvXDjSMCyU0ci4vr+1VGsEWEi+F
6Xldg/eBYVipDNQ1bWXwmQ==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 7056 )
`pragma protect data_block
QNL59PTKzCDsVpSc+C3TiepCk7UGCCgt60KFIvhMYwZP3ykge7SdldhY9jOO6kgd
c4WIbACGglwcbbcHBSahwkhxNTL3V8N2qPI6qih8VqYlK9MRHNKzzYsngptDxUOo
+3nDeZ7Cfi5JK53LXofcMLCITYuaTF3Hl0D3CNCLevFARb+fQj6CF/YorO7XO0f/
XcLFYcU1rkHThUtEXHsQC32QkGz4/+9l+YoWI2zoXY/v7XmDEKJ3WKl89lwfbiss
jMefqvU1sbxdvKKgzCTYcdETTWXMQCtjPUt6/NZBicynBTBZf4j7iSJzdG84d6Hv
PnVCC10drzAERvSHOHqkA2POGzmoY73hsLPOPrjOLQfSSWohXKJO6wlzAfKhpAOC
u/t4quNxlHLFvSGtty7LOo8CeyfF3jmqBIn0U5B49Vx12WHTjHRawY+ahSZsvmbx
dEKTeNTgnoF9mgA86AdzVd1FT+VFYvJ6HfYHyNI2oUhXCqc6Qh0IkOyuYzHKRNEP
okKlmypciJWBWgZ5ZVYigdE+cP78upBjSRnIbVP+T2dm4S7qlttWpNlTUN6Rb1uS
foydRbp0Rbu19CMO5N8xhoE2LYeV+M9AgwupTZSUBosU5oPyTAigFbLNleq98Xcp
+GvUihHoQpQNpRevODDeyVx639hwN8+0hSY8qAHBb/TBZsCZbglNPtH8wxp8TUcI
r2nnuQbKDFsl3ktadPHs4Qt/DEHs4tf6Y4K21UgiSdw+DZhOW7PmDC/DVJiOWlai
zYahVM53Z6SLaNwh7N7nTM/6btlvZGDPNck9UNP5o1sG/sWLSXBeb9ta9sYA9Fg9
7gbRT0fJUWj0vhJnzBZH/89ggj4x1KNVrFDOF3c2Ak26thdpGfIvFEUsjSvtt89u
mkpmGoRNTN551vxC9kIzv4/1R0jmr8c2gi9ESDejDUl/WwKMS0jc1uSyZpTMlXI8
2y4sRuDVxJUzQYvrbZH/gu0X8uFOInlSKE9Yo/EfHgPs3zJMo94Z/QfdMDqazy6y
6z3id3nczS+jL+vPxdAJVofARZoN8oiUJZsbQ7DLQzPrYLH91i4U9jHXTz8tRuAb
W0rU8q/QhRknZha/0TptEIECfRQx4LtbvoZEZOrq7PJDAsF0/FMthmOs93lYZ2Zm
pfMo4pHYoShMNePrP0PfZi/65MvkMxbHStrKa2RHcidJdaBzDetbkK2Qv89SYupI
MvlMBr+5SgTukU0cyRgglNl2O9XC0zq8xYtyn30OuZcsjFaOqOaPihRlbN3TgTEd
xv0ipH9XS7u6Sr8NOIqlvQ6Co8jfu6/NawqKOM7T9Ep1nhPI8M23Kr28aTeWtiqq
EVKIuJjyiJL/0XSje6p+5m6FozPjeR+vs25OVZ9XuikR57vTRXLPfSCXobSudCjk
hkfyG0o2kyVkMlVSEa5IHMWXQv4mXfDbkIX6Tr85TvoOQJKm+kz9/CoZ/nxfUPX1
lo7U0mLpJAdQOKYRZSs19Ut5gUjp7n5d0HdCoGl1cU4Q5ldBFdHwXFJ62GL3CW4H
Ew3FuSMIfV8671NgjDIrLmd6g5NIpi+CI/pjEuqd7sFqmY+4cBATNsDyX9mp7jT9
FldmrW49J2aodgRVcfweaZRUv55hvF63MasNH1nAWjF+Ni4kU+TVfo5BIHCRlX4u
PBpr//hn+9/e61z85WzaoFXnO7OPEjavOQWwJsaZVU+51tNDka48lFw9uEA3I5Ec
hlf/u5oFA/qVeAiYzvWZGCiLQrSHqIzXBTxXrcSDFv1xx0QXoU4UeOs/6Blq6E8R
APA9vABfVFV/o8Mvqb9cBc8wkI5QOvW/acnNXqGPY6fm1lUA+qjBKVorMFwmvSXk
u5Ic138rzWinVwhUWRcWaINk/lgNYgECSstBrFvqeJTc1Pc+sGmoGSX3u4sHJaS7
ux59hvnyILiuEvPTzUQGJiDuqhADiN/7l5NfyyOLaatsOuGGVRwb7H6mUByAOVUE
tcyAWiGeLK9GXW7ZBzaX5PbeCldw8O8qbobHh6eXnfOvo5LhsnZx9AuHQlBTXu+4
IHZaHdhxlYtOMLempgZAUFrDvqlfUEcfhrr5FlwcbmuCcgvVCxS5H5fASEZ9Wu5u
CUVGXOa/I0DPu+cun+898Vs7XmPwo5n1IjGrCLNWEgXPMvy9FG0CrbJsQ9gee+Sr
mtk/UCIJtOiwHDB5jmVv8O3hHXPb4q83NhgDUotRgGz2SrDAm8ni7HwmPczyYRBP
oCyL4oSag2e6HH3zPeudicRtBAkrzNehn5JwIgBFliB+iV3k2+VssE59GW6tOSo6
Y44ZVAcgRdwkm6+4Igh6BG1KXBteB4p7/Dzi6lzmeKGB3VhR0/jMJJ2P3oT9AwSi
hjscmYMtyahlypBrUhwMVWhNumid5+WY3mYBImHl+ys+llW5rAlUgF3n4UQvjOGD
2X0f9Zv5j/WopNJSTQDW0BrA4lfcCuWXB4DuGX9FlLLYWzuT0SwkTNldiUn56RdR
+JfM+RtmnOOHuzx7wFLtecme7PSMxxnhNRPtMU3T8L87ozlZq/D0lNzuDvyGpkk0
2lvTASJWurY3YTYC/IjFZBpnsvdrqQXbZuzzjOHRzodnoei0qXRVEqr3jcucmzaA
QeQcjCiGm1rIRNUJtYMXXgyzF9bel428CrySyIheT04X/sdJ472inoFUSAq3Jzh9
rvHnTX62DWfA2YrMPz96XZAJ+Trvy82ZeryeGtrtVl8+MzcfmfNpHNfQRoiAm+HJ
FFurc2WLKWtme9jv5KlHfHrPnk5voR2CYVSl7PQl0jul18LvaScbLnEfsdjuY2x1
hzf9Q5T54PxDxycRUUR3xPu7PK8bIr973tEZZ3WNmFqpuNRdgR6kRDYJSx6Pv7Tp
T79i0SrfNG9P+cWdN/8H71y+pCv32TR4qigZ1PqMqyQb5RELPaup/Dm9EpKJxC8D
zX+jxuDV+b54dXnA+JXfb1aY46aVRuIR4lE8ddJdyDnxGeB4l86f57yZqLNhsW11
0rMVwZ5014rCMWEpmN8eM5TzrsyfQJmOCLoE3seoYuyrlPWZivinXyhu5QVjLGzz
BNROqYsMlsglBFtA6mOLGGREDAGZkBI5DQLUpDUmBKkfHGpmC75TfaHNsGq7wMru
20Qrc/df4bk3bAwd6voQ28Ig3UIrcB2aOCPyvRGNdM3G869/AaQbJQPpjbj3KDcc
Z0WDsolTs/WEMlGurvjIVXdC8cLJh8GStWCQcioVicGqnrSy0rSDckxTCqNyUuUv
Dbja0VgKrEjfJtPns+bs5QrFexjUh5DYHv9pc46acBa7kPmIj2WoKs0kI/3lCaQ9
qqumOUGaztiehVOBo+ukjc4sYYQ2OlDNDnjgFUoKxtIxSxvL+dcF0VnaGhi31z4r
51U6GrBiG3psjUPbkyeitlGss8YmW8jrMfvJjO+g5WRLwN3S6FH4D8LqmXJ3pCtW
AJXowL2C5Dm6q6RgAavB12oxEkCTzm9pl2ieE8YecJjtQUp6jHHtalQcggQBbdhD
SJgTn17xQpNyc5GOZxpEt3DsWlSm09x2OrgqcxHkRRsBeSfDOus1Zfdbj13qc057
h3eUEHga3uGxqde353IXj25z+0qE2ChsjOusjAuVdS/U9/vrEWxapqHrtEJqucKd
hBonW89zrHbU7wxUbO9q0LeMPIKb8gmsKl0YcGol9xzNKdUczDxeyuEnQwqBbFGy
2xNQREeOBj4eSXXMI7lEY0KpNSZnBQNDE9JxFyDxFb/goumrNPu9BSWfyM9V2jCr
0XmRGEQ0SYBuAYKPZRlQo+4tij2pjUpjwd9cL2sviPOxGOdv9ZR2oVaLUw0dFUi/
q/OWX54nwh59iVa1JuQBQe+7tY6lAUxJVWz4eEnKMxEApgrt7zJ8Ja+ERS8VOlGe
ZCFeOKqgESqyMLlHeXGqvWMr524Xdbr4Ou6b9wgvlPIAJcWgJQ8qjZPm9gDkk3lt
lRBYnNbTHKiSNuSCk7vXw8hkhatrTtkLfo3Cd3qej7Jd33pwEp90ExP7E4uBibW/
6FYWWbU4K85yOp9IZgvTGvIQfbyV6zjZZYUhhvHt+xpX1tAQ43n2BeIC3MvdJbtl
LZyDBi9KGBY997drxoqVsAc/T8IqWyY+nntU06KHxnbPJih7Hrsw82zujZ6Gmm2x
bCY7/yYCKwodChuSzlCr4EP8IGi+uHNo7djYBigiQSJ7HiGgxigBHf3M9WYTDPQ4
cXtVgpKgf9aZt4yhg/vM/ix8PMxtIm7/kNky6aWfsFA3sDrG8YPLgnqbDc7pukM9
OowPxt00+xO6B/EMzXzqPT28TmZSxaeJ4tio4p4diQZr6HDkcQdBMtwhM0avuJf9
WRNApoHeh7/Zf2BPEd4hoLKOtejAU5RfBBuNz467DcbKKmmKrLiFlZzpPohSzSZY
zyPPnNAohjxkGuyJkBHadp2/0VFtXtxCAn2oECF5J+PxnpTJqR136gpNrQzvSjAC
tWQyIoiVpBtkxDFluk49EFOkntlGnSSm8jtf+CG1055iuCl1+bny1FpBQtJtxunj
S6VPSpYDQaCUIQ1i1fV7kz7Mm81QSICT0gLqYqGOB/KaWZbJ0f1LH8KkUU0haZRm
2aQ2DmCQpzLRhd3VVWZpSnVZJ697JlMd1VhClxzmtui4jFTEQ9JSsLvaxFOg6vcK
VopETmo7U5eWUWKW9W7U7AD1JsU3gPIpv8R0wJLuA4y1M50Eia0jM6XBYGf63CDx
936ALijlJHcrKHxJgiaB8YsGty+fSosNT6fk/vovrsUtbE9Tl5P/zy2r7StmNmbv
Vzb/9Sa4WxSGeoni7yYQwHVmyg+rnm2an8uc48aO6ajEx2OYF9tXodR4c8VQ3RqD
8+WTknIy+0CqlNaMG2fnKAvivoPuHMWjPbefq4ILo3ugmY28MR5VuXBejeBiWRz8
P0CRxcMYqYxleEKQ83i3ZF5HZeUUX8kaErPQHberVoqWnwvQNkEmGn3Du5WM4Sbk
D6VefScILWU4j86rt49k6LUdn25snhUTmDVUGol95D4GInkRXM543ryvJ4fWkKPl
vN3RbuOo5aQT8tupTN8jUIXCzhpwwSDVqvykzsaTxqT2DHK2SyuCbbWQfhl8Lseg
AScmI4iVe/LfRDxbd0FkiP8N4IKN4G8hmRpjUY217s2qBGpNcqB0kYbQm1QQrFr/
lYjwvRIVhZeXCoKP1+bJv9ELDoxZDHXSbKT/thSUxIudpCQYASJ6JkQgehntjLkC
BmYriaB3CsdCjAPvPE5do7ooOlDcqxhwHydC38jcCiErgZ55BDitkCKJHe2pQg9A
jRm92Bw6+0M+cVOsJ5JuHH1M7rlffLbQiHwncxpNWQ4sHza6JaxIO0ADOCwpAJhN
TxGHqwK7Go4wi6QrlssUttOX4u/SGfAMSdRpS02OF2YdSs5/mI2/EayPyurJsVx0
PhoHX/Q81RCL+VD/8Oxz1rr4FtgHpAjMn1R2av4N2o4WC5ruLr4ur0NXG2y0lYNa
YY8DUd4GReWGt7i95s8fwsiRTL9BFHpoiOLAK/Gb2nwrL3BYBKS/6F+8aqR231QQ
jcx3yLrltqOSZ43zUeTBTY7pyMGfwy4haBzXXOFyeU1l/mWOLRSt38VzthpI9ALB
RR+Bi+PT9QlDjbd6tn5bOUSmMNop1+sb07vm1e1OFzaekcE0tPAYrJdZpqIbg3kx
CdAZ4T1fwBLamyuAjkNgAemU3ZxQQl60Xw7GDooDkdxOqBQSr6BaRFkIjQ5wR4x5
EUMJSFWdDwSMaYbuJWIJE8WSyUrRErAFSzo7p6i0+SnHtjjmUyaOuYizaY+yxrsy
WJYSf8i29TpyhyHF3exrbhgHT9qNVLBgW8D5mdI5zczvTtbAO3oeWdawoh7brIX6
6VYhI7PBw6EKRPRovWe7z/jVIjGr2m2Yh+t7K6j/rTY6XIJtX3fuVF+t45aGI281
1hZutxVr+FkO7+jCbhHNH+tYf29oCLoCvCdFEtNQRPX8C+zHdigMqHYRhq+NZdGa
8lJbFaGmh22KWsTA5DX9VSShx8Ue3WXcJ3KxWnPemN9FQG3YxRMoh+oGJ7ngB8M6
PHZ9YgmTYgAYgfYSiSev2agDih3FnUWWRKMoDKuHm/Ej9yEztC8TZFqsi/r2uKlW
pSrOvpI2X4X/ugj1i6t2e0fA7oT1rLeyBfDJ7sjQQVHUgPP16/CkHmjl8Im4MJRc
P744EfCV1kzr/sbZ2/r/Mfxt5wqbDYXDfEJ1PN15Xt7BAPtWtInEBWdzlTQRBS5G
idiquH6LKAZNcpX/K4p9joapgGz7DNz3zUyVGD2p+4X9GCoojv0l3jN2IE6nN+j5
gOlvQgCI0dV7Ssmsqkv/ghQJAtH1VEwVMXAZtM+bsOWAGVEm0au/JAJpgUrmpVYP
7YkhGWcNdxSYvtBCTi6bt6fUgN5hOL2w/pMBwwisAeYyuMeEygcWnAswmlMdKBzm
H3SbE5wvsuT6fLNHIvxl0h7LcMemn8yAeUyvN5XrkQxXXJLDwhU6xDkpbDuEVa+R
I2nGXINgOuOaoz1O39Fdm0gFsw2wisalpQcyZJ3TUDvs7DyUR5312W4o6+lhPwGo
JAusl8Tk9RJ/IJnJtUtj4hbGiXEIU0jAloIKfjit9ozYCF9nrC2WlgobPD9HghXD
FQahGm4kuuzYdCNKUxsIRLF3zAKxDFSxovL9HQ4E+ZDQTZFYFNdBTzWsqmYqdSQK
3gpOxuI1cqug+tbwslEj+xmUx3qH96ZjhTVl3uJwu/5xfJPc5T9a0HAbpcIpfDBi
CPHclU6Ol/jqkEQgfHYBM3blmh1ZNf6f5XjJMUnxsjgzhCkwioW7ndA6cUhu6BTX
U85iW5MgN6B2SaBwDc3O14NaGT39RkF1QHrWCjVnPoH0qnI9tezJB5OvzGdhDvFE
Kdh8iN0wvN8oDD8DRH+42hwJyWRjLmGvOXlbX51OeBaGTlEAI4oaFvTKvOdmHX4j
voX2GFwn11Lc6kjzaLNeMwKPImDiWFki2lJihbRsEm06aocROS44ewql/Ql9JXad
IKw9ghQfYa1LbRxUho2Y/TAGG+1XtV3f5I4d09YqehsCKPZXkbT/W+OL1fKRWkuK
e0ZDXcUKXZeRnDTMWyz6kePIdQRng1IczMh10q+GG19/HBN6TSUQ3bmmIGW3PBCc
7UEqWi/8tL0yEBZM3IUPiqtHxW2mRrCbNxNZhKDgSZXe/8O30ub2ymUoX5QQzvuX
kpkSde5ic22pXTb8BrFzH1g7S14G1HMihPAjAj1oSuUQ+g6Oh4+O4YvKOGIB0g73
BVK+I0MqsCapvT4wri+iqCf/RxdhdRyUjghmIbied6GU8utSrI+B2NehamZOxVzZ
2K1HVsStNxHV85NYsMBir1XVNW3qJ7XGypbfQGYh7ACGyTZ6NHLMnBZK6ZPXz6mv
z/GDylLwTir4ClQRsGxnu99OP342qeoFMp9fY+G6AgUXEg3UO7vdZdlopxk7u4Xs
RNH68W0PL5G3UC4yAHQ+g3rfOXjct/+Ggyz5MDRUjWdajkOwA1XN1bILVQKvZWLT
O68vIuJ4eU2CCQI9yurXFS8jBzz/Iejbm84e828xJRz1VYkHNY12vEZNmZrv8U96
m4mSo040XpET517vDuURu1+bTkyPcF5Au42/EHqdhN8tPVebAxICCTt+BkHB9AHn
9W1QU3kot52PkKZiPmbOm3/C56jlUDnEyHikQIyG/uAS3hjsWFTc0pJ8P4Hlimbw
nUDBSCSiSdiTdZ082ruYPOHC8ycNiRH6l66gDroGVs/0u9nK5CSXSiG3IgU7gz8+
ZvjqYpn8zZ7N3/h9cYTatHT9ET2vFThFI7pG+63v4UZq2s9F/ZvjO27A7Vs0pkwX
BtyL7wsNJkecBcEsIldTl0yrbMBHusxcqVl0Wr8BleGgPrQaYgilKE4h4HoiyT8d
XgEQUkoeYy7PsJpKMoCGkbqCcjmg19CDabewF7YwHq7MVQw+8xYcZysK7E5tKy92
vzdKp9mpSfOxnLw2ppZWDIVABcKalWOw6iD2tlKA3zoPz4Y7+0/W/ZKS02BweqEW
MBbd3xss7cSd+0CeW9EfalCPkeSv/wLRraCjPk+AQua8E8vOsYosH+soYFqaB8qu
pLrUOC74Bh89xUB0U4x3/g0Or0YF1aY3KBSyujOVgik06fbm28HDCBzZsfUZZXSJ
BF6fMC+1S9++f/YmX0SmvmhKrWGZDB8XTRfSXMIGLRwCn1RowJBFjNEzGWdZ14zl
hF5Ztyeft1eyTPk9+Trgwb62N/SVWzNZbICG5JWN/rVirjkc23EOuSAanpGpdkJB
jRFXGFBXQpaAWOC2bTTvToY6GmFVwP6P83yPSZhydjzHy1//mDQvZeZs5t7u4y0i
3oOFf6J1Vl9k8dUmH7HUInVTk2qywiqV2ZUc5iLjOYWP7/b3vjW1Ir5mY1eSe2Zy
Y6aki2SDU2vurD9g4HSK98wwtuic5Uz9QWLSj1rJXbFTO6e3u7ZjBkfDYnAzl+LW
F8lroFf1G4l19tYSZyZvld8VyJN1tNeuIPNUEGZkMDAfB/hOeKMJUjhHBmyT4L8j
v3uQVcu5SOuNWLPPOhNL/Ky4vJsYm1bsrMbQSuWtBgeWHCKFKyCeN5ElCbt1UKG9
muWT8DxVSoHUXU01ThmaTgK6n6x9bR0d7oUlZsT8smWUn19A9E9zIlt13cj9FA4X
0VbPSFFn3MN2xrfTq/fEWIOhxhXcier7a+gDZ0gL3GWt8xdVkCBDB4KnqJqFT2IG
CFPGyKK2lJsYhhADQbLHb3FOtfxJgLM7H6vU8/OGFECPFHBoxoy8p9Jw0PsNmJja
CWtcowWpNniLIzCB3+J1jXVAEigNRSqK8chNVwhbLHxc0SuRDd7D75rC/KnNIkab
WzFpHLJeohWUjWSLg0QPtlJL5x1LKtd6vuP+/I7CZDap+TkoAHLmsAm2yzqAPjra
rorcOVkDBiIIvDlJB6D+/cKJPh69FRWzop304BqDp4cIrNqvvJwHluFeEUd6rS/r
HQIpgH4Zs+kb4BgJl4ikKHyva8a+mFHkct8hmTT7pH6n07OJaJHeFE0oBROAs3Gh
nwUEfUJs+1BypFnkwuS67MnICP+qfLWKKvAMqf/4iyTbegksjtulBCEb37ahC+/e
IXXMa4gahQS1LJK946nRXXUsSJ/QxnPiXuc6iOF5s8qR/eT+sTRycEy2A2NCeyF3
qqmWA2Htz/9hmNZGJr1I3LC6Jsg6G32farpC9V2Rf5pY3PGz2FJRgqSGNwl8aCfd
SeTCMPUqeAoJOcFYyY+YEGrFVZKvxHVpWHzvPUsWi4elIf6iShq/NnzG4YTYgz1O
ee6uJpAoAnlzHpCyRuMyZGVyDQX2YkNz+yaA5BQOS+qi6tCgg/aoy8Mm7DKnrqV5

`pragma protect end_protected

endclass



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
OcX5t4ZShEDsE5PE6ww+lCvmRfUUNgg4nWLEm/DQNIhsnX6+PtDcjk3p9S/goXAs
Lm/TtiSFnMQ1eNsJJN+/JkJWlSy808YgMB1RuH6aaIyBq+w0B9R1pLe4RhYU0kMy
SxhdqHiAT/2qO7PyAXXgCTITV8kBCzhp9y1TamZTrE4=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
khq21lKte3g5jmfHALpDjNdi2gtbdn/LkorCuBkiQz0LVq5E+rcJyOXIjixT0pCp
uIxGR9jXM5tFyVcKVTL0hrByBPbMm8yeSzSmuyYaI/8SiP2Zs+bK6mRgsvYEwqI5
zdNQfiFQzs8uwVfZgpna/sg0R5BAB3VFT9BH2OfMlZg=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
Kbwk8cPtWgMdB1zFL3Rn1KUHpqoeFgyLlqh1QSR3JgnBNdxU6PiIkyWsARmnMFap
g46jsNasMlhC7v3ikHLhBw==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
yalndGijGjdkNBunRIxBigK7eRv1CCHsd2SLsOmwdgGaiR4Au8wqA4j6Cn8mJu1e
gdO9I//Q8G8kskGKllE5iKTMFaqaVNkf5YyeeiJeZTauz5/tmlt9TCFrZQVV6wBi
838HEgdimqNWqOUy7cPUuaMHUFQracHgQJOfvrqccNg+jadTJTN2iwmHHM6xTOAm
gnR1ZFBLxU+2u0glj3f9l0cwEmLXKKb9k1qPGH8Ek/l6QcVn9VrYkzNGFEQl6+fC
n8HfNB8+CYUf7dNH9okG5tKrcIhGvJ9/fD/CoMe/A7HDz2orGdemKktALqh5WYCG
tA9ii8LbAQ2VBsWOeqekFA==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
g9GyFmCdJ7OyHvxuLozEw94Q6CFGtVQMKYCF5T4UORmIhX2Mn4TWmYCp2XGkVYjg
Fj80icDZ5Bkt0+CNZ9RsV39wzXuv8oxOV1tVVSJ0Y1boDZvYXeL2qSihOq2XsRh4
DpU9QlOfVLBlgXObt6MztU3ER+4C+zJ07cetbNHuszQ=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
bIBCXg7rDO4jfcoFAycSnTojs9vkPCWW3ETqdfN5uNCTXi7eyj3TODNRVhKodVXP
0AYS3kZJ4e+XAZ0h9BIf1o+FDekVnrdXBjwfulp2H89nibSV8efQ57vA2gM4uKNa
fp7t6F9iZn7OFeBcAJ0So4KhQOpWkN5p97WsTW2atkADdfU47BnVnMhCZV1gJN0m
a2bLpR691nrD3And2dN6EkWwCrIWePt3BnTixP4mq1Puk2vDtVz9W3dMEmfWfWHU
1WePr2wKq+12nIm1GP4yC1JW+/vsqe+h8Z99LfHYuhEx2G5onlE8ayZg2T9zFCsr
6BNmdzsNOdtkbi/nHajFeg==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
hmKn0SRdhqMlPYox1Bfnd+ECAnu62hTiIYYej0Hh2aQUvms8bnwitpQ9yS2RD+3M
WeuQHLacf5nWCOt4v6TbBPW49tCxMRjYlyJTay8XY4TJaVCDM5ngIe/j1tJ/Lch1
falL7/aLqt7cxwBX9TMfg+4hqzGdRtcMwIy9eWb/XbVhSXiDq9pYJMBl/x5SKgyY
XbUeeEwbl6jJhVLvzn6pOPsDEKt89IqLTlfiMcL1JYAr51PP2BujA0L3vjkryyvh
UIPy/js0KavQJMPbPC7MzpvIMFuT/Bpf40/sLte7LejjeZOAs4QClA/gXFxakRAW
9AocqVNC9cN/t6KVjJ+CaA==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 9968 )
`pragma protect data_block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`pragma protect end_protected

`endif // AVERY_PKG_HAS_AVERY_REG

/*                                                                                                                                                                                            
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2018.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */

`ifndef avery_encryption_svh
`define avery_encryption_svh



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
GhH66TgiDuqJ1xNNsN44v24vwpsZKEviZFwg25/oIzdVpoVATYlRFzP4XNrwF4E5
ikkHGCMW6m2zPcuSbIklHK9gLG5zEAzJYwxZmCFmqoHaU0O9YkAP4Pe8g1vRo4wF
blEzM1c0fk8P7fUUirv1kajTtBSsLynecRDKYqkyTFE=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
R+FxUzgUzXcRpQav0KNPMJn/K6xyOiH5IajTVsREK2Jswzp2uenr087TPlgA00eH
W8VfJMtJIe4lPo0wcRcTxVfg6eJ1XwnRh9qxOAkUy4TGGQQXWcrIgxp6pa6ogrHe
FDMIS6+NwMpN42JqaBmuEJqpZFpS7+SJ0YomrOKbV7o=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
QFf4e0iksMoXo2OIrWVSkgvuQsyt6KYT9Nc06CNxZy6YKPYtVBQAj06+VTd79kzU
PUx7MnZB/Ysmi9mdWgBqWA==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
zv4J5kr25ShabQVRxd9A6ZuSji/qWtx/kw9eEzr3X1ZXUy80rLRrhDC8quglgUxx
Z4krhmZhFDgH16BKAyyBI4wNEzUOlAX0q17ADKiIQm+8P6hNrXotmhYus4DdkvWn
5GNdD333on5Sm150Hg0NCyri/TPG+hZfoTCuxKVDBW/g9VQdQSVaQr26nkASrZUd
ew9vdJjcWeGjz/jVFc6S0IlKUj+dMV+VURk7uH26v7ScI0nZRVB8ejArJ6VZC7Lk
crSocis6/XJ69PSg1uUAbdJ78bhpV9I5tAsd1vUKLwEls24wByYlST3CovxpVY7F
+R0n3BQyjydqUBPNLMCQLA==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
24+ofqT4haddj5xPmbu1Wj6WTz2+mzJbVVzJKqaSMKFyaaYM4IcazKYzBIvJTfZY
uMo3K+TqYJ14OnNxl6PkR1seK9oc4AVWO46slDAK6bIynACVT0yFdfFV2BxQS55M
0/I3VYeY9iGaM7zHyqvemvA2uvy2uKMqlExdN8Mle9g=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
eIWJ5UZ35KO/XD7OX0yJ5wH0q2Jkepl5H6dS8zTwS19/j2MGiY6ysmL6BB0uc9eH
hJZZRRh7HOXwbEZb5ZOak5zw4SZOCtZyV199jFSnTsfwunjmDQUMFWURZu1t1FIt
NzvuWj2BB266DnbxPBCliOcydLy+a5ZPnhIyQS+5GwBuQyFOqkdW1DJcWctRM2wf
zpdJmb3oM6QPbIQAxbB2VmySOAZi7dokZfw8wUR4UZmW7npitxhti77dySHI8DuA
E0rUsFAy04APCjM+NeLIRZ60IKWzuTsyxCkow+vHEVoj+aIiPZfoDzaapQiYuhrm
a0FITfYu22yfrDy6pRLlig==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
Qayfcb4dlzd2M5RBX4EBZk8nc5n8G14Y9yIszYztp1Gfah/LhPRbaZwDzrcilrUE
djL/d4BXAsWOH22tzYRqSr6SzKi3IN9EBl30CSWOb26RMmIIFCZ3Is1yp5G2VJeP
RtIvAB30rdLmQY6KcYpoTpno/xboJfh9N4FgUd5j1DEz3CeGT3fCLz4JjfrCEQZK
6SAjJa7yaOLK5RQS02fSUdW2b3+W2lrKYlZ9BDfJKpVCk1OXsneC8nNU92h3reC1
uBSToU8A7FAOcOSNJaP20hY95K41CjpmzVCjR1VP42wyxglkHKbrNe0HS7bs1PDv
U6Kxcy5V9yCj0c1jaYnXQw==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 131984 )
`pragma protect data_block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`pragma protect end_protected
`endif  // avery_encryption_svh


// ---------- Avery PIPE interface ------------ //

// Table 6-10 Message Bus Commands
typedef enum bit[3:0] {
    APIPE_MBC_nop     = 4'b0000,    // NOP
    APIPE_MBC_wr_unci = 4'b0001,    // write_uncommited
    APIPE_MBC_wr_ci   = 4'b0010,    // write_commited
    APIPE_MBC_rd      = 4'b0011,    // read
    APIPE_MBC_rd_comp = 4'b0100,    // read completion
    APIPE_MBC_wr_ack  = 4'b0101     // write_ack
} apipe_msg_bus_cmd_e;

typedef bit[11:0] apipe_msg_bus_addr_t;

// PIPE spec 6.0, 6.1.4.1 Message Bus Interface Commands
class apipe_msg_bus_transaction extends avery_data_base;

    apipe_msg_bus_cmd_e  cmd;  // VAR: Message BUS Command Code
    apipe_msg_bus_addr_t addr; // VAR: Message BUS Address
    avery_u8             data; // VAR: Message BUS data



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
c5EWKlnPpWyFMgNkVAMHO0V7Wn/OA2wbBReUcaAn7OSs5qAHtXZN5nD0W7V0pm50
tSNYvwb0LU60e4qSeH6LTSYAsgR8hAZ53rpujyK8NX5jjIKshSMYka6zC7BZpRRu
80KsWJhrZ8/EPBBQ4bAyHFXRqtm8kWL2t3ibpOt0KEU=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
q+F2kR3Vgx0XrgFyJ6Q5SQarvFSeRPx5Y+V1oiuh+j3rHV7xg3KkyxuxmGnnGYH5
p++OnnYcS6mYTnMcgSBBaUbUDwRIG/baYo8HqkWJqHhVSoh80luKXJWKQ+XbK9uv
wYmMRl7G/iMiV3pSRFiIYFbUFHKjpWJfvqW714Rw7Ak=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
gyNKO43bd21uA86XZmuQt/rSdPoscylZvW0z6OZWZDztaopBa8AsKcK2pP8/yQ7F
ctxWOEdbUSrg4Lsma+kF7A==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
lfOxyWZ4RYNi1xRanw0SWWD1PKXCQ0mJQAWFnWufgoSQh/cZ+5O6WSujQ2nsxk2P
ucMRRVjkLnAi38wcf8bgTZMyH/WdQvPaUAxgcZpEyAnGCoNTyuSAhJNFmsQbWCH1
vw2wCDfZrZX4joaIQ/EBIOy99uUP75pTOQM6ruPGZwZ10NVySd0oMvRVpmC/arBo
cM8x/3Z+GTJex4Fz+crPV55DfF5sq0pngeHSkJYFzYa4ZZ1eoscfdJ53GAfpLFtn
12IWAe2S1rwjCnte8His9NHcZexsAlwY1y2kvbWLP90EZ/jakYcon3oM6EqEHS6Y
74bNU97uKk/yCIr2VZqq4Q==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
HnQCNVaQFXXKLDSA3jHEvP5SMz9vKz6tJ53IdjgxGpxUVwu7XEZQXFb1TYyX0kPd
MUlkJrAE4l3wAMVP1oAEeoKtg+MJSbyxOWROs5BLI3fB+qYNkqL/3XxGTAXyZYUX
WJ0VtHDOOt5I+qo1iKOt7TIkPvLhW3Y/K4pPiI+uYSU=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
J3PGe/6dKBAa9BY6wevRFP0lNkGV2eOd32w2Q8je6zbXsUIiQTrxbdCH25X2PuhY
gDjCDg1FMUSuVYPE8tRQcTWqb9uH4YPw4Rbq8uo5JI+5mdInB+yqQWOxyUpUIi8z
o3LL3B4QjHDOkrgBg8UZ9q3LpWSzpxmyoro8u60QYHE8F6ZUQ8XAlYAeTqCRTs8G
P75yLHx4nGeFZWPA6uJLE0pAPtuxNJ3edqo2X2+0zTcKRMJuLINevA1HzP2xokzl
mrTzsRPiNFXo9Ac9RfTm5rLwFLr7fwqpy09aaFyvWxOg0JgzyNplg3mx53id308a
jD+1YgAKZe7u6SkAE8ODqQ==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
Bqpo1X/TpLx1I9+jIvlEf4aET+uGzx3avyE8xAQvGBtLG3UZgBnH+iLQmM9bkQRr
5PxJTvF2iADyJBpwFEJAGPJXEK+163lMztkCjG1OO6Ma2RhP/C7yqqjVN48ebkYG
5BttZ5KwWnmmKyvPyrw5SMz4gKeR4FJAlQudFwhW2MIqKcR7OsVi1Hd16gSDZx0I
N9lSTZBTz0regGzQ0PDzrhAKawXGcZozQKhPHX+F2hQxWfWpke6a3ZSdSFt8dP+o
/AOrX0aETuLnHkzVldsI/uCvS6H7rhDgFFIIyEpDSqGDv2xzK5AUSMKv6oePxtrI
LXpHzyMSD8DEnN4pl7ByPw==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 3344 )
`pragma protect data_block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`pragma protect end_protected

endclass

endpackage

`endif

// $Revision: 1.213 $

